(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('@angular/forms'), require('date-fns'), require('@angular/common')) :
    typeof define === 'function' && define.amd ? define('ng-element-ui/calendar', ['exports', '@angular/core', '@angular/forms', 'date-fns', '@angular/common'], factory) :
    (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory((global['ng-element-ui'] = global['ng-element-ui'] || {}, global['ng-element-ui'].calendar = {}), global.ng.core, global.ng.forms, global.dateFns, global.ng.common));
}(this, (function (exports, core, forms, dateFns, common) { 'use strict';

    var NelDateCellDirective = /** @class */ (function () {
        function NelDateCellDirective() {
        }
        return NelDateCellDirective;
    }());
    NelDateCellDirective.decorators = [
        { type: core.Directive, args: [{
                    selector: '[nelDateCell]'
                },] }
    ];

    var NelCalendarComponent = /** @class */ (function () {
        function NelCalendarComponent(cdf) {
            this.cdf = cdf;
            this.current = {
                year: 0,
                month: 0
            };
            this.calendarList = [];
            this.showButton = true;
            this.change = function (value) { };
        }
        Object.defineProperty(NelCalendarComponent.prototype, "nelRange", {
            set: function (val) {
                this.showButton = false;
                if (val && val.length !== 2) {
                    throw Error('nelRang need [Date, Date]');
                }
                if (val[0].getDay() !== 1) {
                    throw Error('First Date need is Monday');
                }
                if (val[1].getDay() !== 0) {
                    throw Error('Second Date need is Sunday');
                }
                var days = dateFns.differenceInDays(val[1], val[0]);
                if (days < 0) {
                    throw Error('Second Date need after first Date');
                }
                var week = (days + 1) / 7;
                if (week > 8) {
                    throw Error('The time span cannot exceed two months');
                }
                this.initCalendar(val[0], week);
            },
            enumerable: false,
            configurable: true
        });
        Object.defineProperty(NelCalendarComponent.prototype, "dateCell", {
            get: function () {
                return (this.nelDateCell || this.nzDateCellChild);
            },
            enumerable: false,
            configurable: true
        });
        NelCalendarComponent.prototype.initCalendar = function (date, weeks, selectedDay) {
            if (selectedDay === void 0) { selectedDay = null; }
            this.current = {
                year: dateFns.getYear(date),
                month: dateFns.getMonth(date) + 1
            };
            var firstDay = dateFns.startOfWeek(date, { weekStartsOn: 1 });
            var calendarList = [];
            for (var i = 0; i < weeks; i++) {
                var weekItem = [];
                for (var j = 0; j < 7; j++) {
                    var dateItem = dateFns.addDays(firstDay, i * 7 + j);
                    var today = this.data ? dateFns.format(this.data, 'yyyy-MM-dd') === dateFns.format(dateItem, 'yyyy-MM-dd') : false;
                    var selected = !selectedDay ? today : (dateFns.format(selectedDay, 'yyyy-MM-dd') === dateFns.format(dateItem, 'yyyy-MM-dd'));
                    weekItem.push({
                        text: dateFns.getDate(dateItem),
                        day: dateFns.format(dateItem, 'yyyy-MM-dd'),
                        date: dateItem,
                        isToday: today,
                        isSelected: selected,
                        type: this.current.month > dateFns.getMonth(dateItem) + 1 ? 'next' : this.current.month < dateFns.getMonth(dateItem) + 1 ? 'prev' : 'current'
                    });
                }
                calendarList.push(weekItem);
            }
            this.calendarList = calendarList;
            this.cdf.markForCheck();
        };
        NelCalendarComponent.prototype.selectDay = function (dayItem) {
            this.temporaryDate = dayItem.date;
            this.data = dayItem.date;
            this.change(this.data);
            if (dayItem.type === 'current') {
                for (var i = 0; i < 6; i++) {
                    for (var j = 0; j < 7; j++) {
                        this.calendarList[i][j].isSelected = false;
                    }
                }
                dayItem.isSelected = true;
            }
            else {
                this.initCalendar(dateFns.startOfMonth(dayItem.date), 6, dayItem.date);
            }
        };
        NelCalendarComponent.prototype.prevMonth = function () {
            var prev = dateFns.subMonths(this.temporaryDate, 1);
            var prevMonthDays = this.getMonthDate(prev);
            var day = this.temporaryDate.getDate();
            if (prevMonthDays < day) {
                prev.setDate(prevMonthDays);
            }
            else {
                prev.setDate(day);
            }
            this.temporaryDate = prev;
            this.initCalendar(dateFns.startOfMonth(this.temporaryDate), 6, prev);
        };
        NelCalendarComponent.prototype.getMonthDate = function (date) {
            var year = date.getFullYear();
            var month = date.getMonth() + 1;
            var d = new Date(year, month, 0);
            return d.getDate();
        };
        NelCalendarComponent.prototype.currentMonth = function () {
            this.temporaryDate = new Date();
            this.initCalendar(this.data, 6);
        };
        NelCalendarComponent.prototype.nextMonth = function () {
            var prev = dateFns.subMonths(this.temporaryDate, -1);
            var prevMonthDays = this.getMonthDate(prev);
            var day = this.temporaryDate.getDate();
            if (prevMonthDays < day) {
                prev.setDate(prevMonthDays);
            }
            else {
                prev.setDate(day);
            }
            this.temporaryDate = prev;
            this.initCalendar(dateFns.startOfMonth(this.temporaryDate), 6, this.temporaryDate);
        };
        NelCalendarComponent.prototype.writeValue = function (val) {
            if (val) {
                this.data = val;
                this.temporaryDate = val;
                this.initCalendar(dateFns.startOfMonth(this.data), 6);
            }
        };
        NelCalendarComponent.prototype.registerOnChange = function (fn) {
            this.change = fn;
        };
        NelCalendarComponent.prototype.registerOnTouched = function (fn) { };
        return NelCalendarComponent;
    }());
    NelCalendarComponent.decorators = [
        { type: core.Component, args: [{
                    selector: 'nel-calendar',
                    template: "<div class=\"el-calendar\">\r\n  <div class=\"el-calendar__header\">\r\n    <div class=\"el-calendar__title\">{{current.year}} \u5E74 {{current.month}} \u6708</div>\r\n    <div *ngIf=\"showButton\" class=\"el-calendar__button-group\">\r\n      <div class=\"el-button-group\">\r\n        <button (click)=\"prevMonth()\" class=\"el-button el-button--default el-button--mini\" type=\"button\">\r\n          <span>\u4E0A\u4E2A\u6708</span>\r\n        </button>\r\n        <button (click)=\"currentMonth()\" class=\"el-button el-button--default el-button--mini\" type=\"button\">\r\n          <span>\u4ECA\u5929</span>\r\n        </button>\r\n        <button (click)=\"nextMonth()\" class=\"el-button el-button--default el-button--mini\" type=\"button\">\r\n          <span>\u4E0B\u4E2A\u6708</span>\r\n        </button>\r\n      </div>\r\n    </div>\r\n  </div>\r\n  <div class=\"el-calendar__body\">\r\n    <table class=\"el-calendar-table\" cellspacing=\"0\" cellpadding=\"0\">\r\n      <thead>\r\n        <th>\u5468\u4E00</th>\r\n        <th>\u5468\u4E8C</th>\r\n        <th>\u5468\u4E09</th>\r\n        <th>\u5468\u56DB</th>\r\n        <th>\u5468\u4E94</th>\r\n        <th>\u5468\u516D</th>\r\n        <th>\u5468\u65E5</th>\r\n      </thead>\r\n      <tbody>\r\n        <tr class=\"el-calendar-table__row\" *ngFor=\"let weekItem of calendarList\">\r\n          <td class=\"{{dayItem.type}}\" *ngFor=\"let dayItem of weekItem\" [class.is-today]=\"dayItem.isToday\"\r\n            [class.is-selected]=\"dayItem.isSelected\" (click)=\"selectDay(dayItem)\">\r\n            <div class=\"el-calendar-day\">\r\n              <ng-container *ngIf=\"nzDateCellChild; else spanTpl\">\r\n                <ng-container *ngTemplateOutlet=\"$any(nzDateCellChild); context: { $implicit: dayItem }\">\r\n                </ng-container>\r\n              </ng-container>\r\n              <ng-template #spanTpl>\r\n                <span>{{dayItem.text}}</span>\r\n              </ng-template>\r\n            </div>\r\n          </td>\r\n        </tr>\r\n      </tbody>\r\n    </table>\r\n  </div>\r\n</div>\r\n",
                    changeDetection: core.ChangeDetectionStrategy.OnPush,
                    providers: [
                        {
                            provide: forms.NG_VALUE_ACCESSOR,
                            useExisting: core.forwardRef(function () { return NelCalendarComponent; }),
                            multi: true
                        }
                    ]
                },] }
    ];
    NelCalendarComponent.ctorParameters = function () { return [
        { type: core.ChangeDetectorRef }
    ]; };
    NelCalendarComponent.propDecorators = {
        nelRange: [{ type: core.Input }],
        nelDateCell: [{ type: core.Input }],
        nzDateCellChild: [{ type: core.ContentChild, args: [NelDateCellDirective, { static: false, read: core.TemplateRef },] }]
    };

    var NelCalendarModule = /** @class */ (function () {
        function NelCalendarModule() {
        }
        return NelCalendarModule;
    }());
    NelCalendarModule.decorators = [
        { type: core.NgModule, args: [{
                    declarations: [
                        NelCalendarComponent,
                        NelDateCellDirective
                    ],
                    exports: [
                        NelCalendarComponent,
                        NelDateCellDirective
                    ],
                    imports: [
                        common.CommonModule
                    ]
                },] }
    ];

    /**
     * Generated bundle index. Do not edit.
     */

    exports.NelCalendarComponent = NelCalendarComponent;
    exports.NelCalendarModule = NelCalendarModule;
    exports.NelDateCellDirective = NelDateCellDirective;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=ng-element-ui-calendar.umd.js.map
