(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('ng-element-ui/core/animation'), require('@angular/cdk/portal'), require('@angular/cdk/overlay'), require('rxjs'), require('@angular/common'), require('ng-element-ui/core/outlet')) :
    typeof define === 'function' && define.amd ? define('ng-element-ui/message', ['exports', '@angular/core', 'ng-element-ui/core/animation', '@angular/cdk/portal', '@angular/cdk/overlay', 'rxjs', '@angular/common', 'ng-element-ui/core/outlet'], factory) :
    (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory((global['ng-element-ui'] = global['ng-element-ui'] || {}, global['ng-element-ui'].message = {}), global.ng.core, global['ng-element-ui'].core.animation, global.ng.cdk.portal, global.ng.cdk.overlay, global.rxjs, global.ng.common, global['ng-element-ui'].core.outlet));
}(this, (function (exports, i0, animation, portal, i1, rxjs, common, outlet) { 'use strict';

    var MessageRef = /** @class */ (function () {
        function MessageRef(type, id, leave, overlay, nelContent, nelOptions) {
            this.type = type;
            this.id = id;
            this.leave = leave;
            this.overlay = overlay;
            this.nelContent = nelContent;
            this.nelOptions = nelOptions;
            this.height = 48;
            this.top = 0;
            this.componentInstance = null;
        }
        MessageRef.prototype.close = function () {
            this.componentInstance.state = 'done';
        };
        return MessageRef;
    }());

    var NelMessageComponent = /** @class */ (function () {
        function NelMessageComponent(messageRef) {
            this.messageRef = messageRef;
            this.id = 0;
            this.top = 36;
            this.showClose = false;
            this.duration = 3000;
            this.center = false;
            this.state = 'start';
        }
        NelMessageComponent.prototype.ngOnDestroy = function () {
            if (this.timer) {
                clearTimeout(this.timer);
            }
        };
        NelMessageComponent.prototype.ngOnInit = function () {
            this.type = this.messageRef.type;
            this.id = this.messageRef.id;
            this.top = this.messageRef.top;
            this.content = this.messageRef.nelContent;
            this.overlay = this.messageRef.overlay;
            if (this.messageRef.nelOptions) {
                if (this.messageRef.nelOptions.showClose) {
                    this.showClose = this.messageRef.nelOptions.showClose;
                }
                if (this.messageRef.nelOptions.duration !== undefined) {
                    this.duration = this.messageRef.nelOptions.duration;
                }
                if (this.messageRef.nelOptions.center) {
                    this.center = this.messageRef.nelOptions.center;
                }
                if (this.messageRef.nelOptions.onClose) {
                    this.onClose = this.messageRef.nelOptions.onClose;
                }
            }
            this.initTimer();
        };
        NelMessageComponent.prototype.ngAfterViewInit = function () {
            this.messageRef.height = this.messageEle.nativeElement.offsetHeight;
        };
        NelMessageComponent.prototype.initTimer = function () {
            var _this = this;
            if (this.duration > 0) {
                this.timer = setTimeout(function () {
                    _this.state = 'done';
                }, this.duration);
            }
        };
        NelMessageComponent.prototype.onAnimationStart = function (event) {
            if (event.toState === 'done') {
                clearTimeout(this.timer);
                this.messageRef.leave.next(this.id);
            }
        };
        NelMessageComponent.prototype.onAnimationDone = function (event) {
            if (event.toState === 'done') {
                this.overlay.dispose();
                if (this.onClose) {
                    this.onClose();
                }
            }
        };
        NelMessageComponent.prototype.mouseenter = function () {
            if (this.timer) {
                clearTimeout(this.timer);
            }
        };
        NelMessageComponent.prototype.mouseleave = function () {
            this.initTimer();
        };
        NelMessageComponent.prototype.close = function () {
            if (this.timer) {
                clearTimeout(this.timer);
            }
            this.state = 'done';
        };
        return NelMessageComponent;
    }());
    NelMessageComponent.decorators = [
        { type: i0.Component, args: [{
                    selector: 'nel-message',
                    template: "<div #messageEle class=\"el-message el-message--{{type}}\" [class.is-center]=\"center\" role=\"alert\"\r\n  [style.top]=\"top + 'px'\" [@messageMotion]=\"state\" (@messageMotion.start)=\"onAnimationStart($event)\"\r\n  (@messageMotion.done)=\"onAnimationDone($event)\" (mouseenter)=\"mouseenter()\" (mouseleave)=\"mouseleave()\">\r\n  <i class=\"el-message__icon el-icon-{{type}}\"></i>\r\n  <p class=\"el-message__content\">\r\n    <ng-container *stringTemplate=\"content\">{{content}}</ng-container>\r\n  </p>\r\n  <div *ngIf=\"showClose\" (click)=\"close()\" class=\"el-message__closeBtn el-icon-close\"></div>\r\n</div>\r\n",
                    animations: [animation.messageMotion]
                },] }
    ];
    NelMessageComponent.ctorParameters = function () { return [
        { type: MessageRef }
    ]; };
    NelMessageComponent.propDecorators = {
        messageEle: [{ type: i0.ViewChild, args: ['messageEle', { static: false },] }]
    };

    var NelMessageServiceModule = /** @class */ (function () {
        function NelMessageServiceModule() {
        }
        return NelMessageServiceModule;
    }());
    NelMessageServiceModule.decorators = [
        { type: i0.NgModule }
    ];

    var NelMessageService = /** @class */ (function () {
        function NelMessageService(overlay, injector) {
            this.overlay = overlay;
            this.injector = injector;
            this.messageId = 0;
            this.leave = new rxjs.Subject();
            this.messageRefList = [];
            this._handlerLeave();
        }
        NelMessageService.prototype.info = function (content, options) {
            return this.show('info', content, options);
        };
        NelMessageService.prototype.success = function (content, options) {
            return this.show('success', content, options);
        };
        NelMessageService.prototype.warning = function (content, options) {
            return this.show('warning', content, options);
        };
        NelMessageService.prototype.error = function (content, options) {
            return this.show('error', content, options);
        };
        NelMessageService.prototype.show = function (type, content, options) {
            this.messageId++;
            var overlayRef = this.overlay.create();
            var messageRef = new MessageRef(type, this.messageId, this.leave, overlayRef, content, options);
            var injector = this.createInjector(messageRef, this.injector);
            var componentRef = overlayRef.attach(new portal.ComponentPortal(NelMessageComponent, null, injector));
            // 根据message列表，获取下一个message的top
            var top = 36;
            this.messageRefList.forEach(function (item) {
                top += item.height + 16;
            });
            this.messageRefList.push(messageRef);
            messageRef.top = top;
            messageRef.componentInstance = componentRef.instance;
            return messageRef;
        };
        NelMessageService.prototype.createInjector = function (ref, inj) {
            return i0.Injector.create({
                parent: inj,
                providers: [{ provide: MessageRef, useValue: ref }]
            });
        };
        NelMessageService.prototype._handlerLeave = function () {
            var _this = this;
            this.leave.subscribe(function (id) {
                var componentIndex = _this.messageRefList.findIndex(function (item) { return item.id === id; });
                if (componentIndex > -1) {
                    var height = _this.messageRefList[componentIndex].height;
                    if (componentIndex !== _this.messageRefList.length - 1) {
                        for (var i = componentIndex + 1; i < _this.messageRefList.length; i++) {
                            _this.messageRefList[i].componentInstance.top -= height + 16;
                        }
                    }
                    _this.messageRefList.splice(componentIndex, 1);
                }
            });
        };
        return NelMessageService;
    }());
    NelMessageService.ɵprov = i0.ɵɵdefineInjectable({ factory: function NelMessageService_Factory() { return new NelMessageService(i0.ɵɵinject(i1.Overlay), i0.ɵɵinject(i0.INJECTOR)); }, token: NelMessageService, providedIn: NelMessageServiceModule });
    NelMessageService.decorators = [
        { type: i0.Injectable, args: [{
                    providedIn: NelMessageServiceModule
                },] }
    ];
    NelMessageService.ctorParameters = function () { return [
        { type: i1.Overlay },
        { type: i0.Injector }
    ]; };

    var NelMessageModule = /** @class */ (function () {
        function NelMessageModule() {
        }
        return NelMessageModule;
    }());
    NelMessageModule.decorators = [
        { type: i0.NgModule, args: [{
                    declarations: [
                        NelMessageComponent
                    ],
                    exports: [
                        NelMessageComponent
                    ],
                    imports: [
                        common.CommonModule,
                        i1.OverlayModule,
                        outlet.NelOutletModule,
                        NelMessageServiceModule
                    ]
                },] }
    ];

    /**
     * Generated bundle index. Do not edit.
     */

    exports.NelMessageComponent = NelMessageComponent;
    exports.NelMessageModule = NelMessageModule;
    exports.NelMessageService = NelMessageService;
    exports.ɵa = MessageRef;
    exports.ɵb = NelMessageServiceModule;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=ng-element-ui-message.umd.js.map
