(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('@angular/common'), require('@angular/cdk/overlay'), require('ng-element-ui/core/outlet')) :
    typeof define === 'function' && define.amd ? define('ng-element-ui/popover', ['exports', '@angular/core', '@angular/common', '@angular/cdk/overlay', 'ng-element-ui/core/outlet'], factory) :
    (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory((global['ng-element-ui'] = global['ng-element-ui'] || {}, global['ng-element-ui'].popover = {}), global.ng.core, global.ng.common, global.ng.cdk.overlay, global['ng-element-ui'].core.outlet));
}(this, (function (exports, core, common, overlay, outlet) { 'use strict';

    var NelPopoverComponent = /** @class */ (function () {
        function NelPopoverComponent() {
            this.visibleChange = new core.EventEmitter();
            this.isOpen = false;
            this.arrowLeft = '';
            this.arrowRight = '';
            this.arrowTop = '';
            this.arrowBottom = '';
            this.transform = '';
        }
        NelPopoverComponent.prototype.onClickOutside = function (event) {
            // 触发点击事件的dom，不在origin内，方才关闭
            if (!this.origin.elementRef.nativeElement.contains(event.target) && this.trigger !== 'manual') {
                this.isOpen = false;
                this.visibleChange.emit(false);
            }
        };
        NelPopoverComponent.prototype.close = function () {
            this.isOpen = false;
        };
        return NelPopoverComponent;
    }());
    NelPopoverComponent.decorators = [
        { type: core.Component, args: [{
                    selector: 'nel-popover',
                    template: "<ng-template cdkConnectedOverlay [cdkConnectedOverlayOrigin]=\"origin\" [cdkConnectedOverlayOpen]=\"isOpen\"\r\n  [cdkConnectedOverlayPositions]=\"positionStrategy\" [cdkConnectedOverlayMinWidth]=\"150\"\r\n  [cdkConnectedOverlayWidth]=\"width!\" (overlayOutsideClick)=\"onClickOutside($event)\">\r\n  <div class=\"el-popover--plain el-popover el-popper is-light\" role=\"tooltip\"\r\n    [style.width]=\"width ? (width! + 'px') : ''\">\r\n    <div *ngIf=\"title\" class=\"el-popover__title\" role=\"title\">{{title}}</div>\r\n    <ng-container *stringTemplate=\"content!\">{{content!}}</ng-container>\r\n    <div class=\"el-popper__arrow\" [style.left]=\"arrowLeft\" [style.right]=\"arrowRight\" [style.top]=\"arrowTop\"\r\n      [style.bottom]=\"arrowBottom\" [style.transform]=\"transform\"></div>\r\n  </div>\r\n</ng-template>\r\n"
                },] }
    ];
    NelPopoverComponent.propDecorators = {
        visibleChange: [{ type: core.Output }]
    };

    var NelPopoverDirective = /** @class */ (function () {
        function NelPopoverDirective(hostView, elementRef, resolver, renderer) {
            this.hostView = hostView;
            this.elementRef = elementRef;
            this.resolver = resolver;
            this.renderer = renderer;
            this.nelPopoverTrigger = 'click';
            this.nelPopoverPlacement = 'bottom';
            this.nelPopoverVisibleChange = new core.EventEmitter();
            this.triggerDisposables = [];
            this.componentFactory = this.resolver.resolveComponentFactory(NelPopoverComponent);
            var componentRef = this.hostView.createComponent(this.componentFactory);
            this.component = componentRef.instance;
            this.renderer.removeChild(this.renderer.parentNode(this.elementRef.nativeElement), componentRef.location.nativeElement);
        }
        Object.defineProperty(NelPopoverDirective.prototype, "nelPopoverVisible", {
            set: function (val) {
                if (val) {
                    if (this.component) {
                        this.show();
                    }
                }
                else {
                    this.hide();
                }
            },
            enumerable: false,
            configurable: true
        });
        NelPopoverDirective.prototype.ngOnDestroy = function () {
            this.removeTriggerListeners();
        };
        NelPopoverDirective.prototype.ngOnInit = function () {
            this.trigger();
        };
        NelPopoverDirective.prototype.trigger = function () {
            var _this = this;
            if (this.nelPopoverTrigger === 'click') {
                this.triggerDisposables.push(this.renderer.listen(this.elementRef.nativeElement, 'click', function () { return _this.show(); }));
            }
            else if (this.nelPopoverTrigger === 'focus') {
                this.triggerDisposables.push(this.renderer.listen(this.elementRef.nativeElement, 'focus', function () { return _this.show(); }));
                this.triggerDisposables.push(this.renderer.listen(this.elementRef.nativeElement, 'blur', function () { return _this.hide(); }));
            }
            else if (this.nelPopoverTrigger === 'hover') {
                this.triggerDisposables.push(this.renderer.listen(this.elementRef.nativeElement, 'mouseenter', function () { return _this.show(); }));
                this.triggerDisposables.push(this.renderer.listen(this.elementRef.nativeElement, 'mouseleave', function () { return _this.hide(); }));
            }
        };
        NelPopoverDirective.prototype.removeTriggerListeners = function () {
            this.triggerDisposables.forEach(function (dispose) { return dispose(); });
            this.triggerDisposables.length = 0;
        };
        NelPopoverDirective.prototype.show = function () {
            var position = {
                originX: 'start',
                originY: 'top',
                overlayX: 'start',
                overlayY: 'bottom',
                offsetX: 0,
                offsetY: 0,
            };
            var arrowLeft = '';
            var arrowRight = '';
            var arrowTop = '';
            var arrowBottom = '';
            var transform = '';
            switch (this.nelPopoverPlacement) {
                case 'top-start':
                    position.originX = 'start';
                    position.originY = 'top';
                    position.overlayX = 'start';
                    position.overlayY = 'bottom';
                    position.offsetY = -10;
                    arrowLeft = '0';
                    transform = 'translate(30px, 5px)';
                    break;
                case 'top':
                    position.originX = 'center';
                    position.originY = 'top';
                    position.overlayX = 'center';
                    position.overlayY = 'bottom';
                    position.offsetY = -10;
                    arrowLeft = '50%';
                    transform = 'translate(-50%, 5px)';
                    break;
                case 'top-end':
                    position.originX = 'end';
                    position.originY = 'top';
                    position.overlayX = 'end';
                    position.overlayY = 'bottom';
                    position.offsetY = -10;
                    arrowLeft = '50%';
                    transform = 'translate(30px, 5px)';
                    break;
                case 'bottom-start':
                    position.originX = 'start';
                    position.originY = 'bottom';
                    position.overlayX = 'start';
                    position.overlayY = 'top';
                    position.offsetY = 10;
                    arrowLeft = '0';
                    arrowTop = '-10px';
                    transform = 'translate(30px, 5px)';
                    break;
                case 'bottom':
                    position.originX = 'center';
                    position.originY = 'bottom';
                    position.overlayX = 'center';
                    position.overlayY = 'top';
                    position.offsetY = 10;
                    arrowLeft = '50%';
                    arrowTop = '-10px';
                    transform = 'translate(-50%, 5px)';
                    break;
                case 'bottom-end':
                    position.originX = 'end';
                    position.originY = 'bottom';
                    position.overlayX = 'end';
                    position.overlayY = 'top';
                    position.offsetY = 10;
                    arrowLeft = '50%';
                    arrowTop = '-10px';
                    transform = 'translate(30px, 5px)';
                    break;
                case 'left-start':
                    position.originX = 'start';
                    position.originY = 'top';
                    position.overlayX = 'end';
                    position.overlayY = 'top';
                    position.offsetX = -10;
                    arrowRight = '0';
                    arrowTop = '0';
                    transform = 'translate(5px, 15px)';
                    break;
                case 'left':
                    position.originX = 'start';
                    position.originY = 'center';
                    position.overlayX = 'end';
                    position.overlayY = 'center';
                    position.offsetX = -10;
                    arrowRight = '0';
                    arrowTop = '50%';
                    transform = 'translate(5px, -50%)';
                    break;
                case 'left-end':
                    position.originX = 'start';
                    position.originY = 'bottom';
                    position.overlayX = 'end';
                    position.overlayY = 'bottom';
                    position.offsetX = -10;
                    arrowRight = '0';
                    arrowBottom = '0';
                    transform = 'translate(5px, -15px)';
                    break;
                case 'right-start':
                    position.originX = 'end';
                    position.originY = 'top';
                    position.overlayX = 'start';
                    position.overlayY = 'top';
                    position.offsetX = 10;
                    arrowLeft = '0';
                    arrowTop = '0';
                    transform = 'translate(-5px, 15px)';
                    break;
                case 'right':
                    position.originX = 'end';
                    position.originY = 'center';
                    position.overlayX = 'start';
                    position.overlayY = 'center';
                    position.offsetX = 10;
                    arrowLeft = '0';
                    arrowTop = '50%';
                    transform = 'translate(-5px, -50%)';
                    break;
                case 'right-end':
                    position.originX = 'end';
                    position.originY = 'bottom';
                    position.overlayX = 'start';
                    position.overlayY = 'bottom';
                    position.offsetX = 10;
                    arrowLeft = '0';
                    arrowBottom = '0';
                    transform = 'translate(-5px, -15px)';
                    break;
            }
            if (this.component) {
                this.component.title = this.nelPopoverTitle;
                this.component.content = this.nelPopoverContent;
                this.component.width = this.nelPopoverWidth;
                this.component.trigger = this.nelPopoverTrigger;
                this.component.visibleChange = this.nelPopoverVisibleChange;
                this.component.origin = { elementRef: this.elementRef };
                this.component.isOpen = true;
                this.component.positionStrategy = [position];
                this.component.arrowLeft = arrowLeft;
                this.component.arrowRight = arrowRight;
                this.component.arrowTop = arrowTop;
                this.component.arrowBottom = arrowBottom;
                this.component.transform = transform;
                this.nelPopoverVisibleChange.emit(true);
            }
        };
        NelPopoverDirective.prototype.hide = function () {
            var _a;
            (_a = this.component) === null || _a === void 0 ? void 0 : _a.close();
        };
        return NelPopoverDirective;
    }());
    NelPopoverDirective.decorators = [
        { type: core.Directive, args: [{
                    selector: '[nel-popover]',
                },] }
    ];
    NelPopoverDirective.ctorParameters = function () { return [
        { type: core.ViewContainerRef },
        { type: core.ElementRef },
        { type: core.ComponentFactoryResolver },
        { type: core.Renderer2 }
    ]; };
    NelPopoverDirective.propDecorators = {
        nelPopoverTitle: [{ type: core.Input }],
        nelPopoverContent: [{ type: core.Input }],
        nelPopoverWidth: [{ type: core.Input }],
        nelPopoverTrigger: [{ type: core.Input }],
        nelPopoverPlacement: [{ type: core.Input }],
        nelPopoverVisible: [{ type: core.Input }],
        nelPopoverVisibleChange: [{ type: core.Output }]
    };

    var NelPopoverModule = /** @class */ (function () {
        function NelPopoverModule() {
        }
        return NelPopoverModule;
    }());
    NelPopoverModule.decorators = [
        { type: core.NgModule, args: [{
                    declarations: [
                        NelPopoverDirective,
                        NelPopoverComponent
                    ],
                    exports: [
                        NelPopoverDirective,
                        NelPopoverComponent
                    ],
                    imports: [
                        common.CommonModule,
                        overlay.OverlayModule,
                        outlet.NelOutletModule
                    ]
                },] }
    ];

    /**
     * Generated bundle index. Do not edit.
     */

    exports.NelPopoverComponent = NelPopoverComponent;
    exports.NelPopoverDirective = NelPopoverDirective;
    exports.NelPopoverModule = NelPopoverModule;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=ng-element-ui-popover.umd.js.map
