import { EventEmitter, Component, ElementRef, Input, Output, ViewChild, NgModule } from '@angular/core';
import { Subject, fromEvent } from 'rxjs';
import { getScrollContainer } from 'ng-element-ui/core/utils';

class NelAffixComponent {
    constructor(elementRef) {
        this.elementRef = elementRef;
        this.nelOffset = 0;
        this.nelPosition = 'top';
        this.nelZIndex = 100;
        this.nelOnChange = new EventEmitter();
        this.nelOnScroll = new EventEmitter();
        this.fixed = false;
        this.width = 0;
        this.height = 0;
        this.reachBottom$ = new Subject();
    }
    ngOnDestroy() {
        if (this.subscribeScoll) {
            this.subscribeScoll.unsubscribe();
        }
    }
    ngAfterViewInit() {
        this.width = this.elementRef.nativeElement.offsetWidth;
        this.height = this.elementRef.nativeElement.offsetHeight;
        this.container = getScrollContainer(this.elementRef.nativeElement, true);
        this.initScroll();
        this.handleScroll(true);
    }
    initScroll() {
        this.subscribeScoll = fromEvent(this.container, 'scroll')
            .subscribe(() => {
            this.handleScroll();
        });
    }
    handleScroll(init = false) {
        let fixed = false;
        if (this.nelPosition === 'top') {
            if (this.elementRef.nativeElement.getBoundingClientRect().top <= this.nelOffset) {
                fixed = true;
            }
            if (fixed && this.nelTarget) {
                const difference = this.nelTarget.getBoundingClientRect().bottom - this.nelOffset - this.height;
                if (difference < 0) {
                    this.fixedEle.nativeElement.style.transform = `translateY(${difference}px)`;
                    this.fixedEle.nativeElement.style.zIndex = '';
                }
                else {
                    this.fixedEle.nativeElement.style.transform = '';
                    this.fixedEle.nativeElement.style.zIndex = this.nelZIndex;
                }
                if (this.nelTarget.getBoundingClientRect().bottom < 0) {
                    fixed = false;
                }
                else {
                    fixed = true;
                }
            }
        }
        else {
            if (document.documentElement.clientHeight - this.elementRef.nativeElement.getBoundingClientRect().bottom <= this.nelOffset) {
                fixed = true;
            }
        }
        if (this.fixed !== fixed) {
            this.changeFixed(fixed);
        }
        if (!init) {
            this.nelOnScroll.emit({ scrollTop: this.container.scrollTop, affix: fixed });
        }
    }
    changeFixed(fixed) {
        setTimeout(() => {
            this.fixed = fixed;
            if (fixed) {
                this.elementRef.nativeElement.style.width = this.width + 'px';
                this.elementRef.nativeElement.style.height = this.height + 'px';
                this.fixedEle.nativeElement.style.width = this.width + 'px';
                this.fixedEle.nativeElement.style.height = this.height + 'px';
                if (this.nelPosition === 'top') {
                    this.fixedEle.nativeElement.style.top = this.nelOffset + 'px';
                }
                else {
                    this.fixedEle.nativeElement.style.bottom = this.nelOffset + 'px';
                }
            }
            else {
                this.fixedEle.nativeElement.style.width = '';
                this.fixedEle.nativeElement.style.height = '';
                this.fixedEle.nativeElement.style.top = '';
                this.elementRef.nativeElement.style.width = '';
                this.elementRef.nativeElement.style.height = '';
            }
            this.nelOnChange.emit(fixed);
        }, 0);
    }
}
NelAffixComponent.decorators = [
    { type: Component, args: [{
                selector: 'nel-affix',
                template: "<div #fixedEle [class.el-affix--fixed]=\"fixed\" style=\"z-index: 1000;\">\r\n  <ng-content></ng-content>\r\n</div>\r\n",
                host: {
                    '[class]': `'el-affix'`
                }
            },] }
];
NelAffixComponent.ctorParameters = () => [
    { type: ElementRef }
];
NelAffixComponent.propDecorators = {
    nelOffset: [{ type: Input }],
    nelTarget: [{ type: Input }],
    nelPosition: [{ type: Input }],
    nelZIndex: [{ type: Input }],
    nelOnChange: [{ type: Output }],
    nelOnScroll: [{ type: Output }],
    fixedEle: [{ type: ViewChild, args: ['fixedEle', { static: false },] }]
};

class NelAffixModule {
}
NelAffixModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    NelAffixComponent
                ],
                exports: [
                    NelAffixComponent
                ]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { NelAffixComponent, NelAffixModule };
//# sourceMappingURL=ng-element-ui-affix.js.map
