import { EventEmitter, Component, Input, Output, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { NelIconModule } from 'ng-element-ui/icon';

class NelAvatarComponent {
    constructor() {
        this.size = 'large';
        this.loading = false;
        this.nelShape = 'circle';
        this.nelFit = 'cover';
        this.nelOnError = new EventEmitter();
    }
    set nelSize(val) {
        if (typeof val === 'number') {
            this.sizeNum = val;
            this.size = undefined;
        }
        else {
            this.sizeNum = undefined;
            this.size = val;
        }
    }
    set nelSrc(val) {
        this.loading = true;
        const img = new Image();
        img.src = val;
        img.onload = (e) => {
            this.src = val;
            this.loading = false;
        };
        img.onerror = (e) => {
            if (e instanceof Event) {
                e.preventDefault();
                e.stopPropagation();
            }
            this.nelOnError.emit(e);
            this.loading = false;
        };
    }
}
NelAvatarComponent.decorators = [
    { type: Component, args: [{
                selector: 'nel-avatar',
                template: "<span class=\"el-avatar el-avatar--{{nelShape}}\" [class.el-avatar--large]=\"size == 'large'\"\r\n  [class.el-avatar--medium]=\"size == 'medium'\" [class.el-avatar--small]=\"size == 'small'\"\r\n  [class.el-avatar--icon]=\"nelIcon\" [style.height]=\"sizeNum! + 'px'\" [style.width]=\"sizeNum! + 'px'\"\r\n  [style.line-height]=\"sizeNum! + 'px'\">\r\n  <i *ngIf=\"nelIcon\" nel-icon [nelType]=\"nelIcon\"></i>\r\n  <img *ngIf=\"src\" [src]=\"src\" [style.object-fit]=\"nelFit\" [alt]=\"nelAlt\">\r\n  <ng-container *ngIf=\"nelText\">{{nelText}}</ng-container>\r\n  <ng-content *ngIf=\"!loading\"></ng-content>\r\n</span>\r\n"
            },] }
];
NelAvatarComponent.propDecorators = {
    nelIcon: [{ type: Input }],
    nelSize: [{ type: Input }],
    nelText: [{ type: Input }],
    nelShape: [{ type: Input }],
    nelSrc: [{ type: Input }],
    nelAlt: [{ type: Input }],
    nelFit: [{ type: Input }],
    nelOnError: [{ type: Output }]
};

class NelAvatarModule {
}
NelAvatarModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    NelAvatarComponent
                ],
                exports: [
                    NelAvatarComponent
                ],
                imports: [
                    CommonModule,
                    NelIconModule
                ]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { NelAvatarComponent, NelAvatarModule };
//# sourceMappingURL=ng-element-ui-avatar.js.map
