import { EventEmitter, Component, ChangeDetectionStrategy, Inject, ChangeDetectorRef, Input, Output, NgModule } from '@angular/core';
import { DOCUMENT, CommonModule } from '@angular/common';
import { fromEvent } from 'rxjs';
import { fadeMotion } from 'ng-element-ui/core/animation';
import { NelIconModule } from 'ng-element-ui/icon';

class NelBacktopComponent {
    constructor(doc, cdr) {
        this.cdr = cdr;
        this.visible = false;
        this.nelVisibilityHeight = 200;
        this.nelRight = 40;
        this.nelBottom = 40;
        this.nelClick = new EventEmitter();
        this.target = null;
        this.doc = doc;
    }
    ngOnDestroy() {
        this.subscribeScoll.unsubscribe();
    }
    ngAfterViewInit() {
        this.initTarget();
    }
    initTarget() {
        if (typeof this.nelTarget === 'string') {
            this.target = this.doc.querySelector(this.nelTarget);
        }
        else {
            this.target = this.nelTarget;
        }
        this.registerScrollEvent();
    }
    getTarget() {
        return this.target || window;
    }
    getScroll() {
        const target = this.getTarget();
        if (target instanceof HTMLElement) {
            return target.scrollTop;
        }
        else {
            return target.pageYOffset;
        }
    }
    registerScrollEvent() {
        if (this.subscribeScoll) {
            this.subscribeScoll.unsubscribe();
        }
        this.subscribeScoll = fromEvent(this.getTarget(), 'scroll')
            .subscribe(() => {
            this.handleScroll();
        });
    }
    handleScroll() {
        if (this.getScroll() > this.nelVisibilityHeight) {
            this.visible = true;
        }
        else {
            this.visible = false;
        }
        this.cdr.detectChanges();
    }
    backTop() {
        this.scrollTop();
        this.nelClick.emit();
    }
    scrollTop() {
        const target = this.getTarget();
        target.scrollTo({ top: 0, behavior: 'smooth' });
    }
    ngOnChanges(changes) {
        const { nelTarget } = changes;
        if (nelTarget && !nelTarget.firstChange) {
            this.initTarget();
        }
    }
}
NelBacktopComponent.decorators = [
    { type: Component, args: [{
                selector: 'nel-backtop',
                template: "<div class=\"el-backtop\" (click)=\"backTop()\" *ngIf=\"visible\" @fadeMotion [style.right]=\"nelRight + 'px'\"\r\n  [style.bottom]=\"nelBottom + 'px'\">\r\n  <i *ngIf=\"!nelTemplate\" nel-icon [nelType]=\"'caret-top'\"></i>\r\n  <ng-container *ngTemplateOutlet=\"nelTemplate\"></ng-container>\r\n</div>\r\n",
                changeDetection: ChangeDetectionStrategy.OnPush,
                animations: [fadeMotion]
            },] }
];
NelBacktopComponent.ctorParameters = () => [
    { type: undefined, decorators: [{ type: Inject, args: [DOCUMENT,] }] },
    { type: ChangeDetectorRef }
];
NelBacktopComponent.propDecorators = {
    nelTarget: [{ type: Input }],
    nelVisibilityHeight: [{ type: Input }],
    nelRight: [{ type: Input }],
    nelBottom: [{ type: Input }],
    nelTemplate: [{ type: Input }],
    nelClick: [{ type: Output }]
};

class NelBacktopModule {
}
NelBacktopModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    NelBacktopComponent
                ],
                exports: [
                    NelBacktopComponent
                ],
                imports: [
                    CommonModule,
                    NelIconModule
                ]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { NelBacktopComponent, NelBacktopModule };
//# sourceMappingURL=ng-element-ui-backtop.js.map
