import { __decorate } from 'tslib';
import { Component, ElementRef, Renderer2, Input, NgModule } from '@angular/core';
import { InputBoolean } from 'ng-element-ui/core/utils';
import { CommonModule } from '@angular/common';
import { NelIconModule } from 'ng-element-ui/icon';

class NelButtonComponent {
    constructor(elementRef, renderer) {
        this.elementRef = elementRef;
        this.renderer = renderer;
        this.nelType = '';
        this.nelPlain = false;
        this.nelRound = false;
        this.nelIcon = '';
        this.nelCircle = false;
        this.nelDisabled = false;
        this.nelLoading = false;
        this.nelSize = '';
    }
    set disabled(value) {
        if (value === '' || value) {
            this.nelDisabled = true;
        }
    }
    ngAfterViewInit() {
        this.insertSpan(this.elementRef.nativeElement.childNodes, this.renderer);
    }
    insertSpan(nodes, renderer) {
        nodes.forEach(node => {
            if (node.nodeName === '#text') {
                const span = renderer.createElement('span');
                const parent = renderer.parentNode(node);
                renderer.insertBefore(parent, span, node);
                renderer.appendChild(span, node);
            }
        });
    }
}
NelButtonComponent.decorators = [
    { type: Component, args: [{
                selector: 'button[nel-button]',
                template: `
    <i *ngIf="nelIcon" nel-icon [nelType]="nelIcon"></i>
    <i *ngIf="nelLoading" nel-icon [nelType]="'loading'"></i>
    <ng-content></ng-content>
  `,
                host: {
                    '[class.el-button]': `true`,
                    '[class.el-button--primary]': `nelType === 'primary'`,
                    '[class.el-button--success]': `nelType === 'success'`,
                    '[class.el-button--info]': `nelType === 'info'`,
                    '[class.el-button--warning]': `nelType === 'warning'`,
                    '[class.el-button--danger]': `nelType === 'danger'`,
                    '[class.is-plain]': `nelPlain`,
                    '[class.is-round]': `nelRound`,
                    '[class.is-circle]': `nelCircle`,
                    '[class.is-disabled]': `nelDisabled`,
                    '[class.el-button--text]': `nelType === 'text'`,
                    '[class.is-loading]': `nelLoading`,
                    '[class.el-button--medium]': `nelSize === 'medium'`,
                    '[class.el-button--small]': `nelSize === 'small'`,
                    '[class.el-button--mini]': `nelSize === 'mini'`,
                }
            },] }
];
NelButtonComponent.ctorParameters = () => [
    { type: ElementRef },
    { type: Renderer2 }
];
NelButtonComponent.propDecorators = {
    nelType: [{ type: Input }],
    nelPlain: [{ type: Input }],
    nelRound: [{ type: Input }],
    nelIcon: [{ type: Input }],
    nelCircle: [{ type: Input }],
    disabled: [{ type: Input }],
    nelLoading: [{ type: Input }],
    nelSize: [{ type: Input }]
};
__decorate([
    InputBoolean()
], NelButtonComponent.prototype, "nelPlain", void 0);
__decorate([
    InputBoolean()
], NelButtonComponent.prototype, "nelRound", void 0);
__decorate([
    InputBoolean()
], NelButtonComponent.prototype, "nelCircle", void 0);
__decorate([
    InputBoolean()
], NelButtonComponent.prototype, "nelLoading", void 0);

class NelButtonGroupComponent {
}
NelButtonGroupComponent.decorators = [
    { type: Component, args: [{
                selector: 'nel-button-group',
                template: `
    <ng-content></ng-content>
  `,
                host: {
                    class: 'el-button-group'
                }
            },] }
];

class NelButtonModule {
}
NelButtonModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    NelButtonComponent,
                    NelButtonGroupComponent
                ],
                exports: [
                    NelButtonComponent,
                    NelButtonGroupComponent
                ],
                imports: [
                    CommonModule,
                    NelIconModule
                ]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { NelButtonComponent, NelButtonGroupComponent, NelButtonModule };
//# sourceMappingURL=ng-element-ui-button.js.map
