import { Directive, Component, ChangeDetectionStrategy, forwardRef, ChangeDetectorRef, Input, ContentChild, TemplateRef, NgModule } from '@angular/core';
import { NG_VALUE_ACCESSOR } from '@angular/forms';
import { differenceInDays, getYear, getMonth, startOfWeek, addDays, format, getDate, startOfMonth, subMonths } from 'date-fns';
import { CommonModule } from '@angular/common';

class NelDateCellDirective {
}
NelDateCellDirective.decorators = [
    { type: Directive, args: [{
                selector: '[nelDateCell]'
            },] }
];

class NelCalendarComponent {
    constructor(cdf) {
        this.cdf = cdf;
        this.current = {
            year: 0,
            month: 0
        };
        this.calendarList = [];
        this.showButton = true;
        this.change = (value) => { };
    }
    set nelRange(val) {
        this.showButton = false;
        if (val && val.length !== 2) {
            throw Error('nelRang need [Date, Date]');
        }
        if (val[0].getDay() !== 1) {
            throw Error('First Date need is Monday');
        }
        if (val[1].getDay() !== 0) {
            throw Error('Second Date need is Sunday');
        }
        const days = differenceInDays(val[1], val[0]);
        if (days < 0) {
            throw Error('Second Date need after first Date');
        }
        const week = (days + 1) / 7;
        if (week > 8) {
            throw Error('The time span cannot exceed two months');
        }
        this.initCalendar(val[0], week);
    }
    get dateCell() {
        return (this.nelDateCell || this.nzDateCellChild);
    }
    initCalendar(date, weeks, selectedDay = null) {
        this.current = {
            year: getYear(date),
            month: getMonth(date) + 1
        };
        const firstDay = startOfWeek(date, { weekStartsOn: 1 });
        const calendarList = [];
        for (let i = 0; i < weeks; i++) {
            const weekItem = [];
            for (let j = 0; j < 7; j++) {
                const dateItem = addDays(firstDay, i * 7 + j);
                const today = this.data ? format(this.data, 'yyyy-MM-dd') === format(dateItem, 'yyyy-MM-dd') : false;
                const selected = !selectedDay ? today : (format(selectedDay, 'yyyy-MM-dd') === format(dateItem, 'yyyy-MM-dd'));
                weekItem.push({
                    text: getDate(dateItem),
                    day: format(dateItem, 'yyyy-MM-dd'),
                    date: dateItem,
                    isToday: today,
                    isSelected: selected,
                    type: this.current.month > getMonth(dateItem) + 1 ? 'next' : this.current.month < getMonth(dateItem) + 1 ? 'prev' : 'current'
                });
            }
            calendarList.push(weekItem);
        }
        this.calendarList = calendarList;
        this.cdf.markForCheck();
    }
    selectDay(dayItem) {
        this.temporaryDate = dayItem.date;
        this.data = dayItem.date;
        this.change(this.data);
        if (dayItem.type === 'current') {
            for (let i = 0; i < 6; i++) {
                for (let j = 0; j < 7; j++) {
                    this.calendarList[i][j].isSelected = false;
                }
            }
            dayItem.isSelected = true;
        }
        else {
            this.initCalendar(startOfMonth(dayItem.date), 6, dayItem.date);
        }
    }
    prevMonth() {
        const prev = subMonths(this.temporaryDate, 1);
        const prevMonthDays = this.getMonthDate(prev);
        const day = this.temporaryDate.getDate();
        if (prevMonthDays < day) {
            prev.setDate(prevMonthDays);
        }
        else {
            prev.setDate(day);
        }
        this.temporaryDate = prev;
        this.initCalendar(startOfMonth(this.temporaryDate), 6, prev);
    }
    getMonthDate(date) {
        const year = date.getFullYear();
        const month = date.getMonth() + 1;
        const d = new Date(year, month, 0);
        return d.getDate();
    }
    currentMonth() {
        this.temporaryDate = new Date();
        this.initCalendar(this.data, 6);
    }
    nextMonth() {
        const prev = subMonths(this.temporaryDate, -1);
        const prevMonthDays = this.getMonthDate(prev);
        const day = this.temporaryDate.getDate();
        if (prevMonthDays < day) {
            prev.setDate(prevMonthDays);
        }
        else {
            prev.setDate(day);
        }
        this.temporaryDate = prev;
        this.initCalendar(startOfMonth(this.temporaryDate), 6, this.temporaryDate);
    }
    writeValue(val) {
        if (val) {
            this.data = val;
            this.temporaryDate = val;
            this.initCalendar(startOfMonth(this.data), 6);
        }
    }
    registerOnChange(fn) {
        this.change = fn;
    }
    registerOnTouched(fn) { }
}
NelCalendarComponent.decorators = [
    { type: Component, args: [{
                selector: 'nel-calendar',
                template: "<div class=\"el-calendar\">\r\n  <div class=\"el-calendar__header\">\r\n    <div class=\"el-calendar__title\">{{current.year}} \u5E74 {{current.month}} \u6708</div>\r\n    <div *ngIf=\"showButton\" class=\"el-calendar__button-group\">\r\n      <div class=\"el-button-group\">\r\n        <button (click)=\"prevMonth()\" class=\"el-button el-button--default el-button--mini\" type=\"button\">\r\n          <span>\u4E0A\u4E2A\u6708</span>\r\n        </button>\r\n        <button (click)=\"currentMonth()\" class=\"el-button el-button--default el-button--mini\" type=\"button\">\r\n          <span>\u4ECA\u5929</span>\r\n        </button>\r\n        <button (click)=\"nextMonth()\" class=\"el-button el-button--default el-button--mini\" type=\"button\">\r\n          <span>\u4E0B\u4E2A\u6708</span>\r\n        </button>\r\n      </div>\r\n    </div>\r\n  </div>\r\n  <div class=\"el-calendar__body\">\r\n    <table class=\"el-calendar-table\" cellspacing=\"0\" cellpadding=\"0\">\r\n      <thead>\r\n        <th>\u5468\u4E00</th>\r\n        <th>\u5468\u4E8C</th>\r\n        <th>\u5468\u4E09</th>\r\n        <th>\u5468\u56DB</th>\r\n        <th>\u5468\u4E94</th>\r\n        <th>\u5468\u516D</th>\r\n        <th>\u5468\u65E5</th>\r\n      </thead>\r\n      <tbody>\r\n        <tr class=\"el-calendar-table__row\" *ngFor=\"let weekItem of calendarList\">\r\n          <td class=\"{{dayItem.type}}\" *ngFor=\"let dayItem of weekItem\" [class.is-today]=\"dayItem.isToday\"\r\n            [class.is-selected]=\"dayItem.isSelected\" (click)=\"selectDay(dayItem)\">\r\n            <div class=\"el-calendar-day\">\r\n              <ng-container *ngIf=\"nzDateCellChild; else spanTpl\">\r\n                <ng-container *ngTemplateOutlet=\"$any(nzDateCellChild); context: { $implicit: dayItem }\">\r\n                </ng-container>\r\n              </ng-container>\r\n              <ng-template #spanTpl>\r\n                <span>{{dayItem.text}}</span>\r\n              </ng-template>\r\n            </div>\r\n          </td>\r\n        </tr>\r\n      </tbody>\r\n    </table>\r\n  </div>\r\n</div>\r\n",
                changeDetection: ChangeDetectionStrategy.OnPush,
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        useExisting: forwardRef(() => NelCalendarComponent),
                        multi: true
                    }
                ]
            },] }
];
NelCalendarComponent.ctorParameters = () => [
    { type: ChangeDetectorRef }
];
NelCalendarComponent.propDecorators = {
    nelRange: [{ type: Input }],
    nelDateCell: [{ type: Input }],
    nzDateCellChild: [{ type: ContentChild, args: [NelDateCellDirective, { static: false, read: TemplateRef },] }]
};

class NelCalendarModule {
}
NelCalendarModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    NelCalendarComponent,
                    NelDateCellDirective
                ],
                exports: [
                    NelCalendarComponent,
                    NelDateCellDirective
                ],
                imports: [
                    CommonModule
                ]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { NelCalendarComponent, NelCalendarModule, NelDateCellDirective };
//# sourceMappingURL=ng-element-ui-calendar.js.map
