import { Component, ChangeDetectionStrategy, Input, ContentChildren, ViewChild, ViewChildren, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { OverlayModule } from '@angular/cdk/overlay';
import { NelButtonModule } from 'ng-element-ui/button';

class NelCarouselItemComponent {
    constructor() {
        this.left = '';
        this.top = '';
    }
}
NelCarouselItemComponent.decorators = [
    { type: Component, args: [{
                selector: 'nel-carousel-item',
                template: "<ng-content></ng-content>\r\n",
                changeDetection: ChangeDetectionStrategy.OnPush,
                host: {
                    class: 'el-carousel__item',
                    '[style.left]': 'left',
                    '[style.top]': 'top',
                }
            },] }
];

class NelCarouselComponent {
    constructor() {
        this.hover = false;
        this.width = 0;
        this.height = 0;
        this.active = -1;
        this.CARD_SCALE = 0.83;
        this.nelArrow = 'hover';
        this.nelDirection = 'horizontal';
    }
    ngOnDestroy() {
    }
    ngAfterViewInit() {
        const client = this.containerEle.nativeElement.getBoundingClientRect();
        this.width = client.width;
        this.height = client.height;
        if (this.nelDirection === 'horizontal') {
            this.itemContainerEle.nativeElement.style.width = (this.items.length * 100) + '%';
        }
        else {
            this.itemContainerEle.nativeElement.style.height = (this.items.length * 100) + '%';
        }
        setTimeout(() => {
            this.changeActive(0, true);
        }, 0);
    }
    mouseEnter() {
        this.hover = true;
    }
    mouseLeave() {
        this.hover = false;
    }
    prev() {
        let active = this.active - 1;
        if (active < 0) {
            active = this.items.length - 1;
            this.items.last.left = `${-this.items.length * this.width}px`;
            // return;
        }
        this.changeActive(active, false);
    }
    next() {
        let active = this.active + 1;
        if (active >= this.items.length) {
            active = 0;
            this.items.first.left = `${this.items.length * this.width}px`;
        }
        this.changeActive(active, false);
    }
    indicatorSelect(index) {
        if (this.nelTrigger !== 'click') {
            this.changeActive(index, true);
        }
    }
    selectItem(index) {
        this.changeActive(index, true);
    }
    changeActive(active, indicator) {
        if (this.active === active) {
            return;
        }
        if (this.active !== -1) {
            if (this.nelDirection === 'horizontal') {
                if (!indicator) {
                    let difference = active;
                    if (active === 0) {
                        // 从last切换到first
                        if (this.active === this.items.length - 1) {
                            difference = this.items.length;
                        }
                    }
                    else if (active === this.items.length - 1) {
                        // 从first切换到last
                        if (this.active === 0) {
                            difference = -1;
                        }
                    }
                    this.itemContainerEle.nativeElement.style.transition = 'transform .3s';
                    this.itemContainerEle.nativeElement.style.transform = `translate3d(${-difference * this.width}px, 0px, 0px)`;
                    // 将first或者last的left重置为空
                    setTimeout(() => {
                        if (active === 0) {
                            this.itemContainerEle.nativeElement.style.transition = '';
                            this.items.first.left = '';
                            this.itemContainerEle.nativeElement.style.transform = 'translate3d(0px, 0px, 0px)';
                        }
                        else if (active === this.items.length - 1) {
                            this.itemContainerEle.nativeElement.style.transition = '';
                            this.items.last.left = '';
                            this.itemContainerEle.nativeElement.style.transform = `translate3d(${-(this.items.length - 1) * this.width}px, 0px, 0px)`;
                        }
                    }, 300);
                }
                else {
                    this.itemContainerEle.nativeElement.style.transition = 'transform .3s';
                    this.itemContainerEle.nativeElement.style.transform = `translate3d(${-active * this.width}px, 0px, 0px)`;
                }
            }
            else {
                if (!indicator) {
                    let difference = active;
                    if (active === 0) {
                        // 从last切换到first
                        if (this.active === this.items.length - 1) {
                            difference = this.items.length;
                        }
                    }
                    else if (active === this.items.length - 1) {
                        // 从first切换到last
                        if (this.active === 0) {
                            difference = -1;
                        }
                    }
                    this.itemContainerEle.nativeElement.style.transition = 'transform .3s';
                    this.itemContainerEle.nativeElement.style.transform = `translate3d(0px, ${-difference * this.height}px, 0px)`;
                    // 将first或者last的left重置为空
                    setTimeout(() => {
                        if (active === 0) {
                            this.itemContainerEle.nativeElement.style.transition = '';
                            this.items.first.top = '';
                            this.itemContainerEle.nativeElement.style.transform = 'translate3d(0px, 0px, 0px)';
                        }
                        else if (active === this.items.length - 1) {
                            this.itemContainerEle.nativeElement.style.transition = '';
                            this.items.last.left = '';
                            this.itemContainerEle.nativeElement.style.transform = `translate3d(0px, ${-(this.items.length - 1) * this.height}px, 0px)`;
                        }
                    }, 300);
                }
                else {
                    this.itemContainerEle.nativeElement.style.transition = 'transform .3s';
                    this.itemContainerEle.nativeElement.style.transform = `translate3d(0px, ${-active * this.height}px, 0px)`;
                }
            }
        }
        this.active = active;
    }
}
NelCarouselComponent.decorators = [
    { type: Component, args: [{
                selector: 'nel-carousel',
                template: "<div class=\"el-carousel el-carousel--{{nelDirection}}\" (mouseenter)=\"mouseEnter()\" (mouseleave)=\"mouseLeave()\">\r\n  <div #containerEle class=\"el-carousel__container\" [style.height]=\"nelHeight\">\r\n    <button *ngIf=\"nelDirection === 'horizontal' && nelArrow !== 'never'\" (click)=\"prev()\" type=\"button\"\r\n      class=\"el-carousel__arrow el-carousel__arrow--left\"\r\n      [style.display]=\"nelArrow === 'always' || hover ? '' : 'none'\">\r\n      <i class=\"el-icon-arrow-left\"></i>\r\n    </button>\r\n    <button *ngIf=\"nelDirection === 'horizontal' && nelArrow !== 'never'\" (click)=\"next()\" type=\"button\"\r\n      class=\"el-carousel__arrow el-carousel__arrow--right\"\r\n      [style.display]=\"nelArrow === 'always' || hover ? '' : 'none'\">\r\n      <i class=\"el-icon-arrow-right\"></i>\r\n    </button>\r\n    <div class=\"el-carousel__item__wrapper\">\r\n      <div #itemContainerEle class=\"el-carousel__item__container\"\r\n        [style.flex-direction]=\"nelDirection == 'vertical' ? 'column' : ''\">\r\n        <ng-content></ng-content>\r\n      </div>\r\n    </div>\r\n  </div>\r\n  <ul class=\"el-carousel__indicators el-carousel__indicators--{{nelDirection}}\"\r\n    [class.el-carousel__indicators--outside]=\"nelIndicatorPosition == 'outside'\">\r\n    <li #indicatorEle (mouseenter)=\"indicatorSelect(index)\" (click)=\"selectItem(index)\"\r\n      *ngFor=\"let item of items; let index=index;\"\r\n      class=\"el-carousel__indicator el-carousel__indicator--{{nelDirection}}\" [class.is-active]=\"index == active\">\r\n      <button class=\"el-carousel__button\"></button>\r\n    </li>\r\n  </ul>\r\n</div>\r\n",
                changeDetection: ChangeDetectionStrategy.OnPush
            },] }
];
NelCarouselComponent.ctorParameters = () => [];
NelCarouselComponent.propDecorators = {
    nelHeight: [{ type: Input }],
    nelTrigger: [{ type: Input }],
    nelIndicatorPosition: [{ type: Input }],
    nelArrow: [{ type: Input }],
    nelType: [{ type: Input }],
    nelDirection: [{ type: Input }],
    items: [{ type: ContentChildren, args: [NelCarouselItemComponent, { descendants: false },] }],
    containerEle: [{ type: ViewChild, args: ['containerEle', { static: false },] }],
    itemContainerEle: [{ type: ViewChild, args: ['itemContainerEle', { static: false },] }],
    indicatorList: [{ type: ViewChildren, args: ['indicatorEle',] }]
};

class NelCarouselModule {
}
NelCarouselModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    NelCarouselComponent,
                    NelCarouselItemComponent
                ],
                exports: [
                    NelCarouselComponent,
                    NelCarouselItemComponent
                ],
                imports: [
                    CommonModule,
                    OverlayModule,
                    NelButtonModule
                ]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { NelCarouselComponent, NelCarouselItemComponent, NelCarouselModule };
//# sourceMappingURL=ng-element-ui-carousel.js.map
