import { __decorate } from 'tslib';
import { Injectable, Component, ChangeDetectionStrategy, forwardRef, Optional, ChangeDetectorRef, Input, ContentChildren, NgModule } from '@angular/core';
import { NG_VALUE_ACCESSOR } from '@angular/forms';
import { InputBoolean } from 'ng-element-ui/core/utils';
import { ReplaySubject } from 'rxjs';

class NelCheckboxService {
    constructor() {
        this.selected$ = new ReplaySubject();
    }
    select(val) {
        this.selected$.next(val);
    }
}
NelCheckboxService.decorators = [
    { type: Injectable }
];

class NelCheckboxComponent {
    constructor(checkbox, cdr) {
        this.checkbox = checkbox;
        this.cdr = cdr;
        this.isChecked = false;
        this.nelDisabled = false;
        this.nelIndeterminate = false;
        this.change = (val) => { };
    }
    onHostClick(event) {
        event.stopPropagation();
        event.preventDefault();
        if (!this.nelDisabled) {
            this.isChecked = !this.isChecked;
            this.change(this.isChecked);
            if (this.checkbox) {
                this.checkbox.select({ value: this.nelValue, checked: this.isChecked });
            }
        }
    }
    changeView() {
        this.cdr.detectChanges();
    }
    writeValue(val) {
        if (val !== null) {
            this.isChecked = val ? true : false;
            this.cdr.detectChanges();
        }
    }
    registerOnChange(fn) {
        this.change = fn;
    }
    registerOnTouched(fn) { }
}
NelCheckboxComponent.decorators = [
    { type: Component, args: [{
                selector: '[nel-checkbox]',
                template: "<span class=\"el-checkbox__input\" [class.is-checked]=\"isChecked\" [class.is-disabled]=\"nelDisabled\"\r\n  [class.is-indeterminate]=\"nelIndeterminate\" tabindex=\"false\" role=\"false\">\r\n  <span class=\"el-checkbox__inner\"></span>\r\n  <input class=\"el-checkbox__original\" type=\"checkbox\" value=\"false\">\r\n</span>\r\n<span class=\"el-checkbox__label\">\u5907\u9009\u9879</span>\r\n",
                changeDetection: ChangeDetectionStrategy.OnPush,
                host: {
                    class: 'el-checkbox',
                    '[class.is-checked]': 'isChecked',
                    '[class.is-disabled]': 'nelDisabled',
                    '(click)': 'onHostClick($event)'
                },
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        useExisting: forwardRef(() => NelCheckboxComponent),
                        multi: true
                    }
                ]
            },] }
];
NelCheckboxComponent.ctorParameters = () => [
    { type: NelCheckboxService, decorators: [{ type: Optional }] },
    { type: ChangeDetectorRef }
];
NelCheckboxComponent.propDecorators = {
    nelValue: [{ type: Input }],
    nelDisabled: [{ type: Input }],
    nelIndeterminate: [{ type: Input }]
};
__decorate([
    InputBoolean()
], NelCheckboxComponent.prototype, "nelDisabled", void 0);

class NelCheckboxGroupComponent {
    constructor(checkbox) {
        this.checkbox = checkbox;
        this.change = (val) => { };
        this.checkbox.selected$.subscribe(val => {
            if (val.checked) {
                this.data.push(val.value);
            }
            else {
                const itemIndex = this.data.findIndex((valItem) => valItem === val.value);
                if (itemIndex > -1) {
                    this.data.splice(itemIndex, 1);
                }
            }
            this.change(this.data);
        });
    }
    writeValue(val) {
        console.log(val);
        if (val) {
            this.data = val;
            this.checkboxList.forEach(item => {
                const isItem = this.data.find((selectedItem) => selectedItem === item.nelValue);
                if (isItem) {
                    item.isChecked = true;
                }
                else {
                    item.isChecked = false;
                }
                item.changeView();
            });
        }
    }
    registerOnChange(fn) {
        this.change = fn;
    }
    registerOnTouched(fn) { }
}
NelCheckboxGroupComponent.decorators = [
    { type: Component, args: [{
                selector: 'nel-checkbox-group',
                template: "<ng-content></ng-content>\r\n",
                changeDetection: ChangeDetectionStrategy.OnPush,
                providers: [
                    NelCheckboxService,
                    {
                        provide: NG_VALUE_ACCESSOR,
                        useExisting: forwardRef(() => NelCheckboxGroupComponent),
                        multi: true
                    }
                ],
                host: {
                    class: 'el-checkbox-group'
                }
            },] }
];
NelCheckboxGroupComponent.ctorParameters = () => [
    { type: NelCheckboxService }
];
NelCheckboxGroupComponent.propDecorators = {
    checkboxList: [{ type: ContentChildren, args: [NelCheckboxComponent, { descendants: false },] }]
};

class NelCheckboxModule {
}
NelCheckboxModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    NelCheckboxComponent,
                    NelCheckboxGroupComponent
                ],
                exports: [
                    NelCheckboxComponent,
                    NelCheckboxGroupComponent
                ]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { NelCheckboxComponent, NelCheckboxGroupComponent, NelCheckboxModule, NelCheckboxService as ɵa };
//# sourceMappingURL=ng-element-ui-checkbox.js.map
