import { __decorate } from 'tslib';
import { Component, ChangeDetectionStrategy, forwardRef, Input, Optional, ChangeDetectorRef, NgModule } from '@angular/core';
import { NG_VALUE_ACCESSOR } from '@angular/forms';
import { InputBoolean } from 'ng-element-ui/core/utils';
import { collapseMotion } from 'ng-element-ui/core/animation';
import { NelIconModule } from 'ng-element-ui/icon';
import { NelOutletModule } from 'ng-element-ui/core/outlet';

class NelCollapseComponent {
    constructor() {
        this.nelAccordion = false;
        this.itemList = new Map();
        this.change = (value) => { };
    }
    changeItemActive(nelName, expanded) {
        if (this.nelAccordion) {
            this.itemList.forEach(item => {
                if (item.nelName !== nelName) {
                    item.updateActiveStatus(false);
                }
            });
            this.data = expanded ? nelName.toString() : null;
        }
        else {
            if (expanded) {
                if (this.data instanceof Array) {
                    this.data.push(nelName.toString());
                }
                else {
                    this.data = [nelName.toString()];
                }
            }
            else {
                if (this.data instanceof Array) {
                    this.data.splice(this.data.indexOf(nelName.toString()), 1);
                    if (this.data.length === 0) {
                        this.data = null;
                    }
                }
            }
        }
        this.change(this.data);
    }
    ngAfterContentInit() {
    }
    writeValue(val) {
        if (val) {
            this.data = val;
            this.itemList.forEach(item => {
                if (typeof val === 'string') {
                    if (val === item.nelName.toString()) {
                        item.updateActiveStatus(true);
                    }
                    else {
                        item.updateActiveStatus(false);
                    }
                }
                else {
                    if (val.indexOf(item.nelName.toString()) > -1) {
                        item.updateActiveStatus(true);
                    }
                    else {
                        item.updateActiveStatus(false);
                    }
                }
            });
        }
    }
    registerOnChange(fn) {
        this.change = fn;
    }
    registerOnTouched(fn) { }
}
NelCollapseComponent.decorators = [
    { type: Component, args: [{
                selector: 'nel-collapse',
                template: "<div class=\"el-collapse\">\r\n  <ng-content></ng-content>\r\n</div>\r\n",
                changeDetection: ChangeDetectionStrategy.OnPush,
                providers: [{
                        provide: NG_VALUE_ACCESSOR,
                        useExisting: forwardRef(() => NelCollapseComponent),
                        multi: true
                    }]
            },] }
];
NelCollapseComponent.propDecorators = {
    nelAccordion: [{ type: Input }]
};
__decorate([
    InputBoolean()
], NelCollapseComponent.prototype, "nelAccordion", void 0);

class NelCollapseItemComponent {
    constructor(root, cdr) {
        this.root = root;
        this.cdr = cdr;
        this.nelDisabled = false;
        this.nelName = Math.random().toString(16).substr(2, 8);
        this.expanded = false;
    }
    ngOnInit() {
        this.root.itemList.set(this.nelName, this);
    }
    updateActiveStatus(val) {
        this.expanded = val;
        this.cdr.detectChanges();
    }
    change() {
        if (!this.nelDisabled) {
            this.expanded = !this.expanded;
            this.root.changeItemActive(this.nelName, this.expanded);
        }
    }
}
NelCollapseItemComponent.decorators = [
    { type: Component, args: [{
                selector: 'nel-collapse-item',
                template: "<div class=\"el-collapse-item\" [class.is-disabled]=\"nelDisabled\">\r\n  <div role=\"tab\" (click)=\"change()\">\r\n    <div class=\"el-collapse-item__header\" role=\"button\" tabindex=\"0\" [class.is-active]=\"expanded\">\r\n      <ng-container *stringTemplate=\"nelTitle\">{{nelTitle}}</ng-container>\r\n      <i nel-icon [nelType]=\"'arrow-right'\" class=\"el-collapse-item__arrow\" [class.is-active]=\"expanded\"></i>\r\n    </div>\r\n  </div>\r\n  <div class=\"el-collapse-item__wrap\" role=\"tabpanel\" [@collapseMotion]=\"expanded ? 'expanded' : 'collapsed'\">\r\n    <div class=\"el-collapse-item__content\">\r\n      <ng-content></ng-content>\r\n    </div>\r\n  </div>\r\n</div>\r\n",
                changeDetection: ChangeDetectionStrategy.OnPush,
                animations: [collapseMotion]
            },] }
];
NelCollapseItemComponent.ctorParameters = () => [
    { type: NelCollapseComponent, decorators: [{ type: Optional }] },
    { type: ChangeDetectorRef }
];
NelCollapseItemComponent.propDecorators = {
    nelTitle: [{ type: Input }],
    nelDisabled: [{ type: Input }],
    nelName: [{ type: Input }]
};
__decorate([
    InputBoolean()
], NelCollapseItemComponent.prototype, "nelDisabled", void 0);

class NelCollapseModule {
}
NelCollapseModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    NelCollapseComponent,
                    NelCollapseItemComponent
                ],
                exports: [
                    NelCollapseComponent,
                    NelCollapseItemComponent
                ],
                imports: [
                    NelIconModule,
                    NelOutletModule
                ]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { NelCollapseComponent, NelCollapseItemComponent, NelCollapseModule };
//# sourceMappingURL=ng-element-ui-collapse.js.map
