import { trigger, transition, style, animate, state, group, query, animateChild } from '@angular/animations';

const fadeMotion = trigger('fadeMotion', [
    transition(':enter', [
        style({ opacity: 0 }),
        animate(300, style({ opacity: 1 }))
    ]),
    transition(':leave', [
        animate(300, style({ opacity: 0 }))
    ])
]);

const collapseMotion = trigger('collapseMotion', [
    state('expanded', style({
        display: 'block',
        opacity: '1'
    })),
    state('collapsed', style({
        display: 'none',
        height: '0',
        opacity: '0'
    })),
    transition('expanded <=> collapsed', [
        style({ display: 'block' }),
        animate('300ms')
    ])
]);

const zoomMotion = trigger('zoomMotion', [
    transition(':enter', [
        style({ opacity: 0, transform: 'scaleX(0)' }),
        animate(300, style({ opacity: 1, transform: 'scaleX(1)' }))
    ]),
    transition(':leave', [
        animate(300, style({ opacity: 0, transform: 'scaleX(0)' }))
    ])
]);
const zoomTopMotion = trigger('zoomTopMotion', [
    transition(':enter', [
        style({ transform: 'scaleY(0)', 'transform-origin': 'center top' }),
        animate(300, style({ transform: 'scaleY(1)', 'transform-origin': 'center bottom' }))
    ]),
    transition(':leave', [
        animate(300, style({ transform: 'scaleY(0)', 'transform-origin': 'center top' }))
    ])
]);
const zoomBottomMotion = trigger('zoomBottomMotion', [
    transition(':enter', [
        style({ opacity: 0, transform: 'scaleY(0)', 'transform-origin': 'center bottom' }),
        animate(300, style({ opacity: 1, transform: 'scaleY(1)', 'transform-origin': 'center top' }))
    ]),
    transition(':leave', [
        animate(300, style({ opacity: 0, transform: 'scaleY(0)', 'transform-origin': 'center bottom' }))
    ])
]);

const drawerMotion = trigger('drawerMotion', [
    transition(':enter', [
        style({ opacity: 0, overflow: 'hidden' }),
        group([
            query('@drawerDialogMotion', [animateChild()]),
            animate(300, style({ opacity: 1 }))
        ])
    ]),
    transition(':leave', [
        style({ overflow: 'hidden' }),
        group([
            query('@drawerDialogMotion', [animateChild()]),
            animate(300, style({ opacity: 0 }))
        ])
    ])
]);
const drawerDialogMotion = trigger('drawerDialogMotion', [
    transition('void => rtl', [
        style({ transform: 'translate(100%, 0px)' }),
        animate(300, style({ transform: 'translate(0px, 0px)' }))
    ]),
    transition('rtl => void', [
        style({ transform: 'translate(0px, 0px)' }),
        animate(300, style({ transform: 'translate(100%, 0px)' }))
    ]),
    transition('void => ltr', [
        style({ transform: 'translate(-100%, 0px)' }),
        animate(300, style({ transform: 'translate(0px, 0px)' }))
    ]),
    transition('ltr => void', [
        style({ transform: 'translate(0px, 0px)' }),
        animate(300, style({ transform: 'translate(-100%, 0px)' }))
    ]),
    transition('void => ttb', [
        style({ transform: 'translate(0px, -100%)' }),
        animate(300, style({ transform: 'translate(0px, 0px)' }))
    ]),
    transition('ttb => void', [
        style({ transform: 'translate(0px, 0px)' }),
        animate(300, style({ transform: 'translate(0px, -100%)' }))
    ]),
    transition('void => btt', [
        style({ transform: 'translate(0px, 100%)' }),
        animate(300, style({ transform: 'translate(0px, 0px)' }))
    ]),
    transition('btt => void', [
        style({ transform: 'translate(0px, 0px)' }),
        animate(300, style({ transform: 'translate(0px, 100%)' }))
    ])
]);

const modalMotion = trigger('modalMotion', [
    transition(':enter', [
        style({
            opacity: 0,
            transform: 'translate3d(0, -20px, 0)'
        }),
        animate(300, style({
            opacity: 1,
            transform: 'translate3d(0, 0, 0)'
        }))
    ]),
    transition(':leave', [
        style({
            opacity: 1,
            transform: 'translate3d(0, 0, 0)'
        }),
        animate(300, style({
            opacity: 0,
            transform: 'translate3d(0, -20px, 0)'
        }))
    ]),
]);

const messageMotion = trigger('messageMotion', [
    state('done', style({
        opacity: 1,
        transform: 'translate(-50%, 0)'
    })),
    transition(':enter', [
        style({
            opacity: 0,
            transform: 'translate(-50%, -100%)'
        }),
        animate(300, style({
            opacity: 1,
            transform: 'translate(-50%, 0)'
        }))
    ]),
    transition('start => done', [
        animate(300, style({
            opacity: 0,
            transform: 'translate(-50%, -100%)'
        }))
    ])
]);

const notificationMotion = trigger('notificationMotion', [
    transition('void => rightInto', [
        style({
            opacity: 0,
            transform: 'translate(100%, 0)'
        }),
        animate(300, style({
            opacity: 1,
            transform: 'translate(0, 0)'
        }))
    ]),
    transition('rightInto => leave', [
        style({
            opacity: 1,
            transform: 'translate(0, 0)'
        }),
        animate(300, style({
            opacity: 0,
            transform: 'translate(100%, 0)'
        }))
    ]),
    transition('void => leftInto', [
        style({
            opacity: 0,
            transform: 'translate(-100%, 0)'
        }),
        animate(300, style({
            opacity: 1,
            transform: 'translate(0, 0)'
        }))
    ]),
    transition('leftInto => leave', [
        style({
            opacity: 1,
            transform: 'translate(0, 0)'
        }),
        animate(300, style({
            opacity: 0,
            transform: 'translate(-100%, 0)'
        }))
    ]),
]);

const messageBoxMotion = trigger('messageBoxMotion', [
    transition('void => into', [
        style({
            opacity: 0,
            transform: 'translate(0, -20px)'
        }),
        animate(300, style({
            opacity: 1,
            transform: 'translate(0, 0)'
        }))
    ]),
    transition('into => leave', [
        style({
            opacity: 1,
            transform: 'translate(0, 0)'
        }),
        animate(300, style({
            opacity: 0,
            transform: 'translate(0, -20px)'
        }))
    ])
]);

const loadingMotion = trigger('loadingMotion', [
    transition(':enter', [
        style({ opacity: 0 }),
        animate(300, style({ opacity: 1 }))
    ]),
    transition(':leave', [
        animate(300, style({ opacity: 0 }))
    ])
]);

const dropdownMotion = trigger('dropdownMotion', [
    transition('void => into, leave => into', [
        style({
            opacity: 0,
            transform: 'scaleY(0)',
            'transform-origin': 'center top'
        }),
        animate(300, style({
            opacity: 1,
            transform: 'scaleY(1)',
            'transform-origin': 'center top'
        }))
    ]),
    transition(':leave', [
        style({
            opacity: 1,
            transform: 'scaleY(1)',
            'transform-origin': 'center top'
        }),
        animate(300, style({
            opacity: 0,
            transform: 'scaleY(0)',
            'transform-origin': 'center top'
        }))
    ])
]);

/**
 * Generated bundle index. Do not edit.
 */

export { collapseMotion, drawerDialogMotion, drawerMotion, dropdownMotion, fadeMotion, loadingMotion, messageBoxMotion, messageMotion, modalMotion, notificationMotion, zoomBottomMotion, zoomMotion, zoomTopMotion };
//# sourceMappingURL=ng-element-ui-core-animation.js.map
