import { coerceBooleanProperty } from '@angular/cdk/coercion';

const getScrollContainer = (el, isVertical) => {
    let parent = el;
    while (parent) {
        if ([window, document, document.documentElement].includes(parent)) {
            return window.document.body;
        }
        if (isScroll(parent, isVertical)) {
            return parent;
        }
        parent = parent.parentNode;
    }
    return parent;
};
const isScroll = (el, isVertical) => {
    const determinedDirection = isVertical === null || isVertical === undefined;
    const overflow = determinedDirection
        ? getStyle(el, 'overflow')
        : isVertical
            ? getStyle(el, 'overflow-y')
            : getStyle(el, 'overflow-x');
    if (overflow) {
        return overflow.match(/(scroll|auto)/);
    }
    else {
        return null;
    }
};
const getStyle = function (element, styleName) {
    if (!element || !styleName) {
        return null;
    }
    // styleName = camelize(styleName)
    if (styleName === 'float') {
        styleName = 'cssFloat';
    }
    try {
        const style = element.style[styleName];
        if (style)
            return style;
        const computed = getComputedStyle(element, '');
        return computed ? computed[styleName] : '';
    }
    catch (e) {
        return element.style[styleName];
    }
};

function toBoolean(value) {
    return coerceBooleanProperty(value);
}
function propDecoratorFactory(name, fallback) {
    function propDecorator(target, propName, originalDescriptor) {
        const privatePropName = `$$__${propName}`;
        if (Object.prototype.hasOwnProperty.call(target, privatePropName)) {
            console.warn(`The prop "${privatePropName}" is already exist, it will be overrided by ${name} decorator.`);
        }
        Object.defineProperty(target, privatePropName, {
            configurable: true,
            writable: true
        });
        return {
            get() {
                return originalDescriptor && originalDescriptor.get
                    ? originalDescriptor.get.bind(this)()
                    : this[privatePropName];
            },
            set(value) {
                if (originalDescriptor && originalDescriptor.set) {
                    originalDescriptor.set.bind(this)(fallback(value));
                }
                this[privatePropName] = fallback(value);
            }
        };
    }
    return propDecorator;
}
function InputBoolean() {
    return propDecoratorFactory('InputBoolean', toBoolean);
}

/**
 * Generated bundle index. Do not edit.
 */

export { InputBoolean, getScrollContainer, getStyle, isScroll, toBoolean };
//# sourceMappingURL=ng-element-ui-core-utils.js.map
