import { __decorate } from 'tslib';
import { Component, Input, ViewChild, TemplateRef, ContentChildren, NgModule } from '@angular/core';
import { InputBoolean } from 'ng-element-ui/core/utils';
import { CommonModule } from '@angular/common';
import { NelOutletModule } from 'ng-element-ui/core/outlet';

class NelDescriptionsItemComponent {
}
NelDescriptionsItemComponent.decorators = [
    { type: Component, args: [{
                selector: 'nel-descriptions-item',
                template: "<ng-template>\r\n  <ng-content></ng-content>\r\n</ng-template>\r\n"
            },] }
];
NelDescriptionsItemComponent.propDecorators = {
    nelLabel: [{ type: Input }],
    content: [{ type: ViewChild, args: [TemplateRef, { static: true },] }]
};

class NelDescriptionsComponent {
    constructor() {
        this.nelBorder = false;
        this.nelColumn = 3;
        this.nelDirection = 'horizontal';
        this.list = [];
        this.itemList = [];
    }
    ngAfterContentInit() {
        if (this.nelDirection === 'horizontal') {
            const remainder = this.items.length % this.nelColumn;
            const trLength = Math.ceil(this.items.length / this.nelColumn);
            if (this.nelBorder) {
                let lastColspan = 1;
                for (let i = 1; i < this.nelColumn; i++) {
                    lastColspan = (this.nelColumn - i) * 2 + 1;
                }
                const trItem = [];
                for (let i = 0; i < trLength; i++) {
                    const tdItem = [];
                    for (let j = 0; j < this.nelColumn; j++) {
                        const item = this.items.get(i * this.nelColumn + j);
                        if (item) {
                            tdItem.push({
                                type: 'label',
                                label: item.nelLabel,
                                content: null,
                                colspan: 1
                            });
                            tdItem.push({
                                type: 'content',
                                label: undefined,
                                content: item.content,
                                colspan: i * this.nelColumn + j === this.items.length - 1 ? lastColspan : 1
                            });
                        }
                    }
                    trItem.push(tdItem);
                }
                this.itemList = trItem;
            }
            else {
                let lastColspan = 1;
                for (let i = 1; i < this.nelColumn; i++) {
                    lastColspan = this.nelColumn - i + 1;
                }
                const trItem = [];
                for (let i = 0; i < trLength; i++) {
                    const tdItem = [];
                    for (let j = 0; j < this.nelColumn; j++) {
                        const item = this.items.get(i * this.nelColumn + j);
                        if (item) {
                            tdItem.push({
                                type: '',
                                label: item.nelLabel,
                                content: item.content,
                                colspan: i * this.nelColumn + j === this.items.length - 1 ? lastColspan : 1
                            });
                        }
                    }
                    trItem.push(tdItem);
                }
                this.itemList = trItem;
            }
        }
        else {
            const remainder = this.items.length % this.nelColumn;
            const trLength = Math.ceil(this.items.length / this.nelColumn);
            let lastColspan = 1;
            for (let i = 1; i < this.nelColumn; i++) {
                lastColspan = this.nelColumn - i + 1;
            }
            const trItem = [];
            for (let i = 0; i < trLength; i++) {
                const labelItem = [];
                const contentItem = [];
                for (let j = 0; j < this.nelColumn; j++) {
                    const item = this.items.get(i * this.nelColumn + j);
                    if (item) {
                        labelItem.push({
                            type: 'label',
                            label: item.nelLabel,
                            content: null,
                            colspan: i * this.nelColumn + j === this.items.length - 1 ? lastColspan : 1
                        });
                        contentItem.push({
                            type: 'content',
                            label: undefined,
                            content: item.content,
                            colspan: i * this.nelColumn + j === this.items.length - 1 ? lastColspan : 1
                        });
                    }
                }
                trItem.push(labelItem);
                trItem.push(contentItem);
            }
            this.itemList = trItem;
        }
    }
}
NelDescriptionsComponent.decorators = [
    { type: Component, args: [{
                selector: 'nel-descriptions',
                template: "<div class=\"el-descriptions__header\">\r\n  <div class=\"el-descriptions__title\">{{nelTitle}}</div>\r\n  <div class=\"el-descriptions__extra\">\r\n    <ng-container *ngIf=\"nelExtra\">\r\n      <ng-container *stringTemplate=\"nelExtra\">{{nelExtra}}</ng-container>\r\n    </ng-container>\r\n  </div>\r\n</div>\r\n<div class=\"el-descriptions__body\">\r\n  <table [class.is-bordered]=\"nelBorder\" [class.el-descriptions--medium]=\"nelSize == 'medium'\"\r\n    [class.el-descriptions--small]=\"nelSize == 'small'\" [class.el-descriptions--mini]=\"nelSize == 'mini'\">\r\n    <tbody>\r\n      <ng-container *ngFor=\"let trItem of itemList\">\r\n        <ng-container *ngIf=\"nelDirection == 'horizontal'\">\r\n          <tr *ngIf=\"nelBorder; else trTpl\">\r\n            <ng-container *ngFor=\"let item of trItem\">\r\n              <td *ngIf=\"item.type == 'label'; else tdTpl\" [attr.colspan]=\"item.colspan\"\r\n                class=\"el-descriptions__label is-bordered-label\">\r\n                <ng-container *ngIf=\"item.label\">\r\n                  <ng-container *stringTemplate=\"item.label\">{{item.label}}</ng-container>\r\n                </ng-container>\r\n                <span class=\"el-descriptions__content\">\r\n                  <ng-container *ngTemplateOutlet=\"item.content\"></ng-container>\r\n                </span>\r\n              </td>\r\n              <ng-template #tdTpl>\r\n                <td [attr.colspan]=\"item.colspan\" class=\"el-descriptions__content\">\r\n                  <ng-container *ngTemplateOutlet=\"item.content\"></ng-container>\r\n                </td>\r\n              </ng-template>\r\n            </ng-container>\r\n          </tr>\r\n          <ng-template #trTpl>\r\n            <tr>\r\n              <td [attr.colspan]=\"item.colspan\" *ngFor=\"let item of trItem\">\r\n                <span class=\"el-descriptions__label\" [class.is-bordered-label]=\"nelBorder\">\r\n                  <ng-container *ngIf=\"item.label\">\r\n                    <ng-container *stringTemplate=\"item.label\">{{item.label}}</ng-container>\r\n                  </ng-container>\r\n                </span>\r\n                <span class=\"el-descriptions__content\">\r\n                  <ng-container *ngTemplateOutlet=\"item.content\"></ng-container>\r\n                </span>\r\n              </td>\r\n            </tr>\r\n          </ng-template>\r\n        </ng-container>\r\n        <ng-container *ngIf=\"nelDirection == 'vertical'\">\r\n          <tr>\r\n            <ng-container *ngFor=\"let item of trItem\">\r\n              <td *ngIf=\"item.type == 'label'; else tdTpl\" [attr.colspan]=\"item.colspan\" class=\"el-descriptions__label\"\r\n                [class.is-bordered-label]=\"nelBorder\">\r\n                <ng-container *ngIf=\"item.label\">\r\n                  <ng-container *stringTemplate=\"item.label\">{{item.label}}</ng-container>\r\n                </ng-container>\r\n                <span class=\"el-descriptions__content\">\r\n                  <ng-container *ngTemplateOutlet=\"item.content\"></ng-container>\r\n                </span>\r\n              </td>\r\n              <ng-template #tdTpl>\r\n                <td [attr.colspan]=\"item.colspan\" class=\"el-descriptions__content\">\r\n                  <ng-container *ngTemplateOutlet=\"item.content\"></ng-container>\r\n                </td>\r\n              </ng-template>\r\n            </ng-container>\r\n          </tr>\r\n        </ng-container>\r\n      </ng-container>\r\n    </tbody>\r\n  </table>\r\n</div>\r\n",
                host: {
                    class: 'el-descriptions'
                }
            },] }
];
NelDescriptionsComponent.ctorParameters = () => [];
NelDescriptionsComponent.propDecorators = {
    nelTitle: [{ type: Input }],
    nelBorder: [{ type: Input }],
    nelExtra: [{ type: Input }],
    nelSize: [{ type: Input }],
    nelColumn: [{ type: Input }],
    nelDirection: [{ type: Input }],
    items: [{ type: ContentChildren, args: [NelDescriptionsItemComponent, { descendants: false },] }]
};
__decorate([
    InputBoolean()
], NelDescriptionsComponent.prototype, "nelBorder", void 0);

class NelDescriptionsModule {
}
NelDescriptionsModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    NelDescriptionsComponent,
                    NelDescriptionsItemComponent
                ],
                exports: [
                    NelDescriptionsComponent,
                    NelDescriptionsItemComponent
                ],
                imports: [
                    CommonModule,
                    NelOutletModule
                ]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { NelDescriptionsComponent, NelDescriptionsItemComponent, NelDescriptionsModule };
//# sourceMappingURL=ng-element-ui-descriptions.js.map
