import { __decorate } from 'tslib';
import { EventEmitter, Component, ViewContainerRef, Input, Output, ViewChild, Injector, ɵɵdefineInjectable, ɵɵinject, INJECTOR, Injectable, NgModule } from '@angular/core';
import { Overlay, OverlayModule } from '@angular/cdk/overlay';
import { TemplatePortal, ComponentPortal } from '@angular/cdk/portal';
import { modalMotion } from 'ng-element-ui/core/animation';
import { InputBoolean } from 'ng-element-ui/core/utils';
import { Observable, Subject } from 'rxjs';
import { CommonModule } from '@angular/common';
import { NelOutletModule } from 'ng-element-ui/core/outlet';
import { NelIconModule } from 'ng-element-ui/icon';
import { NelButtonModule } from 'ng-element-ui/button';

class NelDialogComponent {
    constructor(overlay, viewContainerRef) {
        this.overlay = overlay;
        this.viewContainerRef = viewContainerRef;
        this.nelVisibleChange = new EventEmitter();
        this.nelOnClose = new EventEmitter();
        this.nelCenter = false;
    }
    set nelVisible(value) {
        var _a;
        if (value) {
            if (this.dialogTpl) {
                this.openWithTemplate(this.dialogTpl);
            }
        }
        else {
            (_a = this.overlayRef) === null || _a === void 0 ? void 0 : _a.dispose();
        }
    }
    ;
    openWithTemplate(tpl) {
        this.overlayRef = this.overlay.create();
        this.overlayRef.attach(new TemplatePortal(tpl, this.viewContainerRef));
    }
    handleClose() {
        if (this.nelBeforeClose) {
            const before = this.nelBeforeClose();
            if (before instanceof Observable) {
                before.subscribe((data) => {
                    if (data) {
                        this.close();
                    }
                }, (err) => {
                    console.log(err);
                });
            }
            else if (before !== false) {
                this.close();
            }
        }
        else {
            this.close();
        }
    }
    close() {
        var _a;
        (_a = this.overlayRef) === null || _a === void 0 ? void 0 : _a.dispose();
        this.nelVisibleChange.emit(false);
        this.nelOnClose.emit();
    }
    clickDialog($event) {
        $event.stopPropagation();
    }
}
NelDialogComponent.decorators = [
    { type: Component, args: [{
                selector: 'nel-dialog',
                template: "<ng-template #tpl>\r\n  <div class=\"el-overlay\" (click)=\"handleClose()\">\r\n    <div class=\"el-dialog\" [class.el-dialog--center]=\"nelCenter\" role=\"dialog\" style=\"margin-top: 15vh; width: 30%\"\r\n      (click)=\"clickDialog($event)\" @modalMotion>\r\n      <div class=\"el-dialog__header\">\r\n        <span class=\"el-dialog__title\" *ngIf=\"nelTitle\">\r\n          <ng-container *stringTemplate=\"nelTitle\">{{nelTitle}}</ng-container>\r\n        </span>\r\n        <button class=\"el-dialog__headerbtn\" type=\"button\" (click)=\"handleClose()\">\r\n          <i nel-icon [nelType]=\"'close'\" class=\"el-dialog__close\"></i>\r\n        </button>\r\n      </div>\r\n      <div class=\"el-dialog__body\">\r\n        <ng-content></ng-content>\r\n      </div>\r\n      <div class=\"el-dialog__footer\" *ngIf=\"nelFooter\">\r\n        <ng-container *stringTemplate=\"nelFooter\">{{nelFooter}}</ng-container>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</ng-template>\r\n",
                animations: [modalMotion]
            },] }
];
NelDialogComponent.ctorParameters = () => [
    { type: Overlay },
    { type: ViewContainerRef }
];
NelDialogComponent.propDecorators = {
    nelVisible: [{ type: Input }],
    nelTitle: [{ type: Input }],
    nelContent: [{ type: Input }],
    nelFooter: [{ type: Input }],
    nelVisibleChange: [{ type: Output }],
    nelOnClose: [{ type: Output }],
    nelBeforeClose: [{ type: Input }],
    nelCenter: [{ type: Input }],
    dialogTpl: [{ type: ViewChild, args: ['tpl', { static: false },] }]
};
__decorate([
    InputBoolean()
], NelDialogComponent.prototype, "nelCenter", void 0);

class DialogRef {
    constructor(overlay, nelTitle, nelContent, nelOnCancel, nelOnOk) {
        this.overlay = overlay;
        this.nelTitle = nelTitle;
        this.nelContent = nelContent;
        this.nelOnCancel = nelOnCancel;
        this.nelOnOk = nelOnOk;
        this.afterClosed$ = new Subject();
        overlay.backdropClick().subscribe(() => this._close('backdropClick', null));
    }
    close(data) {
        this._close('close', data);
    }
    _close(type, data) {
        this.overlay.dispose();
        this.afterClosed$.next({
            type,
            data
        });
        this.afterClosed$.complete();
    }
}

class NelDialogConfirmComponent {
    constructor(ref) {
        this.ref = ref;
    }
    ngOnInit() {
        this.nelTitle = this.ref.nelTitle;
        this.nelContent = this.ref.nelContent;
        this.nelOnCancel = this.ref.nelOnCancel;
        this.nelOnOk = this.ref.nelOnOk;
    }
    cancel() {
        this.ref.close(null);
        if (this.nelOnCancel) {
            this.nelOnCancel();
        }
    }
    confirm() {
        this.ref.close(null);
        if (this.nelOnOk) {
            this.nelOnOk();
        }
    }
    clickDialog($event) {
        $event.stopPropagation();
    }
}
NelDialogConfirmComponent.decorators = [
    { type: Component, args: [{
                selector: 'nel-dialog-confirm',
                template: "<div class=\"el-overlay is-message-box\" (click)=\"cancel()\">\r\n  <div class=\"el-message-box\" (click)=\"clickDialog($event)\">\r\n    <div class=\"el-message-box__header\">\r\n      <div class=\"el-message-box__title\">\r\n        <span>{{nelTitle}}</span>\r\n      </div>\r\n      <button type=\"button\" class=\"el-message-box__headerbtn\" aria-label=\"Close\" (click)=\"cancel()\">\r\n        <i class=\"el-message-box__close el-icon-close\"></i>\r\n      </button>\r\n    </div>\r\n    <div class=\"el-message-box__content\">\r\n      <div class=\"el-message-box__container\">\r\n        <div class=\"el-message-box__message\">\r\n          <p>{{nelContent}}</p>\r\n        </div>\r\n      </div>\r\n    </div>\r\n    <div class=\"el-message-box__btns\">\r\n      <button nel-button [nelSize]=\"'small'\" (click)=\"cancel()\">\r\n        \u53D6\u6D88\r\n      </button>\r\n      <button nel-button [nelSize]=\"'small'\" [nelType]=\"'primary'\" (click)=\"confirm()\">\r\n        \u786E\u5B9A\r\n      </button>\r\n    </div>\r\n  </div>\r\n</div>\r\n"
            },] }
];
NelDialogConfirmComponent.ctorParameters = () => [
    { type: DialogRef }
];

class NelDialogService {
    constructor(overlay, injector) {
        this.overlay = overlay;
        this.injector = injector;
    }
    confirm(content) {
        const overlayRef = this.overlay.create();
        const dialogRef = new DialogRef(overlayRef, content.nelTitle, content.nelContent, content.nelOnCancel, content.nelOnOk);
        const injector = this.createInjector(dialogRef, this.injector);
        overlayRef.attach(new ComponentPortal(NelDialogConfirmComponent, null, injector));
        return dialogRef;
    }
    createInjector(ref, inj) {
        return Injector.create({
            parent: inj,
            providers: [{ provide: DialogRef, useValue: ref }]
        });
    }
}
NelDialogService.ɵprov = ɵɵdefineInjectable({ factory: function NelDialogService_Factory() { return new NelDialogService(ɵɵinject(Overlay), ɵɵinject(INJECTOR)); }, token: NelDialogService, providedIn: "root" });
NelDialogService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
NelDialogService.ctorParameters = () => [
    { type: Overlay },
    { type: Injector }
];

class NelDialogModule {
}
NelDialogModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    NelDialogComponent,
                    NelDialogConfirmComponent
                ],
                exports: [
                    NelDialogComponent,
                    NelDialogConfirmComponent
                ],
                imports: [
                    CommonModule,
                    OverlayModule,
                    NelOutletModule,
                    NelIconModule,
                    NelButtonModule
                ],
                providers: [
                    NelDialogService
                ]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { NelDialogComponent, NelDialogConfirmComponent, NelDialogModule, NelDialogService, DialogRef as ɵa };
//# sourceMappingURL=ng-element-ui-dialog.js.map
