import { EventEmitter, Component, ViewContainerRef, ElementRef, Input, Output, NgModule } from '@angular/core';
import { drawerMotion, drawerDialogMotion } from 'ng-element-ui/core/animation';
import { Observable } from 'rxjs';
import { CommonModule } from '@angular/common';
import { OverlayModule } from '@angular/cdk/overlay';
import { NelOutletModule } from 'ng-element-ui/core/outlet';

class NelDrawerComponent {
    constructor(hostView, elementRef) {
        this.hostView = hostView;
        this.elementRef = elementRef;
        this.width = '30%';
        this.height = '30%';
        this.nelDirection = 'rtl';
        this.nelWithHeader = true;
        this.nelShowClose = true;
        this.nelVisibleChange = new EventEmitter();
        this.isOpen = false;
    }
    set nelSize(val) {
        if (typeof val === 'number') {
            this.width = val + 'px';
            this.height = val + 'px';
        }
        else {
            this.width = val;
            this.height = val;
        }
    }
    set nelVisible(val) {
        if (val) {
            this.show();
        }
        else {
            if (this.isOpen) {
                this.close();
            }
        }
    }
    show() {
        this.trigger = { elementRef: this.elementRef };
        this.isOpen = true;
    }
    handleClose() {
        if (this.isOpen && this.nelBeforeClose) {
            const before = this.nelBeforeClose();
            if (before instanceof Observable) {
                before.subscribe((data) => {
                    if (data) {
                        this.close();
                    }
                }, (err) => {
                    console.error(err);
                });
            }
            else if (before !== false) {
                this.close();
            }
        }
        else {
            this.close();
        }
    }
    close() {
        this.isOpen = false;
        this.nelVisibleChange.emit(false);
    }
    clickDrawer($event) {
        $event.stopPropagation();
    }
}
NelDrawerComponent.decorators = [
    { type: Component, args: [{
                selector: 'nel-drawer',
                template: "<ng-template cdkConnectedOverlay [cdkConnectedOverlayOrigin]=\"trigger\" [cdkConnectedOverlayOpen]=\"isOpen\">\r\n  <div class=\"el-overlay\" (click)=\"handleClose()\" @drawerMotion>\r\n    <div class=\"el-drawer {{nelDirection}}\" role=\"dialog\" (click)=\"clickDrawer($event)\"\r\n      [style.width]=\"nelDirection=='ltr' || nelDirection=='rtl' ? width : ''\"\r\n      [style.height]=\"nelDirection=='ttb' || nelDirection=='btt' ? height : ''\" [@drawerDialogMotion]=\"nelDirection\">\r\n      <header *ngIf=\"nelWithHeader\" class=\"el-drawer__header\">\r\n        <span *ngIf=\"nelTitle\" role=\"heading\">\r\n          <ng-container *stringTemplate=\"nelTitle\">{{nelTitle}}</ng-container>\r\n        </span>\r\n        <button *ngIf=\"nelShowClose\" (click)=\"handleClose()\" class=\"el-drawer__close-btn\" type=\"button\">\r\n          <i class=\"el-drawer__close el-icon el-icon-close\"></i>\r\n        </button>\r\n      </header>\r\n      <section class=\"el-drawer__body\">\r\n        <ng-content></ng-content>\r\n      </section>\r\n    </div>\r\n  </div>\r\n</ng-template>\r\n",
                animations: [drawerMotion, drawerDialogMotion]
            },] }
];
NelDrawerComponent.ctorParameters = () => [
    { type: ViewContainerRef },
    { type: ElementRef }
];
NelDrawerComponent.propDecorators = {
    nelTitle: [{ type: Input }],
    nelDirection: [{ type: Input }],
    nelWithHeader: [{ type: Input }],
    nelShowClose: [{ type: Input }],
    nelBeforeClose: [{ type: Input }],
    nelSize: [{ type: Input }],
    nelVisible: [{ type: Input }],
    nelVisibleChange: [{ type: Output }]
};

class NelDrawerModule {
}
NelDrawerModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    NelDrawerComponent
                ],
                exports: [
                    NelDrawerComponent
                ],
                imports: [
                    CommonModule,
                    OverlayModule,
                    NelOutletModule
                ]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { NelDrawerComponent, NelDrawerModule };
//# sourceMappingURL=ng-element-ui-drawer.js.map
