import { Injectable, Component, ElementRef, Renderer2, ViewChild, Optional, Input, Directive, Host, NgModule } from '@angular/core';
import { dropdownMotion } from 'ng-element-ui/core/animation';
import { ReplaySubject } from 'rxjs';
import { __decorate } from 'tslib';
import { InputBoolean } from 'ng-element-ui/core/utils';
import { NelButtonGroupComponent } from 'ng-element-ui/button';
import { CommonModule } from '@angular/common';
import { OverlayModule } from '@angular/cdk/overlay';
import { NelScrollbarModule } from 'ng-element-ui/scrollbar';
import { NelIconModule } from 'ng-element-ui/icon';

class NelDropdownService {
    constructor() {
        this.selected$ = new ReplaySubject();
    }
    select() {
        this.selected$.next();
    }
}
NelDropdownService.decorators = [
    { type: Injectable }
];

class NelDropdownMenuComponent {
    constructor(elementRef, renderer, dropdown) {
        this.elementRef = elementRef;
        this.renderer = renderer;
        this.dropdown = dropdown;
        this.isOpen = false;
        this.state = 'leave';
        this.hideOnClick = true;
        this.triggerDisposables = [];
        this.dropdown.selected$.subscribe(() => {
            if (this.hideOnClick) {
                this.close();
            }
        });
    }
    ngOnDestroy() {
        this.removeTriggerListeners();
        if (this.timer) {
            clearTimeout(this.timer);
        }
    }
    initListen() {
        if (this.trigger === 'hover') {
            this.mouseenter();
            setTimeout(() => {
                this.removeTriggerListeners();
                this.triggerDisposables.push(this.renderer.listen(this.dropdownEle.nativeElement, 'mouseenter', () => this.mouseenter()));
                this.triggerDisposables.push(this.renderer.listen(this.dropdownEle.nativeElement, 'mouseleave', () => this.mouseleave()));
            }, 0);
        }
    }
    removeTriggerListeners() {
        this.triggerDisposables.forEach(dispose => dispose());
        this.triggerDisposables.length = 0;
    }
    mouseenter() {
        if (this.timer) {
            clearTimeout(this.timer);
        }
    }
    mouseleave() {
        this.close();
    }
    onClickOutside(event) {
        if (!this.origin.elementRef.nativeElement.contains(event.target)) {
            this.close();
        }
    }
    close() {
        if (this.trigger === 'hover') {
            this.timer = setTimeout(() => {
                this.state = 'leave';
                this.isOpen = false;
            }, 300);
        }
        else {
            this.state = 'leave';
            this.isOpen = false;
        }
    }
}
NelDropdownMenuComponent.decorators = [
    { type: Component, args: [{
                selector: 'nel-dropdown-menu',
                exportAs: 'nelDropdownMenu',
                template: "<ng-template cdkConnectedOverlay [cdkConnectedOverlayOrigin]=\"origin\" [cdkConnectedOverlayOpen]=\"isOpen\"\r\n  [cdkConnectedOverlayPositions]=\"positionStrategy\" (overlayOutsideClick)=\"onClickOutside($event)\">\r\n  <div #dropdownEle class=\"el-dropdown__popper el-popper is-light is-pure\" [@dropdownMotion]=\"state\">\r\n    <nel-scrollbar [nelMaxHeight]=\"maxHeight\">\r\n      <ul class=\"el-dropdown__list\">\r\n        <ul class=\"el-dropdown-menu\" [class.el-dropdown-menu--medium]=\"size == 'medium'\"\r\n          [class.el-dropdown-menu--small]=\"size == 'small'\" [class.el-dropdown-menu--mini]=\"size == 'mini'\">\r\n          <ng-content></ng-content>\r\n        </ul>\r\n      </ul>\r\n    </nel-scrollbar>\r\n    <div class=\"el-popper__arrow\" style=\"left: 50%; top: -10px; transform: translate(-50%, 5px);\">\r\n    </div>\r\n  </div>\r\n</ng-template>\r\n",
                animations: [dropdownMotion],
                providers: [
                    NelDropdownService
                ]
            },] }
];
NelDropdownMenuComponent.ctorParameters = () => [
    { type: ElementRef },
    { type: Renderer2 },
    { type: NelDropdownService }
];
NelDropdownMenuComponent.propDecorators = {
    dropdownEle: [{ type: ViewChild, args: ['dropdownEle', { static: false },] }]
};

class NelDropdownItemComponent {
    constructor(dropdown) {
        this.dropdown = dropdown;
        this.nelDisabled = false;
        this.nelDivided = false;
    }
    onHostClick(event) {
        if (this.dropdown) {
            this.dropdown.select();
        }
    }
}
NelDropdownItemComponent.decorators = [
    { type: Component, args: [{
                selector: 'nel-dropdown-item',
                template: "<li class=\"el-dropdown-menu__item\" [class.is-disabled]=\"nelDisabled\"\r\n  [class.el-dropdown-menu__item--divided]=\"nelDivided\" (click)=\"onHostClick($event)\">\r\n  <i *ngIf=\"nelIcon\" nel-icon [nelType]=\"nelIcon\"></i>\r\n  <ng-content></ng-content>\r\n</li>\r\n"
            },] }
];
NelDropdownItemComponent.ctorParameters = () => [
    { type: NelDropdownService, decorators: [{ type: Optional }] }
];
NelDropdownItemComponent.propDecorators = {
    nelDisabled: [{ type: Input }],
    nelDivided: [{ type: Input }],
    nelIcon: [{ type: Input }]
};
__decorate([
    InputBoolean()
], NelDropdownItemComponent.prototype, "nelDisabled", void 0);
__decorate([
    InputBoolean()
], NelDropdownItemComponent.prototype, "nelDivided", void 0);

class NelDropdownDirective {
    constructor(elementRef, renderer) {
        this.elementRef = elementRef;
        this.renderer = renderer;
        this.nelDropdownTrigger = 'hover';
        this.nelHideOnClick = true;
        this.triggerDisposables = [];
    }
    ngOnDestroy() {
        this.removeTriggerListeners();
    }
    ngOnInit() {
        this.trigger();
        if (this.nelDropdownMenu) {
            this.renderer.removeChild(this.renderer.parentNode(this.elementRef.nativeElement), this.nelDropdownMenu.elementRef.nativeElement);
        }
    }
    trigger() {
        if (this.nelDropdownTrigger === 'hover') {
            this.triggerDisposables.push(this.renderer.listen(this.elementRef.nativeElement, 'mouseenter', ($event) => this.show($event)));
            this.triggerDisposables.push(this.renderer.listen(this.elementRef.nativeElement, 'mouseleave', () => this.hide()));
        }
        else if (this.nelDropdownTrigger === 'click') {
            this.triggerDisposables.push(this.renderer.listen(this.elementRef.nativeElement, 'click', ($event) => this.show($event)));
        }
        else {
            this.triggerDisposables.push(this.renderer.listen(this.elementRef.nativeElement, 'contextmenu', ($event) => this.show($event)));
        }
    }
    removeTriggerListeners() {
        this.triggerDisposables.forEach(dispose => dispose());
        this.triggerDisposables.length = 0;
    }
    show($event) {
        var _a;
        if (this.nelDropdownTrigger === 'contextmenu') {
            $event.preventDefault();
        }
        if (!((_a = this.nelDropdownMenu) === null || _a === void 0 ? void 0 : _a.isOpen)) {
            const position = {
                originX: 'center',
                originY: 'bottom',
                overlayX: 'center',
                overlayY: 'top',
                offsetX: 0,
                offsetY: 10,
            };
            if (this.nelDropdownMenu) {
                this.nelDropdownMenu.trigger = this.nelDropdownTrigger;
                this.nelDropdownMenu.origin = { elementRef: this.elementRef };
                this.nelDropdownMenu.isOpen = true;
                this.nelDropdownMenu.positionStrategy = [position];
                this.nelDropdownMenu.state = 'into';
                this.nelDropdownMenu.initListen();
                this.nelDropdownMenu.hideOnClick = this.nelHideOnClick;
                if (this.nelDropdownSize) {
                    this.nelDropdownMenu.size = this.nelDropdownSize;
                }
                if (this.nelMaxHeight) {
                    this.nelDropdownMenu.maxHeight = this.nelMaxHeight;
                }
            }
        }
    }
    hide() {
        var _a;
        (_a = this.nelDropdownMenu) === null || _a === void 0 ? void 0 : _a.close();
    }
}
NelDropdownDirective.decorators = [
    { type: Directive, args: [{
                selector: '[nel-dropdown]'
            },] }
];
NelDropdownDirective.ctorParameters = () => [
    { type: ElementRef },
    { type: Renderer2 }
];
NelDropdownDirective.propDecorators = {
    nelDropdownTrigger: [{ type: Input }],
    nelDropdownMenu: [{ type: Input }],
    nelHideOnClick: [{ type: Input }],
    nelDropdownSize: [{ type: Input }],
    nelMaxHeight: [{ type: Input }]
};

class NelDropdownButtonDirective {
    constructor(renderer, nelButtonGroupComponent, elementRef) {
        this.renderer = renderer;
        this.nelButtonGroupComponent = nelButtonGroupComponent;
        this.elementRef = elementRef;
    }
    ngAfterViewInit() {
        const parentElement = this.renderer.parentNode(this.elementRef.nativeElement);
        if (this.nelButtonGroupComponent && parentElement) {
            this.renderer.addClass(parentElement, 'el-dropdown');
            this.renderer.addClass(this.elementRef.nativeElement, 'el-dropdown__caret-button');
        }
    }
}
NelDropdownButtonDirective.decorators = [
    { type: Directive, args: [{
                selector: '[nel-button][nel-dropdown]'
            },] }
];
NelDropdownButtonDirective.ctorParameters = () => [
    { type: Renderer2 },
    { type: NelButtonGroupComponent, decorators: [{ type: Host }, { type: Optional }] },
    { type: ElementRef }
];

class NelDropdownModule {
}
NelDropdownModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    NelDropdownMenuComponent,
                    NelDropdownItemComponent,
                    NelDropdownDirective,
                    NelDropdownButtonDirective
                ],
                exports: [
                    NelDropdownMenuComponent,
                    NelDropdownItemComponent,
                    NelDropdownDirective,
                    NelDropdownButtonDirective
                ],
                imports: [
                    CommonModule,
                    OverlayModule,
                    NelScrollbarModule,
                    NelIconModule
                ]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { NelDropdownButtonDirective, NelDropdownDirective, NelDropdownItemComponent, NelDropdownMenuComponent, NelDropdownModule, NelDropdownService as ɵa };
//# sourceMappingURL=ng-element-ui-dropdown.js.map
