import { __decorate } from 'tslib';
import { Component, ChangeDetectionStrategy, ViewChildren, HostListener, ɵɵdefineInjectable, ɵɵinject, INJECTOR, Injectable, Injector, EventEmitter, ElementRef, ChangeDetectorRef, Input, Output, NgModule } from '@angular/core';
import { getScrollContainer, InputBoolean } from 'ng-element-ui/core/utils';
import { Subject, fromEvent } from 'rxjs';
import { debounceTime } from 'rxjs/operators';
import { ComponentPortal, PortalInjector } from '@angular/cdk/portal';
import { Overlay, OverlayModule } from '@angular/cdk/overlay';
import { CommonModule } from '@angular/common';
import { DragDropModule } from '@angular/cdk/drag-drop';
import { NelOutletModule } from 'ng-element-ui/core/outlet';

class ImageRef {
    constructor(overlay, nelUrlList, nelInitialIndex, nelInfinite = true, nelOnClose, nelOnSwitch) {
        this.overlay = overlay;
        this.nelUrlList = nelUrlList;
        this.nelInitialIndex = nelInitialIndex;
        this.nelInfinite = nelInfinite;
        this.nelOnClose = nelOnClose;
        this.nelOnSwitch = nelOnSwitch;
        this.afterClosed$ = new Subject();
    }
    colse(data) {
        this._close('close', data);
    }
    _close(type, data) {
        this.overlay.dispose();
        this.afterClosed$.next({
            type,
            data
        });
        this.afterClosed$.complete();
    }
}

class NelImageViewerComponent {
    constructor(imageRef) {
        this.imageRef = imageRef;
        this.nelInfinite = true;
        this.deg = 0;
        this.scale = 1;
        this.isOriginal = false;
    }
    ngOnInit() {
        this.nelUrlList = this.imageRef.nelUrlList;
        this.nelInitialIndex =
            !this.imageRef.nelInitialIndex || this.imageRef.nelInitialIndex > this.imageRef.nelUrlList.length ? 0 : this.imageRef.nelInitialIndex;
        this.nelInfinite = this.imageRef.nelInfinite;
    }
    ngAfterViewInit() {
        this.imgList.forEach((item, index) => {
            item.nativeElement.style.transform = 'scale(1) rotate(0deg)';
            item.nativeElement.style.marginLeft = '0px';
            item.nativeElement.style.marginTop = '0px';
            item.nativeElement.style.maxHeight = '100%';
            item.nativeElement.style.maxWidth = '100%';
            if (index !== this.nelInitialIndex) {
                item.nativeElement.style.display = 'none';
            }
        });
    }
    close() {
        this.imageRef.colse(this.nelInitialIndex);
        if (this.imageRef.nelOnClose) {
            this.imageRef.nelOnClose();
        }
    }
    prev() {
        if (this.nelInitialIndex - 1 < 0) {
            if (this.nelInfinite) {
                this.nelInitialIndex = this.nelUrlList.length - 1;
            }
            else {
                this.nelInitialIndex = 0;
            }
        }
        else {
            this.nelInitialIndex -= 1;
        }
        if (this.imageRef.nelOnSwitch) {
            this.imageRef.nelOnSwitch(this.nelInitialIndex);
        }
        this.deg = 0;
        this.scale = 1;
        this.setupTransform();
    }
    next() {
        if (this.nelInitialIndex + 1 < this.nelUrlList.length) {
            this.nelInitialIndex += 1;
        }
        else {
            if (this.nelInfinite) {
                this.nelInitialIndex = 0;
            }
            else {
                this.nelInitialIndex = this.nelUrlList.length - 1;
            }
        }
        if (this.imageRef.nelOnSwitch) {
            this.imageRef.nelOnSwitch(this.nelInitialIndex);
        }
        this.deg = 0;
        this.scale = 1;
        this.setupTransform();
    }
    rotateImage(val) {
        this.deg = this.deg + val;
        this.setupTransform();
    }
    scaleImage(val) {
        this.scale = this.scale + val;
        if (this.scale < 0.2) {
            this.scale = 0.2;
        }
        this.setupTransform();
    }
    setupTransform(transition = true) {
        const imgEle = this.imgList.get(this.nelInitialIndex);
        if (imgEle) {
            if (transition) {
                imgEle.nativeElement.style.transition = 'transform 0.3s ease 0s';
            }
            else {
                imgEle.nativeElement.style.transition = '';
            }
            imgEle.nativeElement.style.transform = `scale(${this.scale}) rotate(${this.deg * 90}deg)`;
        }
    }
    changeType() {
        this.isOriginal = !this.isOriginal;
        this.deg = 0;
        this.scale = 1;
        this.setupTransform(false);
    }
    dragStarted() {
        const imgEle = this.imgList.get(this.nelInitialIndex);
        if (imgEle) {
            imgEle.nativeElement.style.transition = '';
        }
    }
    wheelScroll($event) {
        $event.stopPropagation();
        const wheelDirection = $event.wheelDelta || -$event.deltaY;
        if (wheelDirection > 0) {
            // 往上滚动
            this.scaleImage(0.015);
        }
        else {
            // 往下滚动
            this.scaleImage(-0.015);
        }
    }
}
NelImageViewerComponent.decorators = [
    { type: Component, args: [{
                selector: 'nel-image-viewer',
                template: "<div tabindex=\"-1\" class=\"el-image-viewer__wrapper\" style=\"z-index: 2000;\">\r\n  <div class=\"el-image-viewer__mask\"></div>\r\n  <span class=\"el-image-viewer__btn el-image-viewer__close\" (click)=\"close()\">\r\n    <i class=\"el-icon-close\"></i>\r\n  </span>\r\n  <span class=\"el-image-viewer__btn el-image-viewer__prev\" (click)=\"prev()\">\r\n    <i class=\"el-icon-arrow-left\"></i>\r\n  </span>\r\n  <span class=\"el-image-viewer__btn el-image-viewer__next\" (click)=\"next()\">\r\n    <i class=\"el-icon-arrow-right\"></i>\r\n  </span>\r\n  <div class=\"el-image-viewer__btn el-image-viewer__actions\">\r\n    <div class=\"el-image-viewer__actions__inner\">\r\n      <i class=\"el-icon-zoom-out\" (click)=\"scaleImage(-0.2)\"></i>\r\n      <i class=\"el-icon-zoom-in\" (click)=\"scaleImage(0.2)\"></i>\r\n      <i class=\"el-image-viewer__actions__divider\"></i>\r\n      <i *ngIf=\"!isOriginal\" class=\"el-icon-full-screen\" (click)=\"changeType()\"></i>\r\n      <i *ngIf=\"isOriginal\" class=\"el-icon-c-scale-to-original\" (click)=\"changeType()\"></i>\r\n      <i class=\"el-image-viewer__actions__divider\"></i>\r\n      <i class=\"el-icon-refresh-left\" (click)=\"rotateImage(-1)\"></i>\r\n      <i class=\"el-icon-refresh-right\" (click)=\"rotateImage(1)\"></i>\r\n    </div>\r\n  </div>\r\n  <div cdkDrag (cdkDragStarted)=\"dragStarted()\" class=\"el-image-viewer__canvas\">\r\n    <img cdkDragHandle #imgEle *ngFor=\"let url of nelUrlList; let index=index\" [src]=\"url\"\r\n      [style.display]=\"index != nelInitialIndex ? 'none' : ''\"\r\n      [ngStyle]=\"{'max-height': isOriginal ? '' : '100%', 'max-width': isOriginal ? '' : '100%'}\"\r\n      class=\"el-image-viewer__img\">\r\n    <div>\r\n    </div>\r\n  </div>\r\n</div>\r\n",
                changeDetection: ChangeDetectionStrategy.OnPush
            },] }
];
NelImageViewerComponent.ctorParameters = () => [
    { type: ImageRef }
];
NelImageViewerComponent.propDecorators = {
    imgList: [{ type: ViewChildren, args: ['imgEle',] }],
    wheelScroll: [{ type: HostListener, args: ['wheel', ['$event'],] }]
};

class NelImageService {
    constructor(overlay, injector) {
        this.overlay = overlay;
        this.injector = injector;
    }
    preview(config) {
        const overlayRef = this.overlay.create();
        const imageRef = new ImageRef(overlayRef, config.nelUrlList, config.nelInitialIndex, config.nelInfinite, config.nelOnClose, config.nelOnSwitch);
        const injector = this.createInjector(imageRef, this.injector);
        overlayRef.attach(new ComponentPortal(NelImageViewerComponent, null, injector));
        return imageRef;
    }
    createInjector(ref, inj) {
        const injectorTokens = new WeakMap([[ImageRef, ref]]);
        return new PortalInjector(inj, injectorTokens);
    }
}
NelImageService.ɵprov = ɵɵdefineInjectable({ factory: function NelImageService_Factory() { return new NelImageService(ɵɵinject(Overlay), ɵɵinject(INJECTOR)); }, token: NelImageService, providedIn: "root" });
NelImageService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
NelImageService.ctorParameters = () => [
    { type: Overlay },
    { type: Injector }
];

class NelImageComponent {
    constructor(elementRef, cdr, image) {
        this.elementRef = elementRef;
        this.cdr = cdr;
        this.image = image;
        this.loading = true;
        this.hasLoadError = false;
        this.nelLazy = false;
        this.nelOnLoad = new EventEmitter();
        this.nelOnError = new EventEmitter();
    }
    ngOnDestroy() {
        if (this.subscribeLazy) {
            this.subscribeLazy.unsubscribe();
        }
    }
    ngAfterViewInit() {
        if (this.nelSrc) {
            if (this.nelLazy) {
                this.container = getScrollContainer(this.elementRef.nativeElement, true);
                const clientHeight = this.container.clientHeight;
                const offsetTop = this.container.offsetTop;
                const elOffsetTop = this.elementRef.nativeElement.offsetTop;
                if (elOffsetTop - offsetTop <= clientHeight) {
                    this.loadImage();
                }
                else {
                    this.lazyImage();
                }
            }
            else {
                this.loadImage();
            }
        }
        else {
            setTimeout(() => {
                this.loading = false;
                this.hasLoadError = true;
                this.cdr.markForCheck();
            }, 0);
        }
    }
    loadImage() {
        this.loading = true;
        setTimeout(() => {
            const img = new Image();
            img.src = this.nelSrc;
            img.onload = (e) => {
                this.handlerLoad(e);
            };
            img.onerror = (e) => {
                this.handlerError(e);
            };
        }, 0);
    }
    lazyImage() {
        setTimeout(() => {
            this.loading = true;
            this.subscribeLazy = fromEvent(this.container, 'scroll')
                .pipe(debounceTime(200))
                .subscribe(() => {
                this.handleLazy();
            });
        }, 0);
    }
    handlerLoad(e) {
        this.loading = false;
        this.src = this.nelSrc;
        this.nelOnLoad.emit(e);
        this.cdr.markForCheck();
    }
    handlerError(e) {
        this.loading = false;
        this.hasLoadError = true;
        this.nelOnError.emit(e);
        this.cdr.markForCheck();
    }
    handleLazy() {
        const clientHeight = this.container.clientHeight;
        const offsetTop = this.container.offsetTop;
        const scrollTop = this.container.scrollTop;
        const elOffsetTop = this.elementRef.nativeElement.offsetTop;
        if (elOffsetTop - offsetTop <= clientHeight + scrollTop) {
            this.loadImage();
            this.subscribeLazy.unsubscribe();
        }
    }
    preview() {
        if (this.nelPreviewSrcList && this.nelPreviewSrcList.length > 0) {
            this.image.preview({
                nelUrlList: this.nelPreviewSrcList,
                nelInitialIndex: 0
            });
        }
    }
}
NelImageComponent.decorators = [
    { type: Component, args: [{
                selector: 'nel-image',
                template: "<img *ngIf=\"!loading && !hasLoadError\" (click)=\"preview()\" class=\"el-image__inner\" [src]=\"src\"\r\n  [style.object-fit]=\"nelFit\" [alt]=\"nelAlt\">\r\n<div *ngIf=\"loading\" class=\"el-image__placeholder\">\r\n  <ng-container *ngIf=\"nelPlaceholder\">\r\n    <ng-container *stringTemplate=\"nelPlaceholder\">{{nelPlaceholder}}</ng-container>\r\n  </ng-container>\r\n</div>\r\n<div *ngIf=\"hasLoadError\" class=\"el-image__error\">\r\n  <ng-container *ngIf=\"nelError; else errorTpl\">\r\n    <ng-container *stringTemplate=\"nelError\">{{nelError}}</ng-container>\r\n  </ng-container>\r\n  <ng-template #errorTpl>\u52A0\u8F7D\u5931\u8D25</ng-template>\r\n</div>\r\n",
                changeDetection: ChangeDetectionStrategy.OnPush,
                host: {
                    class: 'el-image'
                }
            },] }
];
NelImageComponent.ctorParameters = () => [
    { type: ElementRef },
    { type: ChangeDetectorRef },
    { type: NelImageService }
];
NelImageComponent.propDecorators = {
    nelSrc: [{ type: Input }],
    nelFit: [{ type: Input }],
    nelAlt: [{ type: Input }],
    nelPlaceholder: [{ type: Input }],
    nelError: [{ type: Input }],
    nelLazy: [{ type: Input }],
    nelPreviewSrcList: [{ type: Input }],
    nelOnLoad: [{ type: Output }],
    nelOnError: [{ type: Output }]
};
__decorate([
    InputBoolean()
], NelImageComponent.prototype, "nelLazy", void 0);

class NelImageModule {
}
NelImageModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    NelImageComponent,
                    NelImageViewerComponent
                ],
                exports: [
                    NelImageComponent,
                    NelImageViewerComponent
                ],
                imports: [
                    CommonModule,
                    OverlayModule,
                    DragDropModule,
                    NelOutletModule
                ],
                providers: [
                    NelImageService
                ]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { NelImageComponent, NelImageModule, NelImageService, NelImageViewerComponent, ImageRef as ɵa };
//# sourceMappingURL=ng-element-ui-image.js.map
