import { EventEmitter, Directive, ElementRef, Input, Output, NgModule } from '@angular/core';
import { getScrollContainer } from 'ng-element-ui/core/utils';
import { Subject, fromEvent } from 'rxjs';
import { debounceTime } from 'rxjs/operators';

class NelInfiniteScrollDirective {
    constructor(elementRef) {
        this.elementRef = elementRef;
        this.reachBottom$ = new Subject();
        this.disabled = false;
        // 是否初始化
        this.initData = false;
        this.nelDistance = 0;
        this.nelDelay = 200;
        this.nelImmediate = true;
        this.nelOnReachBottom = new EventEmitter();
    }
    set nelDisabled(value) {
        this.disabled = value;
        if (this.initData) {
            if (value) {
                if (this.subscribeScoll) {
                    this.subscribeScoll.unsubscribe();
                }
                if (this.subscribeReachBottom) {
                    this.subscribeReachBottom.unsubscribe();
                }
            }
            else {
                this.initScroll();
            }
        }
    }
    ngOnDestroy() {
        if (this.subscribeScoll) {
            this.subscribeScoll.unsubscribe();
        }
        if (this.subscribeReachBottom) {
            this.subscribeReachBottom.unsubscribe();
        }
    }
    ngAfterViewInit() {
        this.container = getScrollContainer(this.elementRef.nativeElement, true);
        if (!this.disabled) {
            this.initScroll();
            this.initImmediate();
        }
        this.initData = true;
    }
    initScroll() {
        this.subscribeReachBottom = this.reachBottom$.asObservable().pipe(debounceTime(this.nelDelay)).subscribe(() => {
            this.nelOnReachBottom.emit();
        });
        this.subscribeScoll = fromEvent(this.container, 'scroll')
            .subscribe(() => {
            this.handleScroll();
        });
    }
    initImmediate() {
        if (this.nelImmediate) {
            this.observer = new MutationObserver(mutations => {
                this.immediate();
            });
            const config = { childList: true, subtree: true };
            this.observer.observe(this.container, config);
            // 查询滚动的父元素
            this.immediate();
        }
    }
    immediate() {
        if (this.container.scrollHeight <= this.container.clientHeight) {
            this.nelOnReachBottom.emit();
        }
        else {
            if (this.observer) {
                this.observer.disconnect();
            }
        }
    }
    handleScroll() {
        if (this.container.scrollHeight - this.container.clientHeight
            - this.container.scrollTop <= this.nelDistance) {
            this.reachBottom$.next();
        }
    }
}
NelInfiniteScrollDirective.decorators = [
    { type: Directive, args: [{
                selector: '[nel-infinite-scroll]'
            },] }
];
NelInfiniteScrollDirective.ctorParameters = () => [
    { type: ElementRef }
];
NelInfiniteScrollDirective.propDecorators = {
    nelDistance: [{ type: Input }],
    nelDisabled: [{ type: Input }],
    nelDelay: [{ type: Input }],
    nelImmediate: [{ type: Input }],
    nelOnReachBottom: [{ type: Output }]
};

class NelInfiniteScrollModule {
}
NelInfiniteScrollModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    NelInfiniteScrollDirective
                ],
                exports: [
                    NelInfiniteScrollDirective
                ]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { NelInfiniteScrollDirective, NelInfiniteScrollModule };
//# sourceMappingURL=ng-element-ui-infinite-scroll.js.map
