import { Directive, Input, ContentChildren, NgModule } from '@angular/core';
import { DomSanitizer } from '@angular/platform-browser';

class NelColDirective {
    constructor(sanitizer) {
        this.sanitizer = sanitizer;
        this.nelSpan = 24;
        this.nelOffset = 0;
        this.nelXs = 0;
        this.nelSm = 0;
        this.nelMd = 0;
        this.nelLg = 0;
        this.nelXl = 0;
        this.parentGutter = 0;
    }
    getClass() {
        let classStr = 'el-col el-col-' + this.nelSpan;
        if (this.nelOffset) {
            classStr += ' el-col-offset-' + this.nelOffset;
        }
        if (this.nelXs) {
            let span = 0;
            if (typeof this.nelXs === 'number') {
                span = this.nelXs;
            }
            else {
                span = this.nelXs.span;
            }
            classStr += ' el-col-xs-' + span;
        }
        if (this.nelSm) {
            let span = 0;
            if (typeof this.nelSm === 'number') {
                span = this.nelSm;
            }
            else {
                span = this.nelSm.span;
            }
            classStr += ' el-col-sm-' + span;
        }
        if (this.nelMd) {
            let span = 0;
            if (typeof this.nelMd === 'number') {
                span = this.nelMd;
            }
            else {
                span = this.nelMd.span;
            }
            classStr += ' el-col-md-' + span;
        }
        if (this.nelLg) {
            let span = 0;
            if (typeof this.nelLg === 'number') {
                span = this.nelLg;
            }
            else {
                span = this.nelLg.span;
            }
            classStr += ' el-col-lg-' + span;
        }
        if (this.nelXl) {
            let span = 0;
            if (typeof this.nelXl === 'number') {
                span = this.nelXl;
            }
            else {
                span = this.nelXl.span;
            }
            classStr += ' el-col-xl-' + span;
        }
        return classStr;
    }
    gutterStyle() {
        let styleStr = '';
        if (this.parentGutter) {
            styleStr += `padding-left: ${this.parentGutter / 2}px;`;
            styleStr += `padding-right: ${this.parentGutter / 2}px;`;
        }
        return this.sanitizer.bypassSecurityTrustStyle(styleStr);
    }
}
NelColDirective.decorators = [
    { type: Directive, args: [{
                selector: '[nel-col]',
                host: {
                    '[class]': 'getClass()',
                    '[style]': 'gutterStyle()'
                }
            },] }
];
NelColDirective.ctorParameters = () => [
    { type: DomSanitizer }
];
NelColDirective.propDecorators = {
    nelSpan: [{ type: Input }],
    nelOffset: [{ type: Input }],
    nelXs: [{ type: Input }],
    nelSm: [{ type: Input }],
    nelMd: [{ type: Input }],
    nelLg: [{ type: Input }],
    nelXl: [{ type: Input }]
};

class NelRowDirective {
    constructor(sanitizer) {
        this.sanitizer = sanitizer;
        this.nelGutter = 0;
        this.nelType = undefined;
        this.nelJustify = 'start';
    }
    ngAfterContentInit() {
        if (this.nelGutter > 0) {
            this.colList.forEach((item) => {
                item.parentGutter = this.nelGutter;
            });
        }
    }
    gutterStyle() {
        let styleStr = '';
        if (this.nelGutter) {
            styleStr += `margin-left: -${this.nelGutter / 2}px;`;
            styleStr += `margin-right: -${this.nelGutter / 2}px;`;
        }
        return this.sanitizer.bypassSecurityTrustStyle(styleStr);
    }
}
NelRowDirective.decorators = [
    { type: Directive, args: [{
                selector: '[nel-row]',
                host: {
                    '[class.el-row]': `true`,
                    '[class.el-row--flex]': `nelType == 'flex'`,
                    '[class.is-justify-end]': `nelJustify == 'end'`,
                    '[class.is-justify-center]': `nelJustify == 'center'`,
                    '[class.is-justify-space-around]': `nelJustify == 'space-around'`,
                    '[class.is-justify-space-between]': `nelJustify == 'space-between'`,
                    '[style]': 'gutterStyle()'
                }
            },] }
];
NelRowDirective.ctorParameters = () => [
    { type: DomSanitizer }
];
NelRowDirective.propDecorators = {
    nelGutter: [{ type: Input }],
    nelType: [{ type: Input }],
    nelJustify: [{ type: Input }],
    colList: [{ type: ContentChildren, args: [NelColDirective, { descendants: false },] }]
};

class NelLayoutModule {
}
NelLayoutModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    NelRowDirective,
                    NelColDirective
                ],
                exports: [
                    NelRowDirective,
                    NelColDirective
                ],
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { NelColDirective, NelLayoutModule, NelRowDirective };
//# sourceMappingURL=ng-element-ui-layout.js.map
