import { __decorate } from 'tslib';
import { Component, Input, Injector, ɵɵdefineInjectable, ɵɵinject, INJECTOR, Injectable, NgModule } from '@angular/core';
import { loadingMotion } from 'ng-element-ui/core/animation';
import { InputBoolean } from 'ng-element-ui/core/utils';
import { ComponentPortal } from '@angular/cdk/portal';
import { Overlay } from '@angular/cdk/overlay';
import { CommonModule } from '@angular/common';
import { NelIconModule } from 'ng-element-ui/icon';

class NelLoadingComponent {
    constructor() {
        this.nelLoading = true;
        this.nelFullscreen = false;
    }
}
NelLoadingComponent.decorators = [
    { type: Component, args: [{
                selector: 'nel-loading',
                template: "<ng-content></ng-content>\r\n<div *ngIf=\"nelLoading\" class=\"el-loading-mask\" [class.is-fullscreen]=\"nelFullscreen\" [style.background]=\"nelBackground\"\r\n  @loadingMotion>\r\n  <div class=\"el-loading-spinner\">\r\n    <i *ngIf=\"nelSpinner; else spinnerTpl\" nel-icon [nelType]=\"nelSpinner\"></i>\r\n    <ng-template #spinnerTpl>\r\n      <svg class=\"circular\" viewBox=\"25 25 50 50\">\r\n        <circle class=\"path\" cx=\"50\" cy=\"50\" r=\"20\" fill=\"none\"></circle>\r\n      </svg>\r\n    </ng-template>\r\n    <p *ngIf=\"nelText\" class=\"el-loading-text\">{{nelText}}</p>\r\n  </div>\r\n</div>\r\n",
                animations: [loadingMotion],
                host: {
                    class: 'el-loading-parent--relative'
                }
            },] }
];
NelLoadingComponent.propDecorators = {
    nelLoading: [{ type: Input }],
    nelText: [{ type: Input }],
    nelSpinner: [{ type: Input }],
    nelBackground: [{ type: Input }],
    nelFullscreen: [{ type: Input }]
};
__decorate([
    InputBoolean()
], NelLoadingComponent.prototype, "nelFullscreen", void 0);

class LoadingRef {
    constructor(overlayRef, options) {
        this.overlayRef = overlayRef;
        this.options = options;
        this.componentInstance = null;
    }
    close() {
        this.componentInstance.state = 'done';
    }
}

class NelLoadingFullscreenComponent {
    constructor(loadingRef) {
        this.loadingRef = loadingRef;
        this.state = 'start';
    }
    ngOnInit() {
        this.overlay = this.loadingRef.overlayRef;
        if (this.loadingRef.options) {
            if (this.loadingRef.options.text) {
                this.text = this.loadingRef.options.text;
            }
            if (this.loadingRef.options.spinner) {
                this.spinner = this.loadingRef.options.spinner;
            }
            if (this.loadingRef.options.background) {
                this.background = this.loadingRef.options.background;
            }
        }
    }
    onAnimationDone(event) {
        if (event.toState === 'done') {
            this.overlay.dispose();
        }
    }
}
NelLoadingFullscreenComponent.decorators = [
    { type: Component, args: [{
                selector: 'nel-loading-fullscreen',
                template: "<div class=\"el-loading-mask is-fullscreen\" [style.background]=\"background\" [@loadingMotion]=\"state\"\r\n  (@loadingMotion.done)=\"onAnimationDone($event)\">\r\n  <div class=\"el-loading-spinner\">\r\n    <i *ngIf=\"spinner; else spinnerTpl\" nel-icon [nelType]=\"spinner\"></i>\r\n    <ng-template #spinnerTpl>\r\n      <svg class=\"circular\" viewBox=\"25 25 50 50\">\r\n        <circle class=\"path\" cx=\"50\" cy=\"50\" r=\"20\" fill=\"none\"></circle>\r\n      </svg>\r\n    </ng-template>\r\n    <p *ngIf=\"text\" class=\"el-loading-text\">{{text}}</p>\r\n  </div>\r\n</div>\r\n",
                animations: [loadingMotion]
            },] }
];
NelLoadingFullscreenComponent.ctorParameters = () => [
    { type: LoadingRef }
];

class NelLoadingService {
    constructor(overlay, injector) {
        this.overlay = overlay;
        this.injector = injector;
    }
    show(options) {
        const overlayRef = this.overlay.create();
        const loadingRef = new LoadingRef(overlayRef, options);
        const injector = this.createInjector(loadingRef, this.injector);
        const componentRef = overlayRef.attach(new ComponentPortal(NelLoadingFullscreenComponent, null, injector));
        loadingRef.componentInstance = componentRef.instance;
        this.loadingRef = loadingRef;
        return loadingRef;
    }
    createInjector(ref, inj) {
        return Injector.create({
            parent: inj,
            providers: [{ provide: LoadingRef, useValue: ref }]
        });
    }
    hide() {
        this.loadingRef.close();
    }
}
NelLoadingService.ɵprov = ɵɵdefineInjectable({ factory: function NelLoadingService_Factory() { return new NelLoadingService(ɵɵinject(Overlay), ɵɵinject(INJECTOR)); }, token: NelLoadingService, providedIn: "root" });
NelLoadingService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
NelLoadingService.ctorParameters = () => [
    { type: Overlay },
    { type: Injector }
];

class NelLoadingModule {
}
NelLoadingModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    NelLoadingComponent,
                    NelLoadingFullscreenComponent
                ],
                exports: [
                    NelLoadingComponent,
                    NelLoadingFullscreenComponent
                ],
                imports: [
                    CommonModule,
                    NelIconModule
                ],
                providers: [
                    NelLoadingService
                ]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { NelLoadingComponent, NelLoadingFullscreenComponent, NelLoadingModule, NelLoadingService, LoadingRef as ɵa };
//# sourceMappingURL=ng-element-ui-loading.js.map
