import { Component, Injector, ɵɵdefineInjectable, ɵɵinject, INJECTOR, Injectable, NgModule } from '@angular/core';
import { messageBoxMotion } from 'ng-element-ui/core/animation';
import { ComponentPortal } from '@angular/cdk/portal';
import { Overlay } from '@angular/cdk/overlay';
import { CommonModule } from '@angular/common';
import { NelOutletModule } from 'ng-element-ui/core/outlet';

class MessageBoxRef {
    constructor(type, overlay, title, content, options) {
        this.type = type;
        this.overlay = overlay;
        this.title = title;
        this.content = content;
        this.options = options;
    }
}

class NelMessageBoxComponent {
    constructor(messageBoxRef) {
        this.messageBoxRef = messageBoxRef;
        this.cancelButtonText = '取消';
        this.confirmButtonText = '确定';
        this.center = false;
        this.state = 'start';
        this.leaveType = '';
    }
    ngOnInit() {
        this.boxType = this.messageBoxRef.type;
        this.title = this.messageBoxRef.title;
        this.content = this.messageBoxRef.content;
        this.overlay = this.messageBoxRef.overlay;
        if (this.messageBoxRef.options) {
            if (this.messageBoxRef.options.cancelButtonText) {
                this.cancelButtonText = this.messageBoxRef.options.cancelButtonText;
            }
            if (this.messageBoxRef.options.confirmButtonText) {
                this.confirmButtonText = this.messageBoxRef.options.confirmButtonText;
            }
            if (this.messageBoxRef.options.cancel) {
                this.cancel = this.messageBoxRef.options.cancel;
            }
            if (this.messageBoxRef.options.confirm) {
                this.confirm = this.messageBoxRef.options.confirm;
            }
            if (this.messageBoxRef.options.type) {
                this.type = this.messageBoxRef.options.type;
            }
            if (this.messageBoxRef.options.beforeConfirm) {
                this.beforeConfirm = this.messageBoxRef.options.beforeConfirm;
            }
            if (this.messageBoxRef.options.center) {
                this.center = this.messageBoxRef.options.center;
            }
        }
        this.state = 'into';
    }
    handleCancel(type) {
        if (!(this.boxType === 'alert' && type === 'mask_close')) {
            this.leaveType = type === 'cancel' ? 'cancel' : 'close';
            this.state = 'leave';
        }
    }
    handleConfirm() {
        if (this.beforeConfirm) {
            const result = this.beforeConfirm();
            if (result) {
                this.leaveType = 'confirm';
                this.state = 'leave';
            }
        }
        else {
            this.leaveType = 'confirm';
            this.state = 'leave';
        }
    }
    onAnimationDone(event) {
        if (event.toState === 'leave') {
            this.overlay.dispose();
            if (this.leaveType === 'cancel' || this.leaveType === 'close') {
                if (this.cancel) {
                    this.cancel(this.leaveType);
                }
            }
            else {
                if (this.confirm) {
                    this.confirm();
                }
            }
        }
    }
}
NelMessageBoxComponent.decorators = [
    { type: Component, args: [{
                selector: 'nel-message-box',
                template: "<div class=\"el-overlay is-message-box\" (click)=\"handleCancel('mask_close')\">\r\n  <div class=\"el-message-box\" [class.el-message-box--center]=\"center\" [@messageBoxMotion]=\"state\"\r\n    (@messageBoxMotion.done)=\"onAnimationDone($event)\" (click)=\"$event.stopPropagation()\">\r\n    <div class=\"el-message-box__header\">\r\n      <div class=\"el-message-box__title\">\r\n        <div *ngIf=\"center && type\" class=\"el-message-box__status el-icon-{{type}}\"></div>\r\n        <span>\r\n          <ng-container *stringTemplate=\"title\">{{title}}</ng-container>\r\n        </span>\r\n      </div>\r\n      <button (click)=\"handleCancel('close')\" type=\"button\" class=\"el-message-box__headerbtn\" aria-label=\"Close\">\r\n        <i class=\"el-message-box__close el-icon-close\"></i>\r\n      </button>\r\n    </div>\r\n    <div class=\"el-message-box__content\">\r\n      <div class=\"el-message-box__container\">\r\n        <div *ngIf=\"!center && type\" class=\"el-message-box__status el-icon-{{type}}\"></div>\r\n        <div class=\"el-message-box__message\">\r\n          <p>\r\n            <ng-container *stringTemplate=\"content\">{{content}}</ng-container>\r\n          </p>\r\n        </div>\r\n      </div>\r\n      <div class=\"el-message-box__input\" style=\"display: none;\">\r\n        <div class=\"el-input\">\r\n          <input class=\"el-input__inner\" type=\"text\" autocomplete=\"off\" placeholder=\"\">\r\n        </div>\r\n        <div class=\"el-message-box__errormsg\" style=\"visibility: hidden;\"></div>\r\n      </div>\r\n    </div>\r\n    <div class=\"el-message-box__btns\">\r\n      <button *ngIf=\"boxType != 'alert'\" (click)=\"handleCancel('cancel')\"\r\n        class=\"el-button el-button--default el-button--small\" type=\"button\">\r\n        <span>{{cancelButtonText}}</span>\r\n      </button>\r\n      <button (click)=\"handleConfirm()\" class=\"el-button el-button--default el-button--small el-button--primary\"\r\n        type=\"button\">\r\n        <span>{{confirmButtonText}}</span>\r\n      </button>\r\n    </div>\r\n  </div>\r\n</div>\r\n",
                animations: [messageBoxMotion]
            },] }
];
NelMessageBoxComponent.ctorParameters = () => [
    { type: MessageBoxRef }
];

class NelMessageBoxService {
    constructor(overlay, injector) {
        this.overlay = overlay;
        this.injector = injector;
    }
    blank(title, content, options) {
        return this.show('blank', title, content, options);
    }
    alert(title, content, options) {
        return this.show('alert', title, content, options);
    }
    confirm(title, content, options) {
        return this.show('confirm', title, content, options);
    }
    show(type, title, content, options) {
        const overlayRef = this.overlay.create();
        const messageBoxRef = new MessageBoxRef(type, overlayRef, title, content, options);
        const injector = this.createInjector(messageBoxRef, this.injector);
        overlayRef.attach(new ComponentPortal(NelMessageBoxComponent, null, injector));
        return messageBoxRef;
    }
    createInjector(ref, inj) {
        return Injector.create({
            parent: inj,
            providers: [{ provide: MessageBoxRef, useValue: ref }]
        });
    }
}
NelMessageBoxService.ɵprov = ɵɵdefineInjectable({ factory: function NelMessageBoxService_Factory() { return new NelMessageBoxService(ɵɵinject(Overlay), ɵɵinject(INJECTOR)); }, token: NelMessageBoxService, providedIn: "root" });
NelMessageBoxService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
NelMessageBoxService.ctorParameters = () => [
    { type: Overlay },
    { type: Injector }
];

class NelMessageBoxModule {
}
NelMessageBoxModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    NelMessageBoxComponent
                ],
                exports: [
                    NelMessageBoxComponent
                ],
                imports: [
                    CommonModule,
                    NelOutletModule
                ],
                providers: [
                    NelMessageBoxService
                ]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { NelMessageBoxComponent, NelMessageBoxModule, NelMessageBoxService, MessageBoxRef as ɵa };
//# sourceMappingURL=ng-element-ui-message-box.js.map
