import { Component, ViewChild, NgModule, Injector, ɵɵdefineInjectable, ɵɵinject, INJECTOR, Injectable } from '@angular/core';
import { messageMotion } from 'ng-element-ui/core/animation';
import { ComponentPortal } from '@angular/cdk/portal';
import { Overlay, OverlayModule } from '@angular/cdk/overlay';
import { Subject } from 'rxjs';
import { CommonModule } from '@angular/common';
import { NelOutletModule } from 'ng-element-ui/core/outlet';

class MessageRef {
    constructor(type, id, leave, overlay, nelContent, nelOptions) {
        this.type = type;
        this.id = id;
        this.leave = leave;
        this.overlay = overlay;
        this.nelContent = nelContent;
        this.nelOptions = nelOptions;
        this.height = 48;
        this.top = 0;
        this.componentInstance = null;
    }
    close() {
        this.componentInstance.state = 'done';
    }
}

class NelMessageComponent {
    constructor(messageRef) {
        this.messageRef = messageRef;
        this.id = 0;
        this.top = 36;
        this.showClose = false;
        this.duration = 3000;
        this.center = false;
        this.state = 'start';
    }
    ngOnDestroy() {
        if (this.timer) {
            clearTimeout(this.timer);
        }
    }
    ngOnInit() {
        this.type = this.messageRef.type;
        this.id = this.messageRef.id;
        this.top = this.messageRef.top;
        this.content = this.messageRef.nelContent;
        this.overlay = this.messageRef.overlay;
        if (this.messageRef.nelOptions) {
            if (this.messageRef.nelOptions.showClose) {
                this.showClose = this.messageRef.nelOptions.showClose;
            }
            if (this.messageRef.nelOptions.duration !== undefined) {
                this.duration = this.messageRef.nelOptions.duration;
            }
            if (this.messageRef.nelOptions.center) {
                this.center = this.messageRef.nelOptions.center;
            }
            if (this.messageRef.nelOptions.onClose) {
                this.onClose = this.messageRef.nelOptions.onClose;
            }
        }
        this.initTimer();
    }
    ngAfterViewInit() {
        this.messageRef.height = this.messageEle.nativeElement.offsetHeight;
    }
    initTimer() {
        if (this.duration > 0) {
            this.timer = setTimeout(() => {
                this.state = 'done';
            }, this.duration);
        }
    }
    onAnimationStart(event) {
        if (event.toState === 'done') {
            clearTimeout(this.timer);
            this.messageRef.leave.next(this.id);
        }
    }
    onAnimationDone(event) {
        if (event.toState === 'done') {
            this.overlay.dispose();
            if (this.onClose) {
                this.onClose();
            }
        }
    }
    mouseenter() {
        if (this.timer) {
            clearTimeout(this.timer);
        }
    }
    mouseleave() {
        this.initTimer();
    }
    close() {
        if (this.timer) {
            clearTimeout(this.timer);
        }
        this.state = 'done';
    }
}
NelMessageComponent.decorators = [
    { type: Component, args: [{
                selector: 'nel-message',
                template: "<div #messageEle class=\"el-message el-message--{{type}}\" [class.is-center]=\"center\" role=\"alert\"\r\n  [style.top]=\"top + 'px'\" [@messageMotion]=\"state\" (@messageMotion.start)=\"onAnimationStart($event)\"\r\n  (@messageMotion.done)=\"onAnimationDone($event)\" (mouseenter)=\"mouseenter()\" (mouseleave)=\"mouseleave()\">\r\n  <i class=\"el-message__icon el-icon-{{type}}\"></i>\r\n  <p class=\"el-message__content\">\r\n    <ng-container *stringTemplate=\"content\">{{content}}</ng-container>\r\n  </p>\r\n  <div *ngIf=\"showClose\" (click)=\"close()\" class=\"el-message__closeBtn el-icon-close\"></div>\r\n</div>\r\n",
                animations: [messageMotion]
            },] }
];
NelMessageComponent.ctorParameters = () => [
    { type: MessageRef }
];
NelMessageComponent.propDecorators = {
    messageEle: [{ type: ViewChild, args: ['messageEle', { static: false },] }]
};

class NelMessageServiceModule {
}
NelMessageServiceModule.decorators = [
    { type: NgModule }
];

class NelMessageService {
    constructor(overlay, injector) {
        this.overlay = overlay;
        this.injector = injector;
        this.messageId = 0;
        this.leave = new Subject();
        this.messageRefList = [];
        this._handlerLeave();
    }
    info(content, options) {
        return this.show('info', content, options);
    }
    success(content, options) {
        return this.show('success', content, options);
    }
    warning(content, options) {
        return this.show('warning', content, options);
    }
    error(content, options) {
        return this.show('error', content, options);
    }
    show(type, content, options) {
        this.messageId++;
        const overlayRef = this.overlay.create();
        const messageRef = new MessageRef(type, this.messageId, this.leave, overlayRef, content, options);
        const injector = this.createInjector(messageRef, this.injector);
        const componentRef = overlayRef.attach(new ComponentPortal(NelMessageComponent, null, injector));
        // 根据message列表，获取下一个message的top
        let top = 36;
        this.messageRefList.forEach(item => {
            top += item.height + 16;
        });
        this.messageRefList.push(messageRef);
        messageRef.top = top;
        messageRef.componentInstance = componentRef.instance;
        return messageRef;
    }
    createInjector(ref, inj) {
        return Injector.create({
            parent: inj,
            providers: [{ provide: MessageRef, useValue: ref }]
        });
    }
    _handlerLeave() {
        this.leave.subscribe((id) => {
            const componentIndex = this.messageRefList.findIndex(item => item.id === id);
            if (componentIndex > -1) {
                const height = this.messageRefList[componentIndex].height;
                if (componentIndex !== this.messageRefList.length - 1) {
                    for (let i = componentIndex + 1; i < this.messageRefList.length; i++) {
                        this.messageRefList[i].componentInstance.top -= height + 16;
                    }
                }
                this.messageRefList.splice(componentIndex, 1);
            }
        });
    }
}
NelMessageService.ɵprov = ɵɵdefineInjectable({ factory: function NelMessageService_Factory() { return new NelMessageService(ɵɵinject(Overlay), ɵɵinject(INJECTOR)); }, token: NelMessageService, providedIn: NelMessageServiceModule });
NelMessageService.decorators = [
    { type: Injectable, args: [{
                providedIn: NelMessageServiceModule
            },] }
];
NelMessageService.ctorParameters = () => [
    { type: Overlay },
    { type: Injector }
];

class NelMessageModule {
}
NelMessageModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    NelMessageComponent
                ],
                exports: [
                    NelMessageComponent
                ],
                imports: [
                    CommonModule,
                    OverlayModule,
                    NelOutletModule,
                    NelMessageServiceModule
                ]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { NelMessageComponent, NelMessageModule, NelMessageService, MessageRef as ɵa, NelMessageServiceModule as ɵb };
//# sourceMappingURL=ng-element-ui-message.js.map
