import { Component, ViewChild, Injector, ɵɵdefineInjectable, ɵɵinject, INJECTOR, Injectable, NgModule } from '@angular/core';
import { notificationMotion } from 'ng-element-ui/core/animation';
import { ComponentPortal } from '@angular/cdk/portal';
import { Overlay, OverlayModule } from '@angular/cdk/overlay';
import { Subject } from 'rxjs';
import { CommonModule } from '@angular/common';
import { NelOutletModule } from 'ng-element-ui/core/outlet';

class NelNotificationRef {
    constructor(type, id, leave, overlay, title, content, options) {
        this.type = type;
        this.id = id;
        this.leave = leave;
        this.overlay = overlay;
        this.title = title;
        this.content = content;
        this.options = options;
        this.height = 84;
        this.position = 'topRight';
        this.top = 0;
        this.bottom = 0;
        this.componentInstance = null;
    }
    close() {
        this.componentInstance.state = 'done';
    }
}

class NelNotificationComponent {
    constructor(notificationRef) {
        this.notificationRef = notificationRef;
        this.id = 0;
        this.top = 16;
        this.bottom = 16;
        this.showClose = true;
        this.duration = 3000;
        this.state = '';
    }
    ngOnDestroy() {
        if (this.timer) {
            clearTimeout(this.timer);
        }
    }
    ngOnInit() {
        this.type = this.notificationRef.type;
        this.id = this.notificationRef.id;
        this.position = this.notificationRef.position;
        this.top = this.notificationRef.top;
        this.bottom = this.notificationRef.bottom;
        this.title = this.notificationRef.title;
        this.content = this.notificationRef.content;
        this.overlay = this.notificationRef.overlay;
        if (this.notificationRef.options) {
            if (this.notificationRef.options.duration !== undefined) {
                this.duration = this.notificationRef.options.duration;
            }
            if (this.notificationRef.options.showClose !== undefined) {
                this.showClose = this.notificationRef.options.showClose;
            }
            if (this.notificationRef.options.onClose) {
                this.onClose = this.notificationRef.options.onClose;
            }
        }
        if (this.position === 'topRight' || this.position === 'bottomRight') {
            this.state = 'rightInto';
        }
        else {
            this.state = 'leftInto';
        }
        this.initTimer();
    }
    ngAfterViewInit() {
        this.notificationRef.height = this.notificationEle.nativeElement.offsetHeight;
    }
    initTimer() {
        if (this.duration > 0) {
            this.timer = setTimeout(() => {
                this.state = 'leave';
            }, this.duration);
        }
    }
    onAnimationStart(event) {
        if (event.toState === 'leave') {
            clearTimeout(this.timer);
            this.notificationRef.leave.next({ id: this.id, position: this.position });
        }
    }
    onAnimationDone(event) {
        if (event.toState === 'leave') {
            this.overlay.dispose();
            if (this.onClose) {
                this.onClose();
            }
        }
    }
    mouseenter() {
        if (this.timer) {
            clearTimeout(this.timer);
        }
    }
    mouseleave() {
        this.initTimer();
    }
    close() {
        if (this.timer) {
            clearTimeout(this.timer);
        }
        this.state = 'leave';
    }
}
NelNotificationComponent.decorators = [
    { type: Component, args: [{
                selector: 'nel-notification',
                template: "<div #notificationEle class=\"el-notification\" [class.right]=\"position == 'topRight' || position == 'bottomRight'\"\r\n  [class.left]=\"position == 'topLeft' || position == 'bottomLeft'\" role=\"alert\" style=\"top: 16px\"\r\n  [style.top]=\"top ? top + 'px' : ''\" [style.bottom]=\"bottom ? bottom + 'px' : ''\" [@notificationMotion]=\"state\"\r\n  (@notificationMotion.start)=\"onAnimationStart($event)\" (@notificationMotion.done)=\"onAnimationDone($event)\"\r\n  (mouseenter)=\"mouseenter()\" (mouseleave)=\"mouseleave()\">\r\n  <i *ngIf=\"type != 'blank'\" class=\"el-notification__icon el-icon-{{type}}\"></i>\r\n  <div class=\"el-notification__group\">\r\n    <h2 class=\"el-notification__title\">\r\n      <ng-container *stringTemplate=\"title\">{{title}}</ng-container>\r\n    </h2>\r\n    <div class=\"el-notification__content\">\r\n      <ng-container *stringTemplate=\"content\">{{content}}</ng-container>\r\n    </div>\r\n    <div *ngIf=\"showClose\" (click)=\"close()\" class=\"el-notification__closeBtn el-icon-close\"></div>\r\n  </div>\r\n</div>\r\n",
                animations: [notificationMotion]
            },] }
];
NelNotificationComponent.ctorParameters = () => [
    { type: NelNotificationRef }
];
NelNotificationComponent.propDecorators = {
    notificationEle: [{ type: ViewChild, args: ['notificationEle', { static: false },] }]
};

class NelNotificationService {
    constructor(overlay, injector) {
        this.overlay = overlay;
        this.injector = injector;
        this.notificationId = 0;
        this.leave = new Subject();
        this.notificationRefList = {
            topRight: [],
            bottomRight: [],
            topLeft: [],
            bottomLeft: []
        };
        this._handlerLeave();
    }
    blank(title, content, options) {
        return this.show('blank', title, content, options);
    }
    success(title, content, options) {
        return this.show('success', title, content, options);
    }
    warning(title, content, options) {
        return this.show('warning', title, content, options);
    }
    info(title, content, options) {
        return this.show('info', title, content, options);
    }
    error(title, content, options) {
        return this.show('error', title, content, options);
    }
    show(type, title, content, options) {
        this.notificationId++;
        const overlayRef = this.overlay.create();
        const notificationRef = new NelNotificationRef(type, this.notificationId, this.leave, overlayRef, title, content, options);
        const injector = this.createInjector(notificationRef, this.injector);
        const componentRef = overlayRef.attach(new ComponentPortal(NelNotificationComponent, null, injector));
        // 根据notification，获取下一个notification的top
        let top = 16;
        let bottom = 16;
        let key = 'topRight';
        if (options) {
            if (options.offset) {
                top += options.offset;
                bottom += options.offset;
            }
            if (options.position) {
                switch (options.position) {
                    case 'bottom-right':
                        key = 'bottomRight';
                        break;
                    case 'top-left':
                        key = 'topLeft';
                        break;
                    case 'bottom-left':
                        key = 'bottomLeft';
                        break;
                }
            }
        }
        if (key === 'topRight' || key === 'topLeft') {
            bottom = 0;
            this.notificationRefList[key].forEach(item => {
                top += item.height + 16;
            });
        }
        else {
            top = 0;
            this.notificationRefList[key].forEach(item => {
                bottom += item.height + 16;
            });
        }
        this.notificationRefList[key].push(notificationRef);
        notificationRef.position = key;
        notificationRef.top = top;
        notificationRef.bottom = bottom;
        notificationRef.componentInstance = componentRef.instance;
        return notificationRef;
    }
    createInjector(ref, inj) {
        return Injector.create({
            parent: inj,
            providers: [{ provide: NelNotificationRef, useValue: ref }]
        });
    }
    _handlerLeave() {
        this.leave.subscribe((val) => {
            const componentIndex = this.notificationRefList[val.position].findIndex(item => item.id === val.id);
            if (componentIndex > -1) {
                const height = this.notificationRefList[val.position][componentIndex].height;
                if (componentIndex !== this.notificationRefList[val.position].length - 1) {
                    for (let i = componentIndex + 1; i < this.notificationRefList[val.position].length; i++) {
                        this.notificationRefList[val.position][i].componentInstance.top -= height + 16;
                    }
                }
                this.notificationRefList[val.position].splice(componentIndex, 1);
            }
        });
    }
}
NelNotificationService.ɵprov = ɵɵdefineInjectable({ factory: function NelNotificationService_Factory() { return new NelNotificationService(ɵɵinject(Overlay), ɵɵinject(INJECTOR)); }, token: NelNotificationService, providedIn: "root" });
NelNotificationService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
NelNotificationService.ctorParameters = () => [
    { type: Overlay },
    { type: Injector }
];

class NelNotificationModule {
}
NelNotificationModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    NelNotificationComponent
                ],
                exports: [
                    NelNotificationComponent
                ],
                imports: [
                    CommonModule,
                    OverlayModule,
                    NelOutletModule
                ],
                providers: [
                    NelNotificationService
                ]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { NelNotificationComponent, NelNotificationModule, NelNotificationService, NelNotificationRef as ɵa };
//# sourceMappingURL=ng-element-ui-notification.js.map
