import { Component, EventEmitter, Directive, ViewContainerRef, ElementRef, ComponentFactoryResolver, Renderer2, Input, Output, HostListener, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { OverlayModule } from '@angular/cdk/overlay';
import { NelButtonModule } from 'ng-element-ui/button';
import { NelIconModule } from 'ng-element-ui/icon';

class NelPopconfirmComponent {
    constructor() {
        this.isOpen = false;
        this.arrowLeft = '';
        this.arrowRight = '';
        this.arrowTop = '';
        this.arrowBottom = '';
        this.transform = '';
    }
    close() {
        this.isOpen = false;
    }
    cancel() {
        this.isOpen = false;
        if (this.onCancel) {
            this.onCancel.emit();
        }
    }
    confirm() {
        this.isOpen = false;
        if (this.onConfirm) {
            this.onConfirm.emit();
        }
    }
}
NelPopconfirmComponent.decorators = [
    { type: Component, args: [{
                selector: 'nel-popconfirm',
                template: "<ng-template cdkConnectedOverlay [cdkConnectedOverlayOrigin]=\"trigger\" [cdkConnectedOverlayOpen]=\"isOpen\"\r\n  [cdkConnectedOverlayPositions]=\"positionStrategy\" (overlayOutsideClick)=\"close()\">\r\n  <div class=\"el-popover el-popper is-light\">\r\n    <div class=\"el-popconfirm\">\r\n      <p class=\"el-popconfirm__main\">\r\n        <i *ngIf=\"!hideIcon\" nel-icon [nelType]=\"icon\" class=\"el-popconfirm__icon\" [style.color]=\"iconColor\"></i>\r\n        {{title}}\r\n      </p>\r\n      <div class=\"el-popconfirm__action\">\r\n        <button nel-button [nelType]=\"cancelButtonType\" [nelSize]=\"'mini'\" (click)=\"cancel()\">\r\n          {{cancelButtonText}}\r\n        </button>\r\n        <button nel-button [nelType]=\"confirmButtonType\" [nelSize]=\"'mini'\" (click)=\"confirm()\">\r\n          {{confirmButtonText}}\r\n        </button>\r\n      </div>\r\n    </div>\r\n    <div class=\"el-popper__arrow\" [style.left]=\"arrowLeft\" [style.right]=\"arrowRight\" [style.top]=\"arrowTop\"\r\n      [style.bottom]=\"arrowBottom\" [style.transform]=\"transform\"></div>\r\n  </div>\r\n</ng-template>\r\n"
            },] }
];

class NelPopconfirmDirective {
    constructor(hostView, elementRef, resolver, renderer) {
        this.hostView = hostView;
        this.elementRef = elementRef;
        this.resolver = resolver;
        this.renderer = renderer;
        this.nelPlacement = 'bottom';
        this.nelConfirmButtonText = '确认';
        this.nelCancelButtonText = '取消';
        this.nelConfirmButtonType = 'primary';
        this.nelCancelButtonType = 'text';
        this.nelIcon = 'question';
        this.nelIconColor = '#f90';
        this.nelHideIcon = false;
        this.nelOnCancel = new EventEmitter();
        this.nelOnConfirm = new EventEmitter();
        this.componentFactory = this.resolver.resolveComponentFactory(NelPopconfirmComponent);
        const componentRef = this.hostView.createComponent(this.componentFactory);
        this.component = componentRef.instance;
        this.renderer.removeChild(this.renderer.parentNode(this.elementRef.nativeElement), componentRef.location.nativeElement);
    }
    onClick() {
        this.show();
    }
    show() {
        const position = {
            originX: 'start',
            originY: 'top',
            overlayX: 'start',
            overlayY: 'bottom',
            offsetX: 0,
            offsetY: 0,
        };
        let arrowLeft = '';
        let arrowRight = '';
        let arrowTop = '';
        let arrowBottom = '';
        let transform = '';
        switch (this.nelPlacement) {
            case 'top-start':
                position.originX = 'start';
                position.originY = 'top';
                position.overlayX = 'start';
                position.overlayY = 'bottom';
                position.offsetY = -10;
                arrowLeft = '0';
                transform = 'translate(30px, 5px)';
                break;
            case 'top':
                position.originX = 'center';
                position.originY = 'top';
                position.overlayX = 'center';
                position.overlayY = 'bottom';
                position.offsetY = -10;
                arrowLeft = '50%';
                transform = 'translate(-50%, 5px)';
                break;
            case 'top-end':
                position.originX = 'end';
                position.originY = 'top';
                position.overlayX = 'end';
                position.overlayY = 'bottom';
                position.offsetY = -10;
                arrowLeft = '50%';
                transform = 'translate(30px, 5px)';
                break;
            case 'bottom-start':
                position.originX = 'start';
                position.originY = 'bottom';
                position.overlayX = 'start';
                position.overlayY = 'top';
                position.offsetY = 10;
                arrowLeft = '0';
                arrowTop = '-10px';
                transform = 'translate(30px, 5px)';
                break;
            case 'bottom':
                position.originX = 'center';
                position.originY = 'bottom';
                position.overlayX = 'center';
                position.overlayY = 'top';
                position.offsetY = 10;
                arrowLeft = '50%';
                arrowTop = '-10px';
                transform = 'translate(-50%, 5px)';
                break;
            case 'bottom-end':
                position.originX = 'end';
                position.originY = 'bottom';
                position.overlayX = 'end';
                position.overlayY = 'top';
                position.offsetY = 10;
                arrowLeft = '50%';
                arrowTop = '-10px';
                transform = 'translate(30px, 5px)';
                break;
            case 'left-start':
                position.originX = 'start';
                position.originY = 'top';
                position.overlayX = 'end';
                position.overlayY = 'top';
                position.offsetX = -10;
                arrowRight = '0';
                arrowTop = '0';
                transform = 'translate(5px, 15px)';
                break;
            case 'left':
                position.originX = 'start';
                position.originY = 'center';
                position.overlayX = 'end';
                position.overlayY = 'center';
                position.offsetX = -10;
                arrowRight = '0';
                arrowTop = '50%';
                transform = 'translate(5px, -50%)';
                break;
            case 'left-end':
                position.originX = 'start';
                position.originY = 'bottom';
                position.overlayX = 'end';
                position.overlayY = 'bottom';
                position.offsetX = -10;
                arrowRight = '0';
                arrowBottom = '0';
                transform = 'translate(5px, -15px)';
                break;
            case 'right-start':
                position.originX = 'end';
                position.originY = 'top';
                position.overlayX = 'start';
                position.overlayY = 'top';
                position.offsetX = 10;
                arrowLeft = '0';
                arrowTop = '0';
                transform = 'translate(-5px, 15px)';
                break;
            case 'right':
                position.originX = 'end';
                position.originY = 'center';
                position.overlayX = 'start';
                position.overlayY = 'center';
                position.offsetX = 10;
                arrowLeft = '0';
                arrowTop = '50%';
                transform = 'translate(-5px, -50%)';
                break;
            case 'right-end':
                position.originX = 'end';
                position.originY = 'bottom';
                position.overlayX = 'start';
                position.overlayY = 'bottom';
                position.offsetX = 10;
                arrowLeft = '0';
                arrowBottom = '0';
                transform = 'translate(-5px, -15px)';
                break;
        }
        if (this.component) {
            this.component.title = this.nelPopconfirmTitle;
            this.component.onCancel = this.nelOnCancel;
            this.component.onConfirm = this.nelOnConfirm;
            this.component.confirmButtonText = this.nelConfirmButtonText;
            this.component.cancelButtonText = this.nelCancelButtonText;
            this.component.confirmButtonType = this.nelConfirmButtonType;
            this.component.cancelButtonType = this.nelCancelButtonType;
            this.component.icon = this.nelIcon;
            this.component.iconColor = this.nelIconColor;
            this.component.hideIcon = this.nelHideIcon;
            this.component.trigger = { elementRef: this.elementRef };
            this.component.isOpen = true;
            this.component.positionStrategy = [position];
            this.component.arrowLeft = arrowLeft;
            this.component.arrowRight = arrowRight;
            this.component.arrowTop = arrowTop;
            this.component.arrowBottom = arrowBottom;
            this.component.transform = transform;
        }
    }
}
NelPopconfirmDirective.decorators = [
    { type: Directive, args: [{
                selector: '[nel-popconfirm]'
            },] }
];
NelPopconfirmDirective.ctorParameters = () => [
    { type: ViewContainerRef },
    { type: ElementRef },
    { type: ComponentFactoryResolver },
    { type: Renderer2 }
];
NelPopconfirmDirective.propDecorators = {
    nelPopconfirmTitle: [{ type: Input }],
    nelPlacement: [{ type: Input }],
    nelConfirmButtonText: [{ type: Input }],
    nelCancelButtonText: [{ type: Input }],
    nelConfirmButtonType: [{ type: Input }],
    nelCancelButtonType: [{ type: Input }],
    nelIcon: [{ type: Input }],
    nelIconColor: [{ type: Input }],
    nelHideIcon: [{ type: Input }],
    nelOnCancel: [{ type: Output }],
    nelOnConfirm: [{ type: Output }],
    onClick: [{ type: HostListener, args: ['click', ['$event.target'],] }]
};

class NelPopconfirmModule {
}
NelPopconfirmModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    NelPopconfirmDirective,
                    NelPopconfirmComponent
                ],
                exports: [
                    NelPopconfirmDirective,
                    NelPopconfirmComponent
                ],
                imports: [
                    CommonModule,
                    OverlayModule,
                    NelButtonModule,
                    NelIconModule
                ]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { NelPopconfirmDirective, NelPopconfirmModule, NelPopconfirmComponent as ɵa };
//# sourceMappingURL=ng-element-ui-popconfirm.js.map
