import { EventEmitter, Component, Output, Directive, ViewContainerRef, ElementRef, ComponentFactoryResolver, Renderer2, Input, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { OverlayModule } from '@angular/cdk/overlay';
import { NelOutletModule } from 'ng-element-ui/core/outlet';

class NelPopoverComponent {
    constructor() {
        this.visibleChange = new EventEmitter();
        this.isOpen = false;
        this.arrowLeft = '';
        this.arrowRight = '';
        this.arrowTop = '';
        this.arrowBottom = '';
        this.transform = '';
    }
    onClickOutside(event) {
        // 触发点击事件的dom，不在origin内，方才关闭
        if (!this.origin.elementRef.nativeElement.contains(event.target) && this.trigger !== 'manual') {
            this.isOpen = false;
            this.visibleChange.emit(false);
        }
    }
    close() {
        this.isOpen = false;
    }
}
NelPopoverComponent.decorators = [
    { type: Component, args: [{
                selector: 'nel-popover',
                template: "<ng-template cdkConnectedOverlay [cdkConnectedOverlayOrigin]=\"origin\" [cdkConnectedOverlayOpen]=\"isOpen\"\r\n  [cdkConnectedOverlayPositions]=\"positionStrategy\" [cdkConnectedOverlayMinWidth]=\"150\"\r\n  [cdkConnectedOverlayWidth]=\"width!\" (overlayOutsideClick)=\"onClickOutside($event)\">\r\n  <div class=\"el-popover--plain el-popover el-popper is-light\" role=\"tooltip\"\r\n    [style.width]=\"width ? (width! + 'px') : ''\">\r\n    <div *ngIf=\"title\" class=\"el-popover__title\" role=\"title\">{{title}}</div>\r\n    <ng-container *stringTemplate=\"content!\">{{content!}}</ng-container>\r\n    <div class=\"el-popper__arrow\" [style.left]=\"arrowLeft\" [style.right]=\"arrowRight\" [style.top]=\"arrowTop\"\r\n      [style.bottom]=\"arrowBottom\" [style.transform]=\"transform\"></div>\r\n  </div>\r\n</ng-template>\r\n"
            },] }
];
NelPopoverComponent.propDecorators = {
    visibleChange: [{ type: Output }]
};

class NelPopoverDirective {
    constructor(hostView, elementRef, resolver, renderer) {
        this.hostView = hostView;
        this.elementRef = elementRef;
        this.resolver = resolver;
        this.renderer = renderer;
        this.nelPopoverTrigger = 'click';
        this.nelPopoverPlacement = 'bottom';
        this.nelPopoverVisibleChange = new EventEmitter();
        this.triggerDisposables = [];
        this.componentFactory = this.resolver.resolveComponentFactory(NelPopoverComponent);
        const componentRef = this.hostView.createComponent(this.componentFactory);
        this.component = componentRef.instance;
        this.renderer.removeChild(this.renderer.parentNode(this.elementRef.nativeElement), componentRef.location.nativeElement);
    }
    set nelPopoverVisible(val) {
        if (val) {
            if (this.component) {
                this.show();
            }
        }
        else {
            this.hide();
        }
    }
    ngOnDestroy() {
        this.removeTriggerListeners();
    }
    ngOnInit() {
        this.trigger();
    }
    trigger() {
        if (this.nelPopoverTrigger === 'click') {
            this.triggerDisposables.push(this.renderer.listen(this.elementRef.nativeElement, 'click', () => this.show()));
        }
        else if (this.nelPopoverTrigger === 'focus') {
            this.triggerDisposables.push(this.renderer.listen(this.elementRef.nativeElement, 'focus', () => this.show()));
            this.triggerDisposables.push(this.renderer.listen(this.elementRef.nativeElement, 'blur', () => this.hide()));
        }
        else if (this.nelPopoverTrigger === 'hover') {
            this.triggerDisposables.push(this.renderer.listen(this.elementRef.nativeElement, 'mouseenter', () => this.show()));
            this.triggerDisposables.push(this.renderer.listen(this.elementRef.nativeElement, 'mouseleave', () => this.hide()));
        }
    }
    removeTriggerListeners() {
        this.triggerDisposables.forEach(dispose => dispose());
        this.triggerDisposables.length = 0;
    }
    show() {
        const position = {
            originX: 'start',
            originY: 'top',
            overlayX: 'start',
            overlayY: 'bottom',
            offsetX: 0,
            offsetY: 0,
        };
        let arrowLeft = '';
        let arrowRight = '';
        let arrowTop = '';
        let arrowBottom = '';
        let transform = '';
        switch (this.nelPopoverPlacement) {
            case 'top-start':
                position.originX = 'start';
                position.originY = 'top';
                position.overlayX = 'start';
                position.overlayY = 'bottom';
                position.offsetY = -10;
                arrowLeft = '0';
                transform = 'translate(30px, 5px)';
                break;
            case 'top':
                position.originX = 'center';
                position.originY = 'top';
                position.overlayX = 'center';
                position.overlayY = 'bottom';
                position.offsetY = -10;
                arrowLeft = '50%';
                transform = 'translate(-50%, 5px)';
                break;
            case 'top-end':
                position.originX = 'end';
                position.originY = 'top';
                position.overlayX = 'end';
                position.overlayY = 'bottom';
                position.offsetY = -10;
                arrowLeft = '50%';
                transform = 'translate(30px, 5px)';
                break;
            case 'bottom-start':
                position.originX = 'start';
                position.originY = 'bottom';
                position.overlayX = 'start';
                position.overlayY = 'top';
                position.offsetY = 10;
                arrowLeft = '0';
                arrowTop = '-10px';
                transform = 'translate(30px, 5px)';
                break;
            case 'bottom':
                position.originX = 'center';
                position.originY = 'bottom';
                position.overlayX = 'center';
                position.overlayY = 'top';
                position.offsetY = 10;
                arrowLeft = '50%';
                arrowTop = '-10px';
                transform = 'translate(-50%, 5px)';
                break;
            case 'bottom-end':
                position.originX = 'end';
                position.originY = 'bottom';
                position.overlayX = 'end';
                position.overlayY = 'top';
                position.offsetY = 10;
                arrowLeft = '50%';
                arrowTop = '-10px';
                transform = 'translate(30px, 5px)';
                break;
            case 'left-start':
                position.originX = 'start';
                position.originY = 'top';
                position.overlayX = 'end';
                position.overlayY = 'top';
                position.offsetX = -10;
                arrowRight = '0';
                arrowTop = '0';
                transform = 'translate(5px, 15px)';
                break;
            case 'left':
                position.originX = 'start';
                position.originY = 'center';
                position.overlayX = 'end';
                position.overlayY = 'center';
                position.offsetX = -10;
                arrowRight = '0';
                arrowTop = '50%';
                transform = 'translate(5px, -50%)';
                break;
            case 'left-end':
                position.originX = 'start';
                position.originY = 'bottom';
                position.overlayX = 'end';
                position.overlayY = 'bottom';
                position.offsetX = -10;
                arrowRight = '0';
                arrowBottom = '0';
                transform = 'translate(5px, -15px)';
                break;
            case 'right-start':
                position.originX = 'end';
                position.originY = 'top';
                position.overlayX = 'start';
                position.overlayY = 'top';
                position.offsetX = 10;
                arrowLeft = '0';
                arrowTop = '0';
                transform = 'translate(-5px, 15px)';
                break;
            case 'right':
                position.originX = 'end';
                position.originY = 'center';
                position.overlayX = 'start';
                position.overlayY = 'center';
                position.offsetX = 10;
                arrowLeft = '0';
                arrowTop = '50%';
                transform = 'translate(-5px, -50%)';
                break;
            case 'right-end':
                position.originX = 'end';
                position.originY = 'bottom';
                position.overlayX = 'start';
                position.overlayY = 'bottom';
                position.offsetX = 10;
                arrowLeft = '0';
                arrowBottom = '0';
                transform = 'translate(-5px, -15px)';
                break;
        }
        if (this.component) {
            this.component.title = this.nelPopoverTitle;
            this.component.content = this.nelPopoverContent;
            this.component.width = this.nelPopoverWidth;
            this.component.trigger = this.nelPopoverTrigger;
            this.component.visibleChange = this.nelPopoverVisibleChange;
            this.component.origin = { elementRef: this.elementRef };
            this.component.isOpen = true;
            this.component.positionStrategy = [position];
            this.component.arrowLeft = arrowLeft;
            this.component.arrowRight = arrowRight;
            this.component.arrowTop = arrowTop;
            this.component.arrowBottom = arrowBottom;
            this.component.transform = transform;
            this.nelPopoverVisibleChange.emit(true);
        }
    }
    hide() {
        var _a;
        (_a = this.component) === null || _a === void 0 ? void 0 : _a.close();
    }
}
NelPopoverDirective.decorators = [
    { type: Directive, args: [{
                selector: '[nel-popover]',
            },] }
];
NelPopoverDirective.ctorParameters = () => [
    { type: ViewContainerRef },
    { type: ElementRef },
    { type: ComponentFactoryResolver },
    { type: Renderer2 }
];
NelPopoverDirective.propDecorators = {
    nelPopoverTitle: [{ type: Input }],
    nelPopoverContent: [{ type: Input }],
    nelPopoverWidth: [{ type: Input }],
    nelPopoverTrigger: [{ type: Input }],
    nelPopoverPlacement: [{ type: Input }],
    nelPopoverVisible: [{ type: Input }],
    nelPopoverVisibleChange: [{ type: Output }]
};

class NelPopoverModule {
}
NelPopoverModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    NelPopoverDirective,
                    NelPopoverComponent
                ],
                exports: [
                    NelPopoverDirective,
                    NelPopoverComponent
                ],
                imports: [
                    CommonModule,
                    OverlayModule,
                    NelOutletModule
                ]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { NelPopoverComponent, NelPopoverDirective, NelPopoverModule };
//# sourceMappingURL=ng-element-ui-popover.js.map
