import { TemplateRef, Component, Input, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { NelOutletModule } from 'ng-element-ui/core/outlet';
import { NelIconModule } from 'ng-element-ui/icon';

const defaultFormatter = (p) => `${p}%`;
const ɵ0 = defaultFormatter;
class NelProgressComponent {
    constructor() {
        this.nelPercentage = 0;
        this.nelStrokeWidth = 6;
        this.nelTextInside = false;
        this.nelType = 'line';
        this.nelWidth = 126;
        this.nelStrokeLinecap = 'round';
        this.nelIndeterminate = false;
        this.nelDuration = 3;
    }
    get formatter() {
        return this.nelFormat || defaultFormatter;
    }
    get formatterText() {
        const isTemplateRef = this.nelFormat instanceof TemplateRef;
        if (isTemplateRef) {
            return defaultFormatter;
        }
        else {
            return this.nelFormat || defaultFormatter;
        }
    }
    get relativeStrokeWidth() {
        return (this.nelStrokeWidth / this.nelWidth * 100).toFixed(1);
    }
    get radius() {
        if (this.nelType === 'circle' || this.nelType === 'dashboard') {
            return parseInt(`${50 - parseFloat(this.relativeStrokeWidth) / 2}`, 10);
        }
        else {
            return 0;
        }
    }
    get trackPath() {
        const r = this.radius;
        const isDashboard = this.nelType === 'dashboard';
        return `
        M 50 50
        m 0 ${isDashboard ? '' : '-'}${r}
        a ${r} ${r} 0 1 1 0 ${isDashboard ? '-' : ''}${r * 2}
        a ${r} ${r} 0 1 1 0 ${isDashboard ? '' : '-'}${r * 2}
        `;
    }
    get perimeter() {
        return 2 * Math.PI * this.radius;
    }
    get rate() {
        return this.nelType === 'dashboard' ? 0.75 : 1;
    }
    get strokeDashoffset() {
        const offset = -1 * this.perimeter * (1 - this.rate) / 2;
        return `${offset}px`;
    }
    get trailPathStyle() {
        return {
            strokeDasharray: `${(this.perimeter * this.rate)}px, ${this.perimeter}px`,
            strokeDashoffset: this.strokeDashoffset,
        };
    }
    get circlePathStyle() {
        return {
            strokeDasharray: `${this.perimeter * this.rate * (this.nelPercentage / 100)}px, ${this.perimeter}px`,
            strokeDashoffset: this.strokeDashoffset,
            transition: 'stroke-dasharray 0.6s ease 0s, stroke 0.6s ease',
        };
    }
    get stroke() {
        let ret;
        if (this.nelColor) {
            ret = this.getCurrentColor();
        }
        else {
            switch (this.nelStatus) {
                case 'success':
                    ret = '#13ce66';
                    break;
                case 'exception':
                    ret = '#ff4949';
                    break;
                case 'warning':
                    ret = '#e6a23c';
                    break;
                default:
                    ret = '#20a0ff';
            }
        }
        return ret;
    }
    ngOnInit() {
        if (this.nelType === 'circle') {
        }
    }
    getCurrentColor() {
        var _a;
        if (this.nelColor) {
            if (this.nelColor === 'string') {
                return this.nelColor;
            }
            else if (this.nelColor instanceof Function) {
                return this.nelColor(this.nelPercentage);
            }
            else if (this.nelColor instanceof Array) {
                const span = 100 / this.nelColor.length;
                const seriesColors = this.nelColor.map((seriesColor, index) => {
                    if (typeof seriesColor === 'string') {
                        return {
                            color: seriesColor,
                            percentage: (index + 1) * span,
                        };
                    }
                    return seriesColor;
                });
                const colorArray = seriesColors.sort((a, b) => a.percentage - b.percentage);
                for (const colorItem of colorArray) {
                    if (colorItem.percentage > this.nelPercentage) {
                        return colorItem.color;
                    }
                }
                return (_a = colorArray[colorArray.length - 1]) === null || _a === void 0 ? void 0 : _a.color;
            }
        }
        return null;
    }
}
NelProgressComponent.decorators = [
    { type: Component, args: [{
                selector: 'nel-progress',
                template: "<div class=\"el-progress\" [class.el-progress--line]=\"nelType == 'line'\" [class.el-progress--circle]=\"nelType == 'circle'\"\r\n  [class.el-progress--dashboard]=\"nelType == 'dashboard'\" [class.is-success]=\"nelStatus == 'success'\"\r\n  [class.is-exception]=\"nelStatus == 'exception'\" [class.is-warning]=\"nelStatus == 'warning'\" role=\"progressbar\">\r\n  <!-- bar -->\r\n  <ng-container *ngIf=\"nelType == 'line'; else circleDashboard\">\r\n    <div class=\"el-progress-bar\">\r\n      <div class=\"el-progress-bar__outer\" [style.height]=\"nelStrokeWidth + 'px'\">\r\n        <div class=\"el-progress-bar__inner\" [class.el-progress-bar__inner--indeterminate]=\"nelIndeterminate\"\r\n          [style.width]=\"nelPercentage + '%'\" [style.animation-duration]=\"nelDuration + 's'\"\r\n          [style.background-color]=\"getCurrentColor()\">\r\n          <div *ngIf=\"nelTextInside\" class=\"el-progress-bar__innerText\">\r\n            <ng-template *ngTemplateOutlet=\"formatTemplate\"></ng-template>\r\n          </div>\r\n        </div>\r\n      </div>\r\n    </div>\r\n    <div *ngIf=\"!nelTextInside\" class=\"el-progress__text\" style=\"font-size: 14.4px;\">\r\n      <ng-template *ngTemplateOutlet=\"textTpl\"></ng-template>\r\n    </div>\r\n  </ng-container>\r\n  <!-- circle or dashboard -->\r\n  <ng-template #circleDashboard>\r\n    <div class=\"el-progress-circle\" [style.height]=\"nelWidth + 'px'\" [style.width]=\"nelWidth + 'px'\">\r\n      <svg viewBox=\"0 0 100 100\">\r\n        <path class=\"el-progress-circle__track\" [attr.d]=\"trackPath\" stroke=\"#e5e9f2\"\r\n          [attr.stroke-width]=\"relativeStrokeWidth\" fill=\"none\" [style]=\"trailPathStyle\"></path>\r\n        <path class=\"el-progress-circle__path\" [attr.d]=\"trackPath\" [attr.stroke]=\"stroke\" fill=\"none\"\r\n          [attr.stroke-linecap]=\"nelStrokeLinecap\" [attr.stroke-width]=\"nelPercentage ? relativeStrokeWidth : 0\"\r\n          [style]=\"circlePathStyle\">\r\n        </path>\r\n      </svg>\r\n    </div>\r\n    <div class=\"el-progress__text\" style=\"font-size: 16px;\">\r\n      <ng-template *ngTemplateOutlet=\"textTpl\"></ng-template>\r\n    </div>\r\n  </ng-template>\r\n  <ng-template #textTpl>\r\n    <ng-container\r\n      *ngIf=\"(nelStatus === 'success' || nelStatus === 'exception' || nelStatus === 'warning') && !nelFormat; else formatTemplate\">\r\n      <ng-container [ngSwitch]=\"nelStatus\">\r\n        <i *ngSwitchCase=\"'success'\" nel-icon [nelType]=\"nelType == 'line' ? 'circle-check' : 'check'\"></i>\r\n        <i *ngSwitchCase=\"'warning'\" nel-icon [nelType]=\"'warning'\"></i>\r\n        <i *ngSwitchCase=\"'exception'\" nel-icon [nelType]=\"nelType == 'line' ? 'circle-close' : 'close'\"></i>\r\n      </ng-container>\r\n    </ng-container>\r\n  </ng-template>\r\n  <ng-template #formatTemplate>\r\n    <span>\r\n      <ng-container *stringTemplate=\"formatter; context: { $implicit: nelPercentage }\">\r\n        {{ formatterText(nelPercentage) }}\r\n      </ng-container>\r\n    </span>\r\n  </ng-template>\r\n</div>\r\n"
            },] }
];
NelProgressComponent.propDecorators = {
    nelPercentage: [{ type: Input }],
    nelFormat: [{ type: Input }],
    nelStatus: [{ type: Input }],
    nelStrokeWidth: [{ type: Input }],
    nelTextInside: [{ type: Input }],
    nelColor: [{ type: Input }],
    nelType: [{ type: Input }],
    nelWidth: [{ type: Input }],
    nelStrokeLinecap: [{ type: Input }],
    nelIndeterminate: [{ type: Input }],
    nelDuration: [{ type: Input }]
};

class NelProgressModule {
}
NelProgressModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    NelProgressComponent
                ],
                exports: [
                    NelProgressComponent
                ],
                imports: [
                    CommonModule,
                    NelOutletModule,
                    NelIconModule
                ]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { NelProgressComponent, NelProgressModule, ɵ0 };
//# sourceMappingURL=ng-element-ui-progress.js.map
