import { __decorate } from 'tslib';
import { Injectable, Component, ChangeDetectionStrategy, forwardRef, Optional, ChangeDetectorRef, Input, ViewChild, ContentChildren, NgModule } from '@angular/core';
import { NG_VALUE_ACCESSOR } from '@angular/forms';
import { InputBoolean } from 'ng-element-ui/core/utils';
import { ReplaySubject } from 'rxjs';

class NelRadioService {
    constructor() {
        this.selected$ = new ReplaySubject(1);
    }
    select(value) {
        this.selected$.next(value);
    }
}
NelRadioService.decorators = [
    { type: Injectable }
];

class NelRadioComponent {
    constructor(radio, cdr) {
        this.radio = radio;
        this.cdr = cdr;
        this.isChecked = false;
        this.nelDisabled = false;
        this.nelBorder = false;
        this.change = (value) => { };
    }
    onHostClick(event) {
        event.stopPropagation();
        event.preventDefault();
        if (!this.nelDisabled) {
            this.data = this.nelValue;
            this.isChecked = this.data === this.nelValue;
            this.change(this.nelValue);
            if (this.radio) {
                this.radio.select(this.nelValue);
            }
        }
    }
    changeView() {
        this.cdr.detectChanges();
    }
    writeValue(val) {
        this.data = val;
        this.isChecked = this.data === this.nelValue;
        this.cdr.detectChanges();
    }
    registerOnChange(fn) {
        this.change = fn;
    }
    registerOnTouched(fn) { }
}
NelRadioComponent.decorators = [
    { type: Component, args: [{
                selector: '[nel-radio]',
                template: "<span class=\"el-radio__input\" [class.is-checked]=\"data == nelValue\" [class.is-disabled]=\"nelDisabled\">\r\n  <span class=\"el-radio__inner\"></span>\r\n  <input class=\"el-radio__original\" type=\"radio\" [value]=\"nelValue\" name=\"\" tabindex=\"-1\">\r\n</span>\r\n<span class=\"el-radio__label\">\r\n  <ng-content></ng-content>\r\n</span>\r\n",
                changeDetection: ChangeDetectionStrategy.OnPush,
                providers: [{
                        provide: NG_VALUE_ACCESSOR,
                        useExisting: forwardRef(() => NelRadioComponent),
                        multi: true
                    }],
                host: {
                    '[class]': `'el-radio'`,
                    '[class.is-checked]': 'isChecked',
                    '[class.is-disabled]': 'nelDisabled',
                    '[class.is-bordered]': 'nelBorder',
                    '[class.el-radio--medium]': `nelSize == 'medium'`,
                    '[class.el-radio--small]': `nelSize == 'small'`,
                    '[class.el-radio--mini]': `nelSize == 'mini'`,
                    '(click)': 'onHostClick($event)'
                }
            },] }
];
NelRadioComponent.ctorParameters = () => [
    { type: NelRadioService, decorators: [{ type: Optional }] },
    { type: ChangeDetectorRef }
];
NelRadioComponent.propDecorators = {
    nelValue: [{ type: Input }],
    nelDisabled: [{ type: Input }],
    nelBorder: [{ type: Input }],
    nelSize: [{ type: Input }]
};
__decorate([
    InputBoolean()
], NelRadioComponent.prototype, "nelDisabled", void 0);
__decorate([
    InputBoolean()
], NelRadioComponent.prototype, "nelBorder", void 0);

class NelRadioButtonComponent {
    constructor(radio, cdr) {
        this.radio = radio;
        this.cdr = cdr;
        this.isChecked = false;
        this.isDisabled = false;
        this.inputDisabled = '';
        this.change = (value) => { };
    }
    set nelDisabled(val) {
        this.isDisabled = val;
        if (val) {
            this.inputDisabled = 'disabled';
        }
        else {
            this.inputDisabled = '';
        }
        console.log(this.inputDisabled);
    }
    ;
    onHostClick(event) {
        event.stopPropagation();
        event.preventDefault();
        if (!this.isDisabled) {
            this.data = this.nelValue;
            this.isChecked = this.data === this.nelValue;
            this.inputEle.nativeElement.checked = 'checked';
            this.change(this.nelValue);
            if (this.radio) {
                this.radio.select(this.nelValue);
            }
        }
    }
    changeView() {
        this.cdr.markForCheck();
    }
    writeValue(val) {
        this.data = val;
        this.isChecked = this.data === this.nelValue;
        this.cdr.detectChanges();
    }
    registerOnChange(fn) {
        this.change = fn;
    }
    registerOnTouched(fn) { }
}
NelRadioButtonComponent.decorators = [
    { type: Component, args: [{
                selector: '[nel-radio-button]',
                template: "<input #inputEle class=\"el-radio-button__orig-radio\" type=\"radio\" [value]=\"nelValue\" name=\"\" [disabled]=\"inputDisabled\">\r\n<span class=\"el-radio-button__inner\">\r\n  <ng-content></ng-content>\r\n</span>\r\n",
                changeDetection: ChangeDetectionStrategy.OnPush,
                providers: [{
                        provide: NG_VALUE_ACCESSOR,
                        useExisting: forwardRef(() => NelRadioButtonComponent),
                        multi: true
                    }],
                host: {
                    '[class]': `'el-radio-button'`,
                    '[class.is-active]': 'isChecked',
                    '[class.is-disabled]': `isDisabled`,
                    '[class.el-radio-button--medium]': `size == 'medium'`,
                    '[class.el-radio-button--small]': `size == 'small'`,
                    '[class.el-radio-button--mini]': `size == 'mini'`,
                    '(click)': 'onHostClick($event)'
                }
            },] }
];
NelRadioButtonComponent.ctorParameters = () => [
    { type: NelRadioService, decorators: [{ type: Optional }] },
    { type: ChangeDetectorRef }
];
NelRadioButtonComponent.propDecorators = {
    nelValue: [{ type: Input }],
    nelDisabled: [{ type: Input }],
    inputEle: [{ type: ViewChild, args: ['inputEle', { static: false },] }]
};

class NelRadioGroupComponent {
    constructor(radio) {
        this.radio = radio;
        this.nelDisabled = false;
        this.change = (value) => { };
        this.radio.selected$.subscribe(val => {
            this.data = val;
            this.radioList.forEach(item => {
                if (item.nelValue !== this.data) {
                    item.data = this.data;
                    item.isChecked = false;
                    item.changeView();
                }
            });
            this.radioButtonList.forEach(item => {
                if (item.nelValue !== this.data) {
                    item.data = this.data;
                    item.isChecked = false;
                    item.inputEle.nativeElement.checked = '';
                    item.changeView();
                }
            });
            this.change(this.data);
        });
    }
    writeValue(val) {
        if (val) {
            this.data = val;
            this.radioList.forEach(item => {
                if (item.nelValue === this.data) {
                    item.data = this.data;
                    item.isChecked = true;
                    item.changeView();
                }
                else {
                }
            });
            this.radioButtonList.forEach(item => {
                item.data = this.data;
                // disabled
                if (this.nelDisabled) {
                    item.isDisabled = true;
                    item.inputDisabled = 'disabled';
                }
                if (item.nelValue === this.data) {
                    item.isChecked = true;
                    item.inputEle.nativeElement.checked = 'checked';
                }
                else {
                    item.isChecked = false;
                }
                // size
                if (this.nelSize) {
                    item.size = this.nelSize;
                }
                item.changeView();
            });
        }
    }
    registerOnChange(fn) {
        this.change = fn;
    }
    registerOnTouched(fn) { }
}
NelRadioGroupComponent.decorators = [
    { type: Component, args: [{
                selector: 'nel-radio-group',
                template: "<div class=\"el-radio-group\">\r\n  <ng-content></ng-content>\r\n</div>\r\n",
                changeDetection: ChangeDetectionStrategy.OnPush,
                providers: [
                    NelRadioService,
                    {
                        provide: NG_VALUE_ACCESSOR,
                        useExisting: forwardRef(() => NelRadioGroupComponent),
                        multi: true
                    }
                ]
            },] }
];
NelRadioGroupComponent.ctorParameters = () => [
    { type: NelRadioService }
];
NelRadioGroupComponent.propDecorators = {
    nelDisabled: [{ type: Input }],
    nelSize: [{ type: Input }],
    radioList: [{ type: ContentChildren, args: [NelRadioComponent, { descendants: false },] }],
    radioButtonList: [{ type: ContentChildren, args: [NelRadioButtonComponent, { descendants: false },] }]
};
__decorate([
    InputBoolean()
], NelRadioGroupComponent.prototype, "nelDisabled", void 0);

class NelRadioModule {
}
NelRadioModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    NelRadioComponent,
                    NelRadioGroupComponent,
                    NelRadioButtonComponent
                ],
                exports: [
                    NelRadioComponent,
                    NelRadioGroupComponent,
                    NelRadioButtonComponent
                ]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { NelRadioComponent, NelRadioGroupComponent, NelRadioModule, NelRadioService as ɵa, NelRadioButtonComponent as ɵb };
//# sourceMappingURL=ng-element-ui-radio.js.map
