import { __decorate } from 'tslib';
import { Component, Input, NgModule } from '@angular/core';
import { InputBoolean } from 'ng-element-ui/core/utils';
import { Subject } from 'rxjs';
import { CommonModule } from '@angular/common';
import { NelOutletModule } from 'ng-element-ui/core/outlet';

class NelSkeletonComponent {
    constructor() {
        this.rowList = [0, 1, 2, 3];
        this.nelAnimated = false;
        this.nelThrottle = 0;
        this.loading = true;
        this.changeLoading$ = new Subject();
    }
    set nelRows(val) {
        const rowList = [];
        for (let i = 0; i <= val; i++) {
            rowList.push(i);
        }
        this.rowList = rowList;
    }
    set nelLoading(val) {
        if (val) {
            if (this.nelThrottle) {
                this.timeoutHandle = setTimeout(() => {
                    this.loading = val;
                }, this.nelThrottle);
            }
            else {
                this.loading = val;
            }
        }
        else {
            this.loading = val;
            if (this.timeoutHandle) {
                clearTimeout(this.timeoutHandle);
            }
        }
    }
    ngOnDestroy() {
        if (this.timeoutHandle) {
            clearTimeout(this.timeoutHandle);
        }
    }
}
NelSkeletonComponent.decorators = [
    { type: Component, args: [{
                selector: 'nel-skeleton',
                template: "<ng-content *ngIf=\"!loading; else loadingTpl\"></ng-content>\r\n<ng-template #loadingTpl>\r\n  <ng-container *ngIf=\"nelTemplate; else defaultTpl\">\r\n    <ng-container *stringTemplate=\"nelTemplate\">{{nelTemplate}}</ng-container>\r\n  </ng-container>\r\n  <ng-template #defaultTpl>\r\n    <div *ngFor=\"let row of rowList; let first=first; let last=last;\" class=\"el-skeleton__item el-skeleton__p\"\r\n      [class.is-first]=\"first\" [class.is-last]=\"last\" [class.el-skeleton__paragraph]=\"!first\">\r\n    </div>\r\n  </ng-template>\r\n</ng-template>\r\n",
                host: {
                    class: 'el-skeleton',
                    '[class.is-animated]': 'nelAnimated'
                }
            },] }
];
NelSkeletonComponent.propDecorators = {
    nelRows: [{ type: Input }],
    nelAnimated: [{ type: Input }],
    nelTemplate: [{ type: Input }],
    nelLoading: [{ type: Input }],
    nelThrottle: [{ type: Input }]
};
__decorate([
    InputBoolean()
], NelSkeletonComponent.prototype, "nelAnimated", void 0);

class NelSkeletonItemComponent {
    constructor() {
        this.nelVariant = 'text';
    }
}
NelSkeletonItemComponent.decorators = [
    { type: Component, args: [{
                selector: 'nel-skeleton-item',
                template: "<svg *ngIf=\"nelVariant == 'image'\" viewBox=\"0 0 1024 1024\" xmlns=\"http://www.w3.org/2000/svg\">\r\n  <path\r\n    d=\"M64 896V128h896v768H64z m64-128l192-192 116.352 116.352L640 448l256 307.2V192H128v576z m224-480a96 96 0 1 1-0.064 192.064A96 96 0 0 1 352 288z\">\r\n  </path>\r\n</svg>\r\n",
                host: {
                    class: 'el-skeleton__item',
                    '[class.el-skeleton__p]': `nelVariant == 'p'`,
                    '[class.el-skeleton__text]': `nelVariant == 'text'`,
                    '[class.el-skeleton__h1]': `nelVariant == 'h1'`,
                    '[class.el-skeleton__h3]': `nelVariant == 'h3'`,
                    '[class.el-skeleton__caption]': `nelVariant == 'caption'`,
                    '[class.el-skeleton__button]': `nelVariant == 'button'`,
                    '[class.el-skeleton__image]': `nelVariant == 'image'`,
                    '[class.el-skeleton__circle]': `nelVariant == 'circle'`,
                    '[class.el-skeleton__rect]': `nelVariant == 'rect'`,
                }
            },] }
];
NelSkeletonItemComponent.propDecorators = {
    nelVariant: [{ type: Input }]
};

class NelSkeletonModule {
}
NelSkeletonModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    NelSkeletonComponent,
                    NelSkeletonItemComponent
                ],
                exports: [
                    NelSkeletonComponent,
                    NelSkeletonItemComponent
                ],
                imports: [
                    CommonModule,
                    NelOutletModule
                ]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { NelSkeletonComponent, NelSkeletonItemComponent, NelSkeletonModule };
//# sourceMappingURL=ng-element-ui-skeleton.js.map
