import { __decorate } from 'tslib';
import { Directive, Component, ChangeDetectionStrategy, ContentChildren, TemplateRef, Input, NgModule } from '@angular/core';
import { InputBoolean } from 'ng-element-ui/core/utils';
import { CommonModule } from '@angular/common';
import { NelOutletModule } from 'ng-element-ui/core/outlet';

class NelSpaceItemDirective {
}
NelSpaceItemDirective.decorators = [
    { type: Directive, args: [{
                selector: '[nelSpaceItem]'
            },] }
];

class NelSpaceComponent {
    constructor() {
        this.size = '8px';
        this.nelDirection = 'horizontal';
        this.nelAlignment = 'center';
        this.nelWrap = false;
    }
    set nelSize(val) {
        let size = 0;
        if (typeof val === 'string') {
            switch (val) {
                case 'mini':
                    size = 4;
                    break;
                case 'small':
                    size = 8;
                    break;
                case 'medium':
                    size = 12;
                    break;
                case 'large':
                    size = 16;
                    break;
                default:
                    size = 8;
                    break;
            }
        }
        else if (typeof val === 'number') {
            size = val;
        }
        else {
        }
        this.size = size + 'px';
    }
}
NelSpaceComponent.decorators = [
    { type: Component, args: [{
                selector: 'nel-space',
                template: "<ng-content></ng-content>\r\n<ng-container *ngFor=\"let item of items; let last=last\">\r\n  <div class=\"el-space__item\" [style.padding-bottom]=\"nelSpacer ? '' : size\" [style.margin-right]=\"size\">\r\n    <ng-container *ngTemplateOutlet=\"item\"></ng-container>\r\n  </div>\r\n  <span *ngIf=\"nelSpacer && !last\" style=\"padding-bottom: 0px;\" [style.margin-right]=\"size\">\r\n    <ng-container *stringTemplate=\"nelSpacer\">{{nelSpacer}}</ng-container>\r\n  </span>\r\n</ng-container>\r\n",
                changeDetection: ChangeDetectionStrategy.OnPush,
                host: {
                    class: 'el-space',
                    '[class.el-space--horizontal]': `nelDirection == 'horizontal'`,
                    '[class.el-space--vertical]': `nelDirection == 'vertical'`,
                    '[style.align-items]': 'nelAlignment',
                    '[style.flex-wrap]': `nelWrap ? 'wrap' : ''`,
                    '[style.margin-bottom]': `nelSpacer ? '' : '-' + size`,
                }
            },] }
];
NelSpaceComponent.propDecorators = {
    items: [{ type: ContentChildren, args: [NelSpaceItemDirective, { read: TemplateRef },] }],
    nelDirection: [{ type: Input }],
    nelSize: [{ type: Input }],
    nelAlignment: [{ type: Input }],
    nelWrap: [{ type: Input }],
    nelSpacer: [{ type: Input }]
};
__decorate([
    InputBoolean()
], NelSpaceComponent.prototype, "nelWrap", void 0);

class NelSpaceModule {
}
NelSpaceModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    NelSpaceComponent,
                    NelSpaceItemDirective
                ],
                exports: [
                    NelSpaceComponent,
                    NelSpaceItemDirective
                ],
                imports: [
                    CommonModule,
                    NelOutletModule
                ]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { NelSpaceComponent, NelSpaceItemDirective, NelSpaceModule };
//# sourceMappingURL=ng-element-ui-space.js.map
