import { __decorate } from 'tslib';
import { Component, Input, ContentChildren, NgModule } from '@angular/core';
import { InputBoolean } from 'ng-element-ui/core/utils';
import { CommonModule } from '@angular/common';
import { NelIconModule } from 'ng-element-ui/icon';
import { NelOutletModule } from 'ng-element-ui/core/outlet';

class NelStepComponent {
    constructor() {
        this.alignCenter = false;
        this.simple = false;
        this.last = false;
    }
}
NelStepComponent.decorators = [
    { type: Component, args: [{
                selector: 'nel-step',
                template: "<div class=\"el-step__head\" [class.is-process]=\"active == index\" [class.is-wait]=\"index > active\"\r\n  [class.is-success]=\"finishStatus == 'success' && index < active\"\r\n  [class.is-finish]=\"finishStatus == 'finish' && index < active\"\r\n  [class.is-error]=\"finishStatus == 'error' && index < active\">\r\n  <div class=\"el-step__line\"><i class=\"el-step__line-inner\"></i></div>\r\n  <div class=\"el-step__icon\" [class.is-text]=\"!nelIcon\" [class.is-icon]=\"nelIcon\">\r\n    <i *ngIf=\"nelIcon; else noIcon\" nel-icon [nelType]=\"nelIcon\" class=\"el-step__icon-inner\"></i>\r\n    <ng-template #noIcon>\r\n      <div *ngIf=\"index >= active; else iconTpl\" class=\"el-step__icon-inner\">\r\n        <ng-container *ngIf=\"!simple\">\r\n          {{index + 1}}\r\n        </ng-container>\r\n      </div>\r\n      <ng-template #iconTpl>\r\n        <i nel-icon [nelType]=\"'check'\" class=\"el-step__icon-inner is-status\"></i>\r\n      </ng-template>\r\n    </ng-template>\r\n  </div>\r\n</div>\r\n<div class=\"el-step__main\">\r\n  <div class=\"el-step__title\" [class.is-process]=\"active == index\" [class.is-wait]=\"index > active\"\r\n    [class.is-success]=\"finishStatus == 'success' && index < active\"\r\n    [class.is-finish]=\"finishStatus == 'finish' && index < active\"\r\n    [class.is-error]=\"finishStatus == 'error' && index < active\">\r\n    <ng-container *ngIf=\"nelTitle\">\r\n      <ng-container *stringTemplate=\"nelTitle\">{{nelTitle}}</ng-container>\r\n    </ng-container>\r\n  </div>\r\n  <div class=\"el-step__description\" [class.is-process]=\"active == index\" [class.is-wait]=\"index > active\"\r\n    [class.is-success]=\"finishStatus == 'success' && index < active\"\r\n    [class.is-finish]=\"finishStatus == 'finish' && index < active\"\r\n    [class.is-error]=\"finishStatus == 'error' && index < active\">\r\n    <ng-container *ngIf=\"nelDescription\">\r\n      <ng-container *stringTemplate=\"nelDescription\">{{nelDescription}}</ng-container>\r\n    </ng-container>\r\n  </div>\r\n  <div *ngIf=\"simple\" class=\"el-step__arrow\"></div>\r\n</div>\r\n",
                host: {
                    class: 'el-step',
                    '[class.is-horizontal]': `!simple && direction == 'horizontal'`,
                    '[class.is-vertical]': `!simple && direction == 'vertical'`,
                    '[class.is-simple]': 'simple',
                    '[class.is-flex]': 'last && !alignCenter',
                    '[class.is-center]': 'alignCenter',
                    '[style.max-width]': `last ? space : ''`,
                    '[style.flex-basis]': 'space'
                }
            },] }
];
NelStepComponent.propDecorators = {
    nelTitle: [{ type: Input }],
    nelDescription: [{ type: Input }],
    nelIcon: [{ type: Input }]
};

class NelStepsComponent {
    constructor() {
        this.initStatus = false;
        this.active = 0;
        this.nelFinishStatus = 'finish';
        this.nelAlignCenter = false;
        this.nelDirection = 'horizontal';
        this.nelSimple = false;
    }
    set nelActive(val) {
        this.active = val;
        if (this.initStatus) {
            this.changeActive();
        }
    }
    ngAfterContentInit() {
        const lastStep = this.stepList.last;
        lastStep.last = true;
        this.changeActive();
        this.initStatus = true;
    }
    changeActive() {
        const stepLength = this.stepList.length;
        let space = '';
        if (this.nelAlignCenter) {
            space = 100 / stepLength + '%';
        }
        else {
            space = 100 / (stepLength - 1) + '%';
        }
        this.stepList.forEach((item, index) => {
            if (!item.index) {
                item.index = index;
            }
            item.active = this.active;
            item.finishStatus = this.nelFinishStatus;
            item.alignCenter = this.nelAlignCenter;
            item.direction = this.nelDirection;
            item.simple = this.nelSimple;
            if (this.nelSpace) {
                item.space = typeof this.nelSpace === 'number' ? this.nelSpace + 'px' : this.nelSpace;
            }
            else {
                item.space = space;
            }
        });
    }
}
NelStepsComponent.decorators = [
    { type: Component, args: [{
                selector: 'nel-steps',
                template: "<ng-content></ng-content>\r\n",
                host: {
                    class: 'el-steps',
                    '[class.el-steps--horizontal]': `!nelSimple && nelDirection == 'horizontal'`,
                    '[class.el-steps--vertical]': `!nelSimple && nelDirection == 'vertical'`,
                    '[class.el-steps--simple]': 'nelSimple',
                }
            },] }
];
NelStepsComponent.propDecorators = {
    nelSpace: [{ type: Input }],
    nelFinishStatus: [{ type: Input }],
    nelAlignCenter: [{ type: Input }],
    nelDirection: [{ type: Input }],
    nelSimple: [{ type: Input }],
    nelActive: [{ type: Input }],
    stepList: [{ type: ContentChildren, args: [NelStepComponent, { descendants: false },] }]
};
__decorate([
    InputBoolean()
], NelStepsComponent.prototype, "nelAlignCenter", void 0);
__decorate([
    InputBoolean()
], NelStepsComponent.prototype, "nelSimple", void 0);

class NelStepsModule {
}
NelStepsModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    NelStepsComponent,
                    NelStepComponent
                ],
                exports: [
                    NelStepsComponent,
                    NelStepComponent
                ],
                imports: [
                    CommonModule,
                    NelIconModule,
                    NelOutletModule
                ]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { NelStepComponent, NelStepsComponent, NelStepsModule };
//# sourceMappingURL=ng-element-ui-steps.js.map
