import { __decorate } from 'tslib';
import { Component, Input, ViewChild, TemplateRef, EventEmitter, ChangeDetectionStrategy, ChangeDetectorRef, ContentChildren, ViewChildren, Output, NgModule } from '@angular/core';
import { InputBoolean } from 'ng-element-ui/core/utils';
import { CommonModule } from '@angular/common';
import { NelOutletModule } from 'ng-element-ui/core/outlet';

class NelTabPaneComponent {
    constructor() {
        this.active = false;
    }
}
NelTabPaneComponent.decorators = [
    { type: Component, args: [{
                selector: 'nel-tab-pane',
                template: "<ng-template>\r\n  <ng-content></ng-content>\r\n</ng-template>\r\n<div class=\"el-tab-pane\" [style.display]=\"active ? '' : 'none'\">\r\n  <ng-container *ngTemplateOutlet=\"content\"></ng-container>\r\n</div>\r\n"
            },] }
];
NelTabPaneComponent.propDecorators = {
    nelLabel: [{ type: Input }],
    content: [{ type: ViewChild, args: [TemplateRef, { static: true },] }]
};

class NelTabsComponent {
    constructor(cdr) {
        this.cdr = cdr;
        this._tabLabelCount = 0;
        this._tabItems = [];
        this.activeBar = {
            width: '',
            height: '',
            transform: ''
        };
        this.scrollable = false;
        this.scrollTransform = '';
        this.nelSelectedIndex = 0;
        this.nelTabPosition = 'top';
        this.nelEditable = false;
        this.nelSelectedIndexChange = new EventEmitter();
        this.nelOnEdit = new EventEmitter();
    }
    ngAfterContentInit() {
        this._tabLabelCount = this.items.length;
        setTimeout(() => {
            this.changeTabPane();
        }, 0);
    }
    ngAfterContentChecked() {
        if (this._tabLabelCount !== this.items.length) {
            this.ngAfterViewInit();
            this.ngAfterContentInit();
        }
    }
    ngAfterViewInit() {
        if (!this.nelType) {
            this._tabItems = [];
            this.tabItems.forEach((item) => {
                const _item = {
                    width: item.nativeElement.offsetWidth,
                    height: item.nativeElement.offsetHeight,
                };
                this._tabItems.push(_item);
            });
        }
        this.changeScroll();
        this.changeTab(true);
    }
    ngOnChanges(changes) {
        const { nelTabPosition } = changes;
        if ((nelTabPosition && !nelTabPosition.firstChange)) {
            setTimeout(() => {
                this.ngAfterViewInit();
            }, 0);
        }
    }
    changeTabPane() {
        this.items.forEach(item => {
            item.active = false;
        });
        const activeItem = this.items.get(this.nelSelectedIndex);
        if (activeItem) {
            activeItem.active = true;
        }
    }
    selecteTab(val) {
        this.nelSelectedIndex = val;
        this.nelSelectedIndexChange.emit(val);
        this.changeTab(false);
        this.changeTabPane();
    }
    changeTab(init) {
        if (!this.nelType) {
            let key = 'width';
            if (this.nelTabPosition === 'right' || this.nelTabPosition === 'left') {
                key = 'height';
            }
            let width = 0;
            let height = 0;
            let transform = 0;
            if (key === 'width') {
                this._tabItems.forEach((item, index) => {
                    if (index < this.nelSelectedIndex) {
                        transform += item[key];
                    }
                    else if (index === this.nelSelectedIndex) {
                        width = item[key];
                    }
                });
                if (this.nelSelectedIndex === this.tabItems.length - 1) {
                    transform += 20;
                    width -= 20;
                }
                else if (this.nelSelectedIndex > 0) {
                    transform += 20;
                    width -= 40;
                }
                else {
                    width -= 20;
                }
            }
            else {
                this._tabItems.forEach((item, index) => {
                    if (index < this.nelSelectedIndex) {
                        transform += item[key];
                    }
                    else if (index === this.nelSelectedIndex) {
                        height = item[key];
                    }
                });
            }
            if (init) {
                setTimeout(() => {
                    this.activeBar = {
                        width: key === 'width' ? width + 'px' : '',
                        height: key === 'height' ? height + 'px' : '',
                        transform: key === 'width' ? `translateX(${transform}px)` : `translateY(${transform}px)`
                    };
                }, 0);
            }
            else {
                this.activeBar = {
                    width: key === 'width' ? width + 'px' : '',
                    height: key === 'height' ? height + 'px' : '',
                    transform: key === 'width' ? `translateX(${transform}px)` : `translateY(${transform}px)`
                };
            }
        }
    }
    changeScroll() {
        // 判断是否显示滚动条
        setTimeout(() => {
            if (this.navScroll.nativeElement.offsetWidth < this.navScrollPosition.nativeElement.offsetWidth) {
                this.scrollable = true;
                this.scrollTransform = `translateX(${this.navScroll.nativeElement.offsetWidth - this.navScrollPosition.nativeElement.offsetWidth}px)`;
                this.cdr.markForCheck();
            }
            else {
                this.scrollable = false;
                this.scrollTransform = 'translateX(0px)';
                this.cdr.markForCheck();
            }
        }, 0);
    }
    edit() {
        this.nelOnEdit.emit({ index: -1, action: 'add' });
    }
    remove(event, _index) {
        event.stopPropagation();
        this.nelOnEdit.emit({ index: _index, action: 'remove' });
    }
}
NelTabsComponent.decorators = [
    { type: Component, args: [{
                selector: 'nel-tabs',
                template: "<div class=\"el-tabs el-tabs--{{nelTabPosition}}\" [class.el-tabs--card]=\"nelType == 'card'\"\r\n  [class.el-tabs--border-card]=\"nelType == 'border-card'\">\r\n  <ng-container *ngIf=\"nelTabPosition != 'bottom'\">\r\n    <ng-container *ngTemplateOutlet=\"tabsTpl\"></ng-container>\r\n  </ng-container>\r\n  <div class=\"el-tabs__content\">\r\n    <ng-content></ng-content>\r\n  </div>\r\n  <ng-container *ngIf=\"nelTabPosition == 'bottom'\">\r\n    <ng-container *ngTemplateOutlet=\"tabsTpl\"></ng-container>\r\n  </ng-container>\r\n</div>\r\n<ng-template #tabsTpl>\r\n  <div class=\"el-tabs__header is-{{nelTabPosition}}\">\r\n    <span *ngIf=\"nelType == 'card' && this.nelEditable\" (click)=\"edit()\" class=\"el-tabs__new-tab\" tabindex=\"0\">\r\n      <i class=\"el-icon-plus\"></i>\r\n    </span>\r\n    <div class=\"el-tabs__nav-wrap is-{{nelTabPosition}}\" [class.is-scrollable]=\"scrollable\">\r\n      <!-- scrollable -->\r\n      <ng-container *ngIf=\"scrollable\">\r\n        <span class=\"el-tabs__nav-prev\"><i class=\"el-icon-arrow-left\"></i></span>\r\n        <span class=\"el-tabs__nav-next is-disabled\"><i class=\"el-icon-arrow-right\"></i></span>\r\n      </ng-container>\r\n      <div #navScroll class=\"el-tabs__nav-scroll\">\r\n        <div #navScrollPosition class=\"el-tabs__nav is-{{nelTabPosition}}\" [style.transform]=\"scrollTransform\">\r\n          <div *ngIf=\"!nelType\" class=\"el-tabs__active-bar is-{{nelTabPosition}}\" [style.width]=\"activeBar.width\"\r\n            [style.height]=\"activeBar.height\" [style.transform]=\"activeBar.transform\"></div>\r\n          <ng-container *ngFor=\"let tabPane of items; let index=index\">\r\n            <div #tabItem (click)=\"selecteTab(index)\" class=\"el-tabs__item is-{{nelTabPosition}}\"\r\n              [class.is-active]=\"index == nelSelectedIndex\" [class.is-closable]=\"nelType == 'card' && this.nelEditable\">\r\n              <ng-container *ngIf=\"tabPane.nelLabel\">\r\n                <ng-container *stringTemplate=\"tabPane.nelLabel\">{{tabPane.nelLabel}}</ng-container>\r\n              </ng-container>\r\n              <span *ngIf=\"nelType == 'card' && this.nelEditable\" (click)=\"remove($event, index)\"\r\n                class=\"el-icon-close\"></span>\r\n            </div>\r\n          </ng-container>\r\n        </div>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</ng-template>\r\n",
                changeDetection: ChangeDetectionStrategy.OnPush
            },] }
];
NelTabsComponent.ctorParameters = () => [
    { type: ChangeDetectorRef }
];
NelTabsComponent.propDecorators = {
    nelSelectedIndex: [{ type: Input }],
    nelType: [{ type: Input }],
    nelTabPosition: [{ type: Input }],
    nelEditable: [{ type: Input }],
    items: [{ type: ContentChildren, args: [NelTabPaneComponent, { descendants: false },] }],
    tabItems: [{ type: ViewChildren, args: ['tabItem',] }],
    navScroll: [{ type: ViewChild, args: ['navScroll', { static: false },] }],
    navScrollPosition: [{ type: ViewChild, args: ['navScrollPosition', { static: false },] }],
    nelSelectedIndexChange: [{ type: Output }],
    nelOnEdit: [{ type: Output }]
};
__decorate([
    InputBoolean()
], NelTabsComponent.prototype, "nelEditable", void 0);

class NelTabsModule {
}
NelTabsModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    NelTabsComponent,
                    NelTabPaneComponent
                ],
                exports: [
                    NelTabsComponent,
                    NelTabPaneComponent
                ],
                imports: [
                    CommonModule,
                    NelOutletModule
                ]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { NelTabPaneComponent, NelTabsComponent, NelTabsModule };
//# sourceMappingURL=ng-element-ui-tabs.js.map
