import { Component, ChangeDetectionStrategy, Directive, ElementRef, Input, HostListener, NgModule } from '@angular/core';
import { fadeMotion } from 'ng-element-ui/core/animation';
import { ComponentPortal } from '@angular/cdk/portal';
import { Overlay, OverlayPositionBuilder, OverlayModule } from '@angular/cdk/overlay';
import { NelOutletModule } from 'ng-element-ui/core/outlet';

class NelTooltipComponent {
    constructor() {
        this.arrowLeft = '';
        this.arrowRight = '';
        this.arrowTop = '';
        this.arrowBottom = '';
        this.transform = '';
        this.effect = 'dark';
    }
}
NelTooltipComponent.decorators = [
    { type: Component, args: [{
                selector: 'nel-tooltip',
                template: "<div class=\"el-popper is-{{effect}}\">\r\n  <ng-container *stringTemplate=\"content\">{{content}}</ng-container>\r\n  <div class=\"el-popper__arrow\" [style.left]=\"arrowLeft\" [style.right]=\"arrowRight\" [style.top]=\"arrowTop\"\r\n    [style.bottom]=\"arrowBottom\" [style.transform]=\"transform\"></div>\r\n</div>\r\n",
                changeDetection: ChangeDetectionStrategy.OnPush,
                animations: [fadeMotion]
            },] }
];

class NelTooltipDirective {
    constructor(overlay, overlayPositionBuilder, elementRef) {
        this.overlay = overlay;
        this.overlayPositionBuilder = overlayPositionBuilder;
        this.elementRef = elementRef;
        this.nelPlacement = 'bottom';
        this.nelEffect = 'dark';
        this.disabled = false;
    }
    set nelDisabled(value) {
        this.disabled = value;
        if (value) {
            this.hide();
        }
    }
    ngOnInit() {
        // if (this.nelPlacement === 'bottom') {
        //   this.show();
        // }
    }
    onMouseenter() {
        if (!this.disabled) {
            this.show();
        }
    }
    onMouseleave() {
        this.hide();
    }
    show() {
        const position = {
            originX: 'start',
            originY: 'top',
            overlayX: 'start',
            overlayY: 'bottom',
            offsetX: 0,
            offsetY: 0
        };
        let arrowLeft = '';
        let arrowRight = '';
        let arrowTop = '';
        let arrowBottom = '';
        let transform = '';
        switch (this.nelPlacement) {
            case 'top-start':
                position.originX = 'start';
                position.originY = 'top';
                position.overlayX = 'start';
                position.overlayY = 'bottom';
                position.offsetY = -10;
                arrowLeft = '0';
                transform = 'translate(30px, 5px)';
                break;
            case 'top':
                position.originX = 'center';
                position.originY = 'top';
                position.overlayX = 'center';
                position.overlayY = 'bottom';
                position.offsetY = -10;
                arrowLeft = '50%';
                transform = 'translate(-50%, 5px)';
                break;
            case 'top-end':
                position.originX = 'end';
                position.originY = 'top';
                position.overlayX = 'end';
                position.overlayY = 'bottom';
                position.offsetY = -10;
                arrowLeft = '50%';
                transform = 'translate(30px, 5px)';
                break;
            case 'bottom-start':
                position.originX = 'start';
                position.originY = 'bottom';
                position.overlayX = 'start';
                position.overlayY = 'top';
                position.offsetY = 10;
                arrowLeft = '0';
                arrowTop = '-10px';
                transform = 'translate(30px, 5px)';
                break;
            case 'bottom':
                position.originX = 'center';
                position.originY = 'bottom';
                position.overlayX = 'center';
                position.overlayY = 'top';
                position.offsetY = 10;
                arrowLeft = '50%';
                arrowTop = '-10px';
                transform = 'translate(-50%, 5px)';
                break;
            case 'bottom-end':
                position.originX = 'end';
                position.originY = 'bottom';
                position.overlayX = 'end';
                position.overlayY = 'top';
                position.offsetY = 10;
                arrowLeft = '50%';
                arrowTop = '-10px';
                transform = 'translate(30px, 5px)';
                break;
            case 'left-start':
                position.originX = 'start';
                position.originY = 'top';
                position.overlayX = 'end';
                position.overlayY = 'top';
                position.offsetX = -10;
                arrowRight = '0';
                arrowTop = '0';
                transform = 'translate(5px, 15px)';
                break;
            case 'left':
                position.originX = 'start';
                position.originY = 'center';
                position.overlayX = 'end';
                position.overlayY = 'center';
                position.offsetX = -10;
                arrowRight = '0';
                arrowTop = '50%';
                transform = 'translate(5px, -50%)';
                break;
            case 'left-end':
                position.originX = 'start';
                position.originY = 'bottom';
                position.overlayX = 'end';
                position.overlayY = 'bottom';
                position.offsetX = -10;
                arrowRight = '0';
                arrowBottom = '0';
                transform = 'translate(5px, -15px)';
                break;
            case 'right-start':
                position.originX = 'end';
                position.originY = 'top';
                position.overlayX = 'start';
                position.overlayY = 'top';
                position.offsetX = 10;
                arrowLeft = '0';
                arrowTop = '0';
                transform = 'translate(-5px, 15px)';
                break;
            case 'right':
                position.originX = 'end';
                position.originY = 'center';
                position.overlayX = 'start';
                position.overlayY = 'center';
                position.offsetX = 10;
                arrowLeft = '0';
                arrowTop = '50%';
                transform = 'translate(-5px, -50%)';
                break;
            case 'right-end':
                position.originX = 'end';
                position.originY = 'bottom';
                position.overlayX = 'start';
                position.overlayY = 'bottom';
                position.offsetX = 10;
                arrowLeft = '0';
                arrowBottom = '0';
                transform = 'translate(-5px, -15px)';
                break;
        }
        const positionStrategy = this.overlayPositionBuilder
            .flexibleConnectedTo(this.elementRef)
            .withPositions([position]);
        this.overlayRef = this.overlay.create({ positionStrategy });
        if (this.overlayRef) {
            const tooltipRef = this.overlayRef.attach(new ComponentPortal(NelTooltipComponent));
            if (this.nelContent) {
                tooltipRef.instance.content = this.nelContent;
                tooltipRef.instance.effect = this.nelEffect;
                tooltipRef.instance.arrowLeft = arrowLeft;
                tooltipRef.instance.arrowRight = arrowRight;
                tooltipRef.instance.arrowTop = arrowTop;
                tooltipRef.instance.arrowBottom = arrowBottom;
                tooltipRef.instance.transform = transform;
            }
        }
    }
    hide() {
        var _a;
        (_a = this.overlayRef) === null || _a === void 0 ? void 0 : _a.detach();
    }
}
NelTooltipDirective.decorators = [
    { type: Directive, args: [{
                selector: '[nel-tooltip]',
            },] }
];
NelTooltipDirective.ctorParameters = () => [
    { type: Overlay },
    { type: OverlayPositionBuilder },
    { type: ElementRef }
];
NelTooltipDirective.propDecorators = {
    nelContent: [{ type: Input }],
    nelPlacement: [{ type: Input }],
    nelEffect: [{ type: Input }],
    nelDisabled: [{ type: Input }],
    onMouseenter: [{ type: HostListener, args: ['mouseenter', ['$event.target'],] }],
    onMouseleave: [{ type: HostListener, args: ['mouseleave', ['$event.target'],] }]
};

class NelTooltipModule {
}
NelTooltipModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    NelTooltipComponent,
                    NelTooltipDirective
                ],
                exports: [
                    NelTooltipComponent,
                    NelTooltipDirective
                ],
                entryComponents: [
                    NelTooltipComponent
                ],
                imports: [
                    OverlayModule,
                    NelOutletModule
                ]
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { NelTooltipComponent, NelTooltipDirective, NelTooltipModule };
//# sourceMappingURL=ng-element-ui-tooltip.js.map
